(function () {
    (function (arr) {
        arr.forEach(function (item) {
            if (item.hasOwnProperty('remove')) {
                return;
            }
            Object.defineProperty(item, 'remove', {
                configurable: true,
                enumerable: true,
                writable: true,
                value: function remove() {
                    this.parentNode.removeChild(this);
                }
            });
        });
    })([Element.prototype, CharacterData.prototype, DocumentType.prototype]);

    if (!("customElements" in window)) {
        window.customElements = {};
    }
    window.customElements.forcePolyfill = true;
    window._nativeCustomElements = window.customElements;
})();
/**
 * @license
 * Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
 */

// minimal template polyfill
(function() {
  'use strict';

  var needsTemplate = (typeof HTMLTemplateElement === 'undefined');
  var brokenDocFragment = !(document.createDocumentFragment().cloneNode() instanceof DocumentFragment);
  var needsDocFrag = false;

  // NOTE: Replace DocumentFragment to work around IE11 bug that
  // casues children of a document fragment modified while
  // there is a mutation observer to not have a parentNode, or
  // have a broken parentNode (!?!)
  if (/Trident/.test(navigator.userAgent)) {
    (function() {

      needsDocFrag = true;

      var origCloneNode = Node.prototype.cloneNode;
      Node.prototype.cloneNode = function cloneNode(deep) {
        var newDom = origCloneNode.call(this, deep);
        if (this instanceof DocumentFragment) {
          newDom.__proto__ = DocumentFragment.prototype;
        }
        return newDom;
      };

      // IE's DocumentFragment querySelector code doesn't work when
      // called on an element instance
      DocumentFragment.prototype.querySelectorAll = HTMLElement.prototype.querySelectorAll;
      DocumentFragment.prototype.querySelector = HTMLElement.prototype.querySelector;

      Object.defineProperties(DocumentFragment.prototype, {
        'nodeType': {
          get: function () {
            return Node.DOCUMENT_FRAGMENT_NODE;
          },
          configurable: true
        },

        'localName': {
          get: function () {
            return undefined;
          },
          configurable: true
        },

        'nodeName': {
          get: function () {
            return '#document-fragment';
          },
          configurable: true
        }
      });

      var origInsertBefore = Node.prototype.insertBefore;
      function insertBefore(newNode, refNode) {
        if (newNode instanceof DocumentFragment) {
          var child;
          while ((child = newNode.firstChild)) {
            origInsertBefore.call(this, child, refNode);
          }
        } else {
          origInsertBefore.call(this, newNode, refNode);
        }
        return newNode;
      }
      Node.prototype.insertBefore = insertBefore;

      var origAppendChild = Node.prototype.appendChild;
      Node.prototype.appendChild = function appendChild(child) {
        if (child instanceof DocumentFragment) {
          insertBefore.call(this, child, null);
        } else {
          origAppendChild.call(this, child);
        }
        return child;
      };

      var origRemoveChild = Node.prototype.removeChild;
      var origReplaceChild = Node.prototype.replaceChild;
      Node.prototype.replaceChild = function replaceChild(newChild, oldChild) {
        if (newChild instanceof DocumentFragment) {
          insertBefore.call(this, newChild, oldChild);
          origRemoveChild.call(this, oldChild);
        } else {
          origReplaceChild.call(this, newChild, oldChild);
        }
        return oldChild;
      };

      Document.prototype.createDocumentFragment = function createDocumentFragment() {
        var frag = this.createElement('df');
        frag.__proto__ = DocumentFragment.prototype;
        return frag;
      };

      var origImportNode = Document.prototype.importNode;
      Document.prototype.importNode = function importNode(impNode, deep) {
        deep = deep || false;
        var newNode = origImportNode.call(this, impNode, deep);
        if (impNode instanceof DocumentFragment) {
          newNode.__proto__ = DocumentFragment.prototype;
        }
        return newNode;
      };
    })();
  }

  // NOTE: we rely on this cloneNode not causing element upgrade.
  // This means this polyfill must load before the CE polyfill and
  // this would need to be re-worked if a browser supports native CE
  // but not <template>.
  var capturedCloneNode = Node.prototype.cloneNode;
  var capturedCreateElement = Document.prototype.createElement;
  var capturedImportNode = Document.prototype.importNode;
  var capturedRemoveChild = Node.prototype.removeChild;
  var capturedAppendChild = Node.prototype.appendChild;
  var capturedReplaceChild = Node.prototype.replaceChild;

  var elementQuerySelectorAll = Element.prototype.querySelectorAll;
  var docQuerySelectorAll = Document.prototype.querySelectorAll;
  var fragQuerySelectorAll = DocumentFragment.prototype.querySelectorAll;

  function QSA(node, selector) {
    switch (node.nodeType) {
      case Node.DOCUMENT_NODE:
        return docQuerySelectorAll.call(node, selector);
      case Node.DOCUMENT_FRAGMENT_NODE:
        return fragQuerySelectorAll.call(node, selector);
      default:
        return elementQuerySelectorAll.call(node, selector);
    }
  }

  // returns true if nested templates cannot be cloned (they cannot be on
  // some impl's like Safari 8 and Edge)
  // OR if cloning a document fragment does not result in a document fragment
  var needsCloning = (function() {
    if (!needsTemplate) {
      var t = document.createElement('template');
      var t2 = document.createElement('template');
      t2.content.appendChild(document.createElement('div'));
      t.content.appendChild(t2);
      var clone = t.cloneNode(true);
      return (clone.content.childNodes.length === 0 || clone.content.firstChild.content.childNodes.length === 0
        || brokenDocFragment);
    }
  })();

  var TEMPLATE_TAG = 'template';
  var PolyfilledHTMLTemplateElement = function() {};

  if (needsTemplate) {

    var contentDoc = document.implementation.createHTMLDocument('template');
    var canDecorate = true;

    var templateStyle = document.createElement('style');
    templateStyle.textContent = TEMPLATE_TAG + '{display:none;}';

    var head = document.head;
    head.insertBefore(templateStyle, head.firstElementChild);

    /**
      Provides a minimal shim for the <template> element.
    */
    PolyfilledHTMLTemplateElement.prototype = Object.create(HTMLElement.prototype);


    // if elements do not have `innerHTML` on instances, then
    // templates can be patched by swizzling their prototypes.
    var canProtoPatch =
      !(document.createElement('div').hasOwnProperty('innerHTML'));

    /**
      The `decorate` method moves element children to the template's `content`.
      NOTE: there is no support for dynamically adding elements to templates.
    */
    PolyfilledHTMLTemplateElement.decorate = function(template) {
      // if the template is decorated, return fast
      if (template.content) {
        return;
      }
      template.content = contentDoc.createDocumentFragment();
      var child;
      while ((child = template.firstChild)) {
        capturedAppendChild.call(template.content, child);
      }
      // NOTE: prefer prototype patching for performance and
      // because on some browsers (IE11), re-defining `innerHTML`
      // can result in intermittent errors.
      if (canProtoPatch) {
        template.__proto__ = PolyfilledHTMLTemplateElement.prototype;
      } else {
        template.cloneNode = function(deep) {
          return PolyfilledHTMLTemplateElement._cloneNode(this, deep);
        };
        // add innerHTML to template, if possible
        // Note: this throws on Safari 7
        if (canDecorate) {
          try {
            defineInnerHTML(template);
            defineOuterHTML(template);
          } catch (err) {
            canDecorate = false;
          }
        }
      }
      // bootstrap recursively
      PolyfilledHTMLTemplateElement.bootstrap(template.content);
    };

    var defineInnerHTML = function defineInnerHTML(obj) {
      Object.defineProperty(obj, 'innerHTML', {
        get: function() {
          var o = '';
          for (var e = this.content.firstChild; e; e = e.nextSibling) {
            o += e.outerHTML || escapeData(e.data);
          }
          return o;
        },
        set: function(text) {
          contentDoc.body.innerHTML = text;
          PolyfilledHTMLTemplateElement.bootstrap(contentDoc);
          while (this.content.firstChild) {
            capturedRemoveChild.call(this.content, this.content.firstChild);
          }
          while (contentDoc.body.firstChild) {
            capturedAppendChild.call(this.content, contentDoc.body.firstChild);
          }
        },
        configurable: true
      });
    };

    var defineOuterHTML = function defineOuterHTML(obj) {
      Object.defineProperty(obj, 'outerHTML', {
        get: function() {
          return '<' + TEMPLATE_TAG + '>' + this.innerHTML + '</' + TEMPLATE_TAG + '>';
        },
        set: function(innerHTML) {
          if (this.parentNode) {
            contentDoc.body.innerHTML = innerHTML;
            var docFrag = this.ownerDocument.createDocumentFragment();
            while (contentDoc.body.firstChild) {
              capturedAppendChild.call(docFrag, contentDoc.body.firstChild);
            }
            capturedReplaceChild.call(this.parentNode, docFrag, this);
          } else {
            throw new Error("Failed to set the 'outerHTML' property on 'Element': This element has no parent node.");
          }
        },
        configurable: true
      });
    };

    defineInnerHTML(PolyfilledHTMLTemplateElement.prototype);
    defineOuterHTML(PolyfilledHTMLTemplateElement.prototype);

    /**
      The `bootstrap` method is called automatically and "fixes" all
      <template> elements in the document referenced by the `doc` argument.
    */
    PolyfilledHTMLTemplateElement.bootstrap = function bootstrap(doc) {
      var templates = QSA(doc, TEMPLATE_TAG);
      for (var i=0, l=templates.length, t; (i<l) && (t=templates[i]); i++) {
        PolyfilledHTMLTemplateElement.decorate(t);
      }
    };

    // auto-bootstrapping for main document
    document.addEventListener('DOMContentLoaded', function() {
      PolyfilledHTMLTemplateElement.bootstrap(document);
    });

    // Patch document.createElement to ensure newly created templates have content
    Document.prototype.createElement = function createElement() {
      var el = capturedCreateElement.apply(this, arguments);
      if (el.localName === 'template') {
        PolyfilledHTMLTemplateElement.decorate(el);
      }
      return el;
    };

    var escapeDataRegExp = /[&\u00A0<>]/g;

    var escapeReplace = function escapeReplace(c) {
      switch (c) {
        case '&':
          return '&amp;';
        case '<':
          return '&lt;';
        case '>':
          return '&gt;';
        case '\u00A0':
          return '&nbsp;';
      }
    };

    var escapeData = function escapeData(s) {
      return s.replace(escapeDataRegExp, escapeReplace);
    };
  }

  // make cloning/importing work!
  if (needsTemplate || needsCloning) {

    PolyfilledHTMLTemplateElement._cloneNode = function _cloneNode(template, deep) {
      var clone = capturedCloneNode.call(template, false);
      // NOTE: decorate doesn't auto-fix children because they are already
      // decorated so they need special clone fixup.
      if (this.decorate) {
        this.decorate(clone);
      }
      if (deep) {
        // NOTE: use native clone node to make sure CE's wrapped
        // cloneNode does not cause elements to upgrade.
        capturedAppendChild.call(clone.content, capturedCloneNode.call(template.content, true));
        // now ensure nested templates are cloned correctly.
        fixClonedDom(clone.content, template.content);
      }
      return clone;
    };

    // Given a source and cloned subtree, find <template>'s in the cloned
    // subtree and replace them with cloned <template>'s from source.
    // We must do this because only the source templates have proper .content.
    var fixClonedDom = function fixClonedDom(clone, source) {
      // do nothing if cloned node is not an element
      if (!source.querySelectorAll) return;
      // these two lists should be coincident
      var s$ = QSA(source, TEMPLATE_TAG);
      if (s$.length === 0) {
        return;
      }
      var t$ = QSA(clone, TEMPLATE_TAG);
      for (var i=0, l=t$.length, t, s; i<l; i++) {
        s = s$[i];
        t = t$[i];
        if (PolyfilledHTMLTemplateElement && PolyfilledHTMLTemplateElement.decorate) {
          PolyfilledHTMLTemplateElement.decorate(s);
        }
        capturedReplaceChild.call(t.parentNode, cloneNode.call(s, true), t);
      }
    };

    // override all cloning to fix the cloned subtree to contain properly
    // cloned templates.
    var cloneNode = Node.prototype.cloneNode = function cloneNode(deep) {
      var dom;
      // workaround for Edge bug cloning documentFragments
      // https://developer.microsoft.com/en-us/microsoft-edge/platform/issues/8619646/
      if (!needsDocFrag && brokenDocFragment && this instanceof DocumentFragment) {
        if (!deep) {
          return this.ownerDocument.createDocumentFragment();
        } else {
          dom = importNode.call(this.ownerDocument, this, true);
        }
      } else if (this.nodeType === Node.ELEMENT_NODE && this.localName === TEMPLATE_TAG) {
        dom = PolyfilledHTMLTemplateElement._cloneNode(this, deep);
      } else {
        dom = capturedCloneNode.call(this, deep);
      }
      // template.content is cloned iff `deep`.
      if (deep) {
        fixClonedDom(dom, this);
      }
      return dom;
    };

    // NOTE: we are cloning instead of importing <template>'s.
    // However, the ownerDocument of the cloned template will be correct!
    // This is because the native import node creates the right document owned
    // subtree and `fixClonedDom` inserts cloned templates into this subtree,
    // thus updating the owner doc.
    var importNode = Document.prototype.importNode = function importNode(element, deep) {
      deep = deep || false;
      if (element.localName === TEMPLATE_TAG) {
        return PolyfilledHTMLTemplateElement._cloneNode(element, deep);
      } else {
        var dom = capturedImportNode.call(this, element, deep);
        if (deep) {
          fixClonedDom(dom, element);
        }
        return dom;
      }
    };
  }

  if (needsTemplate) {
    window.HTMLTemplateElement = PolyfilledHTMLTemplateElement;
  }

})();

/**
 * @license
 * Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
 */

/**
 * This shim allows elements written in, or compiled to, ES5 to work on native
 * implementations of Custom Elements.
 *
 * ES5-style classes don't work with native Custom Elements because the
 * HTMLElement constructor uses the value of `new.target` to look up the custom
 * element definition for the currently called constructor. `new.target` is only
 * set when `new` is called and is only propagated via super() calls. super()
 * is not emulatable in ES5. The pattern of `SuperClass.call(this)`` only works
 * when extending other ES5-style classes, and does not propagate `new.target`.
 *
 * This shim allows the native HTMLElement constructor to work by generating and
 * registering a stand-in class instead of the users custom element class. This
 * stand-in class's constructor has an actual call to super().
 * `customElements.define()` and `customElements.get()` are both overridden to
 * hide this stand-in class from users.
 *
 * In order to create instance of the user-defined class, rather than the stand
 * in, the stand-in's constructor swizzles its instances prototype and invokes
 * the user-defined constructor. When the user-defined constructor is called
 * directly it creates an instance of the stand-in class to get a real extension
 * of HTMLElement and returns that.
 *
 * There are two important constructors: A patched HTMLElement constructor, and
 * the StandInElement constructor. They both will be called to create an element
 * but which is called first depends on whether the browser creates the element
 * or the user-defined constructor is called directly. The variables
 * `browserConstruction` and `userConstruction` control the flow between the
 * two constructors.
 *
 * This shim should be better than forcing the polyfill because:
 *   1. It's smaller
 *   2. All reaction timings are the same as native (mostly synchronous)
 *   3. All reaction triggering DOM operations are automatically supported
 *
 * There are some restrictions and requirements on ES5 constructors:
 *   1. All constructors in a inheritance hierarchy must be ES5-style, so that
 *      they can be called with Function.call(). This effectively means that the
 *      whole application must be compiled to ES5.
 *   2. Constructors must return the value of the emulated super() call. Like
 *      `return SuperClass.call(this)`
 *   3. The `this` reference should not be used before the emulated super() call
 *      just like `this` is illegal to use before super() in ES6.
 *   4. Constructors should not create other custom elements before the emulated
 *      super() call. This is the same restriction as with native custom
 *      elements.
 *
 *  Compiling valid class-based custom elements to ES5 will satisfy these
 *  requirements with the latest version of popular transpilers.
 */
(() => {
  'use strict';

  // Do nothing if `customElements` does not exist.
  if (!window.customElements) return;

  const NativeHTMLElement = window.HTMLElement;
  const nativeDefine = window.customElements.define;
  const nativeGet = window.customElements.get;

  /**
   * Map of user-provided constructors to tag names.
   *
   * @type {Map<Function, string>}
   */
  const tagnameByConstructor = new Map();

  /**
   * Map of tag names to user-provided constructors.
   *
   * @type {Map<string, Function>}
   */
  const constructorByTagname = new Map();


  /**
   * Whether the constructors are being called by a browser process, ie parsing
   * or createElement.
   */
  let browserConstruction = false;

  /**
   * Whether the constructors are being called by a user-space process, ie
   * calling an element constructor.
   */
  let userConstruction = false;

  window.HTMLElement = function() {
    if (!browserConstruction) {
      const tagname = tagnameByConstructor.get(this.constructor);
      const fakeClass = nativeGet.call(window.customElements, tagname);

      // Make sure that the fake constructor doesn't call back to this constructor
      userConstruction = true;
      const instance = new (fakeClass)();
      return instance;
    }
    // Else do nothing. This will be reached by ES5-style classes doing
    // HTMLElement.call() during initialization
    browserConstruction = false;
  };
  // By setting the patched HTMLElement's prototype property to the native
  // HTMLElement's prototype we make sure that:
  //     document.createElement('a') instanceof HTMLElement
  // works because instanceof uses HTMLElement.prototype, which is on the
  // ptototype chain of built-in elements.
  window.HTMLElement.prototype = NativeHTMLElement.prototype;

  const define = (tagname, elementClass) => {
    const elementProto = elementClass.prototype;
    const StandInElement = class extends NativeHTMLElement {
      constructor() {
        // Call the native HTMLElement constructor, this gives us the
        // under-construction instance as `this`:
        super();

        // The prototype will be wrong up because the browser used our fake
        // class, so fix it:
        Object.setPrototypeOf(this, elementProto);

        if (!userConstruction) {
          // Make sure that user-defined constructor bottom's out to a do-nothing
          // HTMLElement() call
          browserConstruction = true;
          // Call the user-defined constructor on our instance:
          elementClass.call(this);
        }
        userConstruction = false;
      }
    };
    const standInProto = StandInElement.prototype;
    StandInElement.observedAttributes = elementClass.observedAttributes;
    standInProto.connectedCallback = elementProto.connectedCallback;
    standInProto.disconnectedCallback = elementProto.disconnectedCallback;
    standInProto.attributeChangedCallback = elementProto.attributeChangedCallback;
    standInProto.adoptedCallback = elementProto.adoptedCallback;

    tagnameByConstructor.set(elementClass, tagname);
    constructorByTagname.set(tagname, elementClass);
    nativeDefine.call(window.customElements, tagname, StandInElement);
  };

  const get = (tagname) => constructorByTagname.get(tagname);

  // Workaround for Safari bug where patching customElements can be lost, likely
  // due to native wrapper garbage collection issue
  Object.defineProperty(window, 'customElements',
    {value: window.customElements, configurable: true, writable: true});
  Object.defineProperty(window.customElements, 'define',
    {value: define, configurable: true, writable: true});
  Object.defineProperty(window.customElements, 'get',
    {value: get, configurable: true, writable: true});

})();

/* interact.js v1.2.9 | https://raw.github.com/taye/interact.js/master/LICENSE */var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(m,J,r){m!=Array.prototype&&m!=Object.prototype&&(m[J]=r.value)};$jscomp.getGlobal=function(m){return"undefined"!=typeof window&&window===m?m:"undefined"!=typeof global&&null!=global?global:m};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.polyfill=function(m,J,r,M){if(J){r=$jscomp.global;m=m.split(".");for(M=0;M<m.length-1;M++){var B=m[M];B in r||(r[B]={});r=r[B]}m=m[m.length-1];M=r[m];J=J(M);J!=M&&null!=J&&$jscomp.defineProperty(r,m,{configurable:!0,writable:!0,value:J})}};
$jscomp.polyfill("Math.hypot",function(m){return m?m:function(m,r,M){m=Number(m);r=Number(r);var B,u=Math.max(Math.abs(m),Math.abs(r));for(B=2;B<arguments.length;B++)u=Math.max(u,Math.abs(arguments[B]));if(1E100<u||1E-100>u){m/=u;r/=u;var x=m*m+r*r;for(B=2;B<arguments.length;B++){var F=Number(arguments[B])/u;x+=F*F}return Math.sqrt(x)*u}x=m*m+r*r;for(B=2;B<arguments.length;B++)F=Number(arguments[B]),x+=F*F;return Math.sqrt(x)}},"es6-impl","es3");
(function(m){function J(){}function r(a){if(!a||"object"!==typeof a)return!1;var b=Y(a)||v;return/object|function/.test(typeof b.Element)?a instanceof b.Element:1===a.nodeType&&"string"===typeof a.nodeName}function M(a){return a===v||!(!a||!a.Window)&&a instanceof a.Window}function B(a){return u(a)&&!0&&x(a.splice)}function u(a){return!!a&&"object"===typeof a}function x(a){return"function"===typeof a}function F(a){return"number"===typeof a}function K(a){return"boolean"===typeof a}function P(a){return"string"===
typeof a}function fa(a){if(!P(a))return!1;S.querySelector(a);return!0}function C(a,b){for(var c in b)a[c]=b[c];return a}function qa(a,b){for(var c in b){var d=!1,e;for(e in za)if(0===c.indexOf(e)&&za[e].test(c)){d=!0;break}d||(a[c]=b[c])}return a}function ra(a,b){a.page=a.page||{};a.page.x=b.page.x;a.page.y=b.page.y;a.client=a.client||{};a.client.x=b.client.x;a.client.y=b.client.y;a.timeStamp=b.timeStamp}function Qa(a,b,c){a.page.x=c.page.x-b.page.x;a.page.y=c.page.y-b.page.y;a.client.x=c.client.x-
b.client.x;a.client.y=c.client.y-b.client.y;a.timeStamp=(new Date).getTime()-b.timeStamp;b=Math.max(a.timeStamp/1E3,.001);a.page.speed=ga(a.page.x,a.page.y)/b;a.page.vx=a.page.x/b;a.page.vy=a.page.y/b;a.client.speed=ga(a.client.x,a.page.y)/b;a.client.vx=a.client.x/b;a.client.vy=a.client.y/b}function Ra(a){return a instanceof v.Event||ha&&v.Touch&&a instanceof v.Touch}function sa(a,b,c){c=c||{};a=a||"page";c.x=b[a+"X"];c.y=b[a+"Y"];return c}function Aa(a,b){b=b||{};Sa&&Ra(a)?(sa("screen",a,b),b.x+=
v.scrollX,b.y+=v.scrollY):sa("page",a,b);return b}function Ta(a,b){b=b||{};Sa&&Ra(a)?sa("screen",a,b):sa("client",a,b);return b}function Q(a){return F(a.pointerId)?a.pointerId:a.identifier}function Ba(a){return a instanceof kb?a.correspondingUseElement:a}function Y(a){if(M(a))return a;a=a.ownerDocument||a;return a.defaultView||a.parentWindow||v}function Ca(a){return(a=a instanceof Ua?a.getBoundingClientRect():a.getClientRects()[0])&&{left:a.left,right:a.right,top:a.top,bottom:a.bottom,width:a.width||
a.right-a.left,height:a.height||a.bottom-a.top}}function ta(a){var b=Ca(a);if(!lb&&b){var c=(c=Y(a))||v;a=c.scrollX||c.document.documentElement.scrollLeft;c=c.scrollY||c.document.documentElement.scrollTop;b.left+=a;b.right+=a;b.top+=c;b.bottom+=c}return b}function Da(a){var b=[];B(a)?(b[0]=a[0],b[1]=a[1]):"touchend"===a.type?1===a.touches.length?(b[0]=a.touches[0],b[1]=a.changedTouches[0]):0===a.touches.length&&(b[0]=a.changedTouches[0],b[1]=a.changedTouches[1]):(b[0]=a.touches[0],b[1]=a.touches[1]);
return b}function Va(a){for(var b={pageX:0,pageY:0,clientX:0,clientY:0,screenX:0,screenY:0},c,d=0;d<a.length;d++)for(c in b)b[c]+=a[d][c];for(c in b)b[c]/=a.length;return b}function Ea(a){if(a.length||a.touches&&1<a.touches.length){a=Da(a);var b=Math.min(a[0].pageX,a[1].pageX),c=Math.min(a[0].pageY,a[1].pageY);return{x:b,y:c,left:b,top:c,width:Math.max(a[0].pageX,a[1].pageX)-b,height:Math.max(a[0].pageY,a[1].pageY)-c}}}function Fa(a,b){b=b||H.deltaSource;var c=b+"X";b+="Y";a=Da(a);return ga(a[0][c]-
a[1][c],a[0][b]-a[1][b])}function Ga(a,b,c){c=c||H.deltaSource;var d=c+"X";c+="Y";a=Da(a);d=180*Math.atan((a[0][c]-a[1][c])/(a[0][d]-a[1][d]))/Math.PI;F(b)&&(b=(d-b)%360,315<b?d-=360+d/360|0:135<b?d-=180+d/360|0:-315>b?d+=360+d/360|0:-135>b&&(d+=180+d/360|0));return d}function na(a,b){var c=a?a.options.origin:H.origin;"parent"===c?c=N(b):"self"===c?c=a.getRect(b):fa(c)&&(c=Ha(b,c)||{x:0,y:0});x(c)&&(c=c(a&&b));r(c)&&(c=ta(c));c.x="x"in c?c.x:c.left;c.y="y"in c?c.y:c.top;return c}function Wa(a,b,c,
d){var e=1-a;return e*e*b+2*e*a*c+a*a*d}function ba(a,b){for(;b;){if(b===a)return!0;b=b.parentNode}return!1}function Ha(a,b){for(a=N(a);r(a);){if(T(a,b))return a;a=N(a)}return null}function N(a){if((a=a.parentNode)&&a instanceof Xa)for(;(a=a.host)&&a&&a instanceof Xa;);return a}function ua(a,b){return a._context===b.ownerDocument||ba(a._context,b)}function ca(a,b,c){return(a=a.options.ignoreFrom)&&r(c)?P(a)?Ia(c,a,b):r(a)?ba(a,c):!1:!1}function da(a,b,c){return(a=a.options.allowFrom)?r(c)?P(a)?Ia(c,
a,b):r(a)?ba(a,c):!1:!1:!0}function Ya(a,b){if(!b)return!1;b=b.options.drag.axis;return"xy"===a||"xy"===b||b===a}function Ja(a,b){a=a.options;/^resize/.test(b)&&(b="resize");return a[b].snap&&a[b].snap.enabled}function Ka(a,b){a=a.options;/^resize/.test(b)&&(b="resize");return a[b].restrict&&a[b].restrict.enabled}function ia(a,b,c){for(var d=a.options,e=d[c.name].max,d=d[c.name].maxPerElement,k=0,h=0,f=0,q=0,G=w.length;q<G;q++){var n=w[q],t=n.prepared.name;if(n.interacting()&&(k++,k>=va||n.target===
a&&(h+=t===c.name|0,h>=e||n.element===b&&(f++,t!==c.name||f>=d))))return!1}return 0<va}function wa(){this.prevDropElement=this.prevDropTarget=this.dropElement=this.dropTarget=this.element=this.target=null;this.prepared={name:null,axis:null,edges:null};this.matches=[];this.matchElements=[];this.inertiaStatus={active:!1,smoothEnd:!1,ending:!1,startEvent:null,upCoords:{},xe:0,ye:0,sx:0,sy:0,t0:0,vx0:0,vys:0,duration:0,resumeDx:0,resumeDy:0,lambda_v0:0,one_ve_v0:0,i:null};if(x(Function.prototype.bind))this.boundInertiaFrame=
this.inertiaFrame.bind(this),this.boundSmoothEndFrame=this.smoothEndFrame.bind(this);else{var a=this;this.boundInertiaFrame=function(){return a.inertiaFrame()};this.boundSmoothEndFrame=function(){return a.smoothEndFrame()}}this.activeDrops={dropzones:[],elements:[],rects:[]};this.pointers=[];this.pointerIds=[];this.downTargets=[];this.downTimes=[];this.holdTimers=[];this.prevCoords={page:{x:0,y:0},client:{x:0,y:0},timeStamp:0};this.curCoords={page:{x:0,y:0},client:{x:0,y:0},timeStamp:0};this.startCoords=
{page:{x:0,y:0},client:{x:0,y:0},timeStamp:0};this.pointerDelta={page:{x:0,y:0,vx:0,vy:0,speed:0},client:{x:0,y:0,vx:0,vy:0,speed:0},timeStamp:0};this.downEvent=null;this.downPointer={};this.prevEvent=this._curEventTarget=this._eventTarget=null;this.tapTime=0;this.prevTap=null;this.startOffset={left:0,right:0,top:0,bottom:0};this.restrictOffset={left:0,right:0,top:0,bottom:0};this.snapOffsets=[];this.gesture={start:{x:0,y:0},startDistance:0,prevDistance:0,distance:0,scale:1,startAngle:0,prevAngle:0};
this.snapStatus={x:0,y:0,dx:0,dy:0,realX:0,realY:0,snappedX:0,snappedY:0,targets:[],locked:!1,changed:!1};this.restrictStatus={dx:0,dy:0,restrictedX:0,restrictedY:0,snap:null,restricted:!1,changed:!1};this.restrictStatus.snap=this.snapStatus;this.resizing=this.dragging=this.gesturing=this.pointerWasMoved=this.pointerIsDown=!1;this.resizeAxes="xy";this.mouse=!1;w.push(this)}function Za(a,b,c){var d=w.length,e=/mouse/i.test(a.pointerType||b)||4===a.pointerType,k=Q(a);if(/down|start/i.test(b))for(a=
0;a<d;a++){var h=w[a];var f=c;if(h.inertiaStatus.active&&h.target.options[h.prepared.name].inertia.allowResume&&h.mouse===e)for(;f;){if(f===h.element)return h;f=N(f)}}if(e||!ha&&!U){for(a=0;a<d;a++)if(w[a].mouse&&!w[a].inertiaStatus.active)return w[a];for(a=0;a<d;a++)if(w[a].mouse&&(!/down/.test(b)||!w[a].inertiaStatus.active))return h;h=new wa;h.mouse=!0;return h}for(a=0;a<d;a++)if(-1!==y(w[a].pointerIds,k))return w[a];if(/up|end|out/i.test(b))return null;for(a=0;a<d;a++)if(h=w[a],!(h.prepared.name&&
!h.target.options.gesture.enabled||h.interacting()||!e&&h.mouse))return h;return new wa}function $a(a){return function(b){var c,d=Ba(b.path?b.path[0]:b.target),e=Ba(b.currentTarget),k;if(ha&&/touch/.test(b.type))for(ab=(new Date).getTime(),k=0;k<b.changedTouches.length;k++){var h=b.changedTouches[k];if(c=Za(h,b.type,d))c._updateEventTargets(d,e),c[a](h,b,d,e)}else{if(!U&&/mouse/.test(b.type)){for(k=0;k<w.length;k++)if(!w[k].mouse&&w[k].pointerIsDown)return;if(500>(new Date).getTime()-ab)return}if(c=
Za(b,b.type,d))c._updateEventTargets(d,e),c[a](b,b,d,e)}}}function I(a,b,c,d,e,k){var h=a.target,f=a.snapStatus,q=a.restrictStatus,G=a.pointers,n=(h&&h.options||H).deltaSource,t=n+"X",z=n+"Y",p=h?h.options:H,m=na(h,e),r="start"===d,l="end"===d;var A=r?a.startCoords:a.curCoords;e=e||a.element;var g=C({},A.page);A=C({},A.client);g.x-=m.x;g.y-=m.y;A.x-=m.x;A.y-=m.y;var ja=p[c].snap&&p[c].snap.relativePoints;!Ja(h,c)||r&&ja&&ja.length||(this.snap={range:f.range,locked:f.locked,x:f.snappedX,y:f.snappedY,
realX:f.realX,realY:f.realY,dx:f.dx,dy:f.dy},f.locked&&(g.x+=f.dx,g.y+=f.dy,A.x+=f.dx,A.y+=f.dy));!Ka(h,c)||r&&p[c].restrict.elementRect||!q.restricted||(g.x+=q.dx,g.y+=q.dy,A.x+=q.dx,A.y+=q.dy,this.restrict={dx:q.dx,dy:q.dy});this.pageX=g.x;this.pageY=g.y;this.clientX=A.x;this.clientY=A.y;this.x0=a.startCoords.page.x-m.x;this.y0=a.startCoords.page.y-m.y;this.clientX0=a.startCoords.client.x-m.x;this.clientY0=a.startCoords.client.y-m.y;this.ctrlKey=b.ctrlKey;this.altKey=b.altKey;this.shiftKey=b.shiftKey;
this.metaKey=b.metaKey;this.button=b.button;this.buttons=b.buttons;this.target=e;this.t0=a.downTimes[0];this.type=c+(d||"");this.interaction=a;this.interactable=h;e=a.inertiaStatus;e.active&&(this.detail="inertia");k&&(this.relatedTarget=k);l?"client"===n?(this.dx=A.x-a.startCoords.client.x,this.dy=A.y-a.startCoords.client.y):(this.dx=g.x-a.startCoords.page.x,this.dy=g.y-a.startCoords.page.y):r?this.dy=this.dx=0:"inertiastart"===d?(this.dx=a.prevEvent.dx,this.dy=a.prevEvent.dy):"client"===n?(this.dx=
A.x-a.prevEvent.clientX,this.dy=A.y-a.prevEvent.clientY):(this.dx=g.x-a.prevEvent.pageX,this.dy=g.y-a.prevEvent.pageY);a.prevEvent&&"inertia"===a.prevEvent.detail&&!e.active&&p[c].inertia&&p[c].inertia.zeroResumeDelta&&(e.resumeDx+=this.dx,e.resumeDy+=this.dy,this.dx=this.dy=0);"resize"===c&&a.resizeAxes?p.resize.square?("y"===a.resizeAxes?this.dx=this.dy:this.dy=this.dx,this.axes="xy"):(this.axes=a.resizeAxes,"x"===a.resizeAxes?this.dy=0:"y"===a.resizeAxes&&(this.dx=0)):"gesture"===c&&(this.touches=
[G[0],G[1]],r?(this.distance=Fa(G,n),this.box=Ea(G),this.scale=1,this.ds=0,this.angle=Ga(G,void 0,n),this.da=0):l||b instanceof I?(this.distance=a.prevEvent.distance,this.box=a.prevEvent.box,this.scale=a.prevEvent.scale,this.ds=this.scale-1,this.angle=a.prevEvent.angle,this.da=this.angle-a.gesture.startAngle):(this.distance=Fa(G,n),this.box=Ea(G),this.scale=this.distance/a.gesture.startDistance,this.angle=Ga(G,a.gesture.prevAngle,n),this.ds=this.scale-a.gesture.prevScale,this.da=this.angle-a.gesture.prevAngle));
r?(this.timeStamp=a.downTimes[0],this.velocityY=this.velocityX=this.speed=this.duration=this.dt=0):"inertiastart"===d?(this.timeStamp=a.prevEvent.timeStamp,this.dt=a.prevEvent.dt,this.duration=a.prevEvent.duration,this.speed=a.prevEvent.speed,this.velocityX=a.prevEvent.velocityX,this.velocityY=a.prevEvent.velocityY):(this.timeStamp=(new Date).getTime(),this.dt=this.timeStamp-a.prevEvent.timeStamp,this.duration=this.timeStamp-a.downTimes[0],b instanceof I?(b=this[t]-a.prevEvent[t],z=this[z]-a.prevEvent[z],
c=this.dt/1E3,this.speed=ga(b,z)/c,this.velocityX=b/c,this.velocityY=z/c):(this.speed=a.pointerDelta[n].speed,this.velocityX=a.pointerDelta[n].vx,this.velocityY=a.pointerDelta[n].vy));(l||"inertiastart"===d)&&600<a.prevEvent.speed&&150>this.timeStamp-a.prevEvent.timeStamp&&(d=180*Math.atan2(a.prevEvent.velocityY,a.prevEvent.velocityX)/Math.PI,0>d&&(d+=360),l=112.5<=d&&247.5>d,z=202.5<=d&&337.5>d,this.swipe={up:z,down:!z&&22.5<=d&&157.5>d,left:l,right:!l&&(292.5<=d||67.5>d),angle:d,speed:a.prevEvent.speed,
velocity:{x:a.prevEvent.velocityX,y:a.prevEvent.velocityY}})}function bb(){this.originalEvent.preventDefault()}function cb(a){var b="";"drag"===a.name&&(b=xa.drag);if("resize"===a.name)if(a.axis)b=xa[a.name+a.axis];else if(a.edges){for(var b="resize",c=["top","bottom","left","right"],d=0;4>d;d++)a.edges[c[d]]&&(b+=c[d]);b=xa[b]}return b}function db(a,b,c){var d=this.getRect(c),e=!1,k=null,h=C({},b.curCoords.page);a=this.options;if(!d)return null;if(V.resize&&a.resize.enabled){e=a.resize;var f={left:!1,
right:!1,top:!1,bottom:!1};if(u(e.edges)){for(var q in f){var G=f,n=q;a:{var t=q;var z=e.edges[q],g=h,p=b._eventTarget,m=c,l=d,A=e.margin||oa;if(z){if(!0===z){var x=F(l.width)?l.width:l.right-l.left,ja=F(l.height)?l.height:l.bottom-l.top;0>x&&("left"===t?t="right":"right"===t&&(t="left"));0>ja&&("top"===t?t="bottom":"bottom"===t&&(t="top"));if("left"===t){t=g.x<(0<=x?l.left:l.right)+A;break a}if("top"===t){t=g.y<(0<=ja?l.top:l.bottom)+A;break a}if("right"===t){t=g.x>(0<=x?l.right:l.left)-A;break a}if("bottom"===
t){t=g.y>(0<=ja?l.bottom:l.top)-A;break a}}t=r(p)?r(z)?z===p:Ia(p,z,m):!1}else t=!1}G[n]=t}f.left=f.left&&!f.right;f.top=f.top&&!f.bottom;e=f.left||f.right||f.top||f.bottom}else c="y"!==a.resize.axis&&h.x>d.right-oa,d="x"!==a.resize.axis&&h.y>d.bottom-oa,e=c||d,k=(c?"x":"")+(d?"y":"")}a=e?"resize":V.drag&&a.drag.enabled?"drag":null;V.gesture&&2<=b.pointerIds.length&&!b.dragging&&!b.resizing&&(a="gesture");return a?{name:a,axis:k,edges:f}:null}function Z(a,b){if(!u(a))return null;var c=a.name;b=b.options;
return("resize"===c&&b.resize.enabled||"drag"===c&&b.drag.enabled||"gesture"===c&&b.gesture.enabled)&&V[c]?a:null}function pa(a,b){var c={},d=R[a.type],e=Ba(a.path?a.path[0]:a.target),k=e;b=b?!0:!1;for(var h in a)c[h]=a[h];c.originalEvent=a;for(c.preventDefault=bb;r(k);){for(a=0;a<d.selectors.length;a++)if(h=d.contexts[a],T(k,d.selectors[a])&&ba(h,e)&&ba(h,k)){h=d.listeners[a];c.currentTarget=k;for(var f=0;f<h.length;f++)if(h[f][1]===b)h[f][0](c)}k=N(k)}}function ya(a){return pa.call(this,a,!0)}function p(a,
b){return D.get(a,b)||new E(a,b)}function E(a,b){this._element=a;this._iEvents=this._iEvents||{};if(fa(a)){this.selector=a;var c=(a=b&&b.context)?Y(a):v;a&&(c.Node?a instanceof c.Node:r(a)||a===c.document)&&(this._context=a)}else c=Y(a),r(a,c)&&(U?(n.add(this._element,L.down,l.pointerDown),n.add(this._element,L.move,l.pointerHover)):(n.add(this._element,"mousedown",l.pointerDown),n.add(this._element,"mousemove",l.pointerHover),n.add(this._element,"touchstart",l.pointerDown),n.add(this._element,"touchmove",
l.pointerHover)));this._doc=c.document;-1===y(ka,this._doc)&&eb(this._doc);D.push(this);this.set(b)}function O(a,b){var c=!1;return function(){c||(v.console.warn(b),c=!0);return a.apply(this,arguments)}}function fb(a){for(var b=0;b<w.length;b++)w[b].pointerEnd(a,a)}function eb(a){if(-1===y(ka,a)){var b=a.defaultView||a.parentWindow,c;for(c in R)n.add(a,c,pa),n.add(a,c,ya,!0);U?(L=gb===b.MSPointerEvent?{up:"MSPointerUp",down:"MSPointerDown",over:"mouseover",out:"mouseout",move:"MSPointerMove",cancel:"MSPointerCancel"}:
{up:"pointerup",down:"pointerdown",over:"pointerover",out:"pointerout",move:"pointermove",cancel:"pointercancel"},n.add(a,L.down,l.selectorDown),n.add(a,L.move,l.pointerMove),n.add(a,L.over,l.pointerOver),n.add(a,L.out,l.pointerOut),n.add(a,L.up,l.pointerUp),n.add(a,L.cancel,l.pointerCancel),n.add(a,L.move,l.autoScrollMove)):(n.add(a,"mousedown",l.selectorDown),n.add(a,"mousemove",l.pointerMove),n.add(a,"mouseup",l.pointerUp),n.add(a,"mouseover",l.pointerOver),n.add(a,"mouseout",l.pointerOut),n.add(a,
"touchstart",l.selectorDown),n.add(a,"touchmove",l.pointerMove),n.add(a,"touchend",l.pointerUp),n.add(a,"touchcancel",l.pointerCancel),n.add(a,"mousemove",l.autoScrollMove),n.add(a,"touchmove",l.autoScrollMove));n.add(b,"blur",fb);try{if(b.frameElement){var d=b.frameElement.ownerDocument,e=d.defaultView;n.add(d,"mouseup",l.pointerEnd);n.add(d,"touchend",l.pointerEnd);n.add(d,"touchcancel",l.pointerEnd);n.add(d,"pointerup",l.pointerEnd);n.add(d,"MSPointerUp",l.pointerEnd);n.add(e,"blur",fb)}}catch(k){p.windowParentError=
k}n.add(a,"dragstart",function(a){for(var b=0;b<w.length;b++){var c=w[b];if(c.element&&(c.element===a.target||ba(c.element,a.target))){c.checkAndPreventDefault(a,c.target,c.element);break}}});n.useAttachEvent&&(n.add(a,"selectstart",function(a){var b=w[0];b.currentAction()&&b.checkAndPreventDefault(a)}),n.add(a,"dblclick",$a("ie8Dblclick")));ka.push(a)}}function y(a,b){for(var c=0,d=a.length;c<d;c++)if(a[c]===b)return c;return-1}function T(a,b,c){if(la)return la(a,b,c);v!==m&&(b=b.replace(/\/deep\//g,
" "));return a[La](b)}function Ia(a,b,c){for(;r(a);){if(T(a,b))return!0;a=N(a);if(a===c)return T(a,b)}return!1}if(m){var v=function(){var a=m.document.createTextNode("");return a.ownerDocument!==m.document&&"function"===typeof m.wrap&&m.wrap(a)===a?m.wrap(m):m}(),S=v.document,Xa=v.DocumentFragment||J,Ua=v.SVGElement||J,mb=v.SVGSVGElement||J,kb=v.SVGElementInstance||J,nb=v.HTMLElement||v.Element,gb=v.PointerEvent||v.MSPointerEvent,L,ga=Math.hypot||function(a,b){return Math.sqrt(a*a+b*b)},ma={},ka=
[],D=[],w=[],Ma=!1,R={},H={base:{accept:null,actionChecker:null,styleCursor:!0,preventDefault:"auto",origin:{x:0,y:0},deltaSource:"page",allowFrom:null,ignoreFrom:null,_context:S,dropChecker:null},drag:{enabled:!1,manualStart:!0,max:Infinity,maxPerElement:1,snap:null,restrict:null,inertia:null,autoScroll:null,axis:"xy"},drop:{enabled:!1,accept:null,overlap:"pointer"},resize:{enabled:!1,manualStart:!1,max:Infinity,maxPerElement:1,snap:null,restrict:null,inertia:null,autoScroll:null,square:!1,preserveAspectRatio:!1,
axis:"xy",margin:NaN,edges:null,invert:"none"},gesture:{manualStart:!1,enabled:!1,max:Infinity,maxPerElement:1,restrict:null},perAction:{manualStart:!1,max:Infinity,maxPerElement:1,snap:{enabled:!1,endOnly:!1,range:Infinity,targets:null,offsets:null,relativePoints:null},restrict:{enabled:!1,endOnly:!1},autoScroll:{enabled:!1,container:null,margin:60,speed:300},inertia:{enabled:!1,resistance:10,minSpeed:100,endSpeed:10,allowResume:!0,zeroResumeDelta:!0,smoothEndDuration:300}},_holdDuration:600},g=
{interaction:null,i:null,x:0,y:0,scroll:function(){var a=g.interaction.target.options[g.interaction.prepared.name].autoScroll,b=a.container||Y(g.interaction.element),c=(new Date).getTime(),d=(c-g.prevTimeX)/1E3,e=(c-g.prevTimeY)/1E3;if(a.velocity){var k=a.velocity.x;a=a.velocity.y}else k=a=a.speed;d*=k;e*=a;if(1<=d||1<=e)M(b)?b.scrollBy(g.x*d,g.y*e):b&&(b.scrollLeft+=g.x*d,b.scrollTop+=g.y*e),1<=d&&(g.prevTimeX=c),1<=e&&(g.prevTimeY=c);g.isScrolling&&(aa(g.i),g.i=W(g.scroll))},isScrolling:!1,prevTimeX:0,
prevTimeY:0,start:function(a){g.isScrolling=!0;aa(g.i);g.interaction=a;g.prevTimeX=(new Date).getTime();g.prevTimeY=(new Date).getTime();g.i=W(g.scroll)},stop:function(){g.isScrolling=!1;aa(g.i)}},ha="ontouchstart"in v||v.DocumentTouch&&S instanceof v.DocumentTouch,U=gb&&!/Chrome/.test(navigator.userAgent),oa=ha||U?20:10,Na=1,ab=0,va=Infinity,xa=S.all&&!v.atob?{drag:"move",resizex:"e-resize",resizey:"s-resize",resizexy:"se-resize",resizetop:"n-resize",resizeleft:"w-resize",resizebottom:"s-resize",
resizeright:"e-resize",resizetopleft:"se-resize",resizebottomright:"se-resize",resizetopright:"ne-resize",resizebottomleft:"ne-resize",gesture:""}:{drag:"move",resizex:"ew-resize",resizey:"ns-resize",resizexy:"nwse-resize",resizetop:"ns-resize",resizeleft:"ew-resize",resizebottom:"ns-resize",resizeright:"ew-resize",resizetopleft:"nwse-resize",resizebottomright:"nwse-resize",resizetopright:"nesw-resize",resizebottomleft:"nesw-resize",gesture:""},V={drag:!0,resize:!0,gesture:!0},hb="onmousewheel"in
S?"mousewheel":"wheel",ea="dragstart dragmove draginertiastart dragend dragenter dragleave dropactivate dropdeactivate dropmove drop resizestart resizemove resizeinertiastart resizeend gesturestart gesturemove gestureinertiastart gestureend down move up cancel tap doubletap hold".split(" "),X={},Sa="Opera"==navigator.appName&&ha&&navigator.userAgent.match("Presto"),lb=/iP(hone|od|ad)/.test(navigator.platform)&&/OS 7[^\d]/.test(navigator.appVersion),La="matches"in Element.prototype?"matches":"webkitMatchesSelector"in
Element.prototype?"webkitMatchesSelector":"mozMatchesSelector"in Element.prototype?"mozMatchesSelector":"oMatchesSelector"in Element.prototype?"oMatchesSelector":"msMatchesSelector",la,W=m.requestAnimationFrame,aa=m.cancelAnimationFrame,n=function(){function a(b,c,d,k){var t,l=y(q,b),g=G[l],p=d;if(g&&g.events){if(e){var z=n[l];var m=y(z.supplied,d);p=z.wrapped[m]}if("all"===c)for(c in g.events)g.events.hasOwnProperty(c)&&a(b,c,"all");else{if(g.events[c]){var r=g.events[c].length;if("all"===d){for(t=
0;t<r;t++)a(b,c,g.events[c][t],!!k);return}for(t=0;t<r;t++)if(g.events[c][t]===d){b[h](f+c,p,k||!1);g.events[c].splice(t,1);e&&z&&(z.useCount[m]--,0===z.useCount[m]&&(z.supplied.splice(m,1),z.wrapped.splice(m,1),z.useCount.splice(m,1)));break}g.events[c]&&0===g.events[c].length&&(g.events[c]=null,g.typeCount--)}g.typeCount||(G.splice(l,1),q.splice(l,1),n.splice(l,1))}}}function b(){this.returnValue=!1}function c(){this.cancelBubble=!0}function d(){this.immediatePropagationStopped=this.cancelBubble=
!0}var e="attachEvent"in v&&!("addEventListener"in v),k=e?"attachEvent":"addEventListener",h=e?"detachEvent":"removeEventListener",f=e?"on":"",q=[],G=[],n=[];return{add:function(a,h,g,l){var t=y(q,a),m=G[t];m||(m={events:{},typeCount:0},t=q.push(a)-1,G.push(m),n.push(e?{supplied:[],wrapped:[],useCount:[]}:null));m.events[h]||(m.events[h]=[],m.typeCount++);if(-1===y(m.events[h],g)){if(e){var t=n[t],p=y(t.supplied,g),z=t.wrapped[p]||function(e){e.immediatePropagationStopped||(e.target=e.srcElement,
e.currentTarget=a,e.preventDefault=e.preventDefault||b,e.stopPropagation=e.stopPropagation||c,e.stopImmediatePropagation=e.stopImmediatePropagation||d,/mouse|click/.test(e.type)&&(e.pageX=e.clientX+Y(a).document.documentElement.scrollLeft,e.pageY=e.clientY+Y(a).document.documentElement.scrollTop),g(e))};l=a[k](f+h,z,!!l);-1===p?(t.supplied.push(g),t.wrapped.push(z),t.useCount.push(1)):t.useCount[p]++}else l=a[k](h,g,l||!1);m.events[h].push(g);return l}},remove:a,useAttachEvent:e,_elements:q,_targets:G,
_attachedListeners:n}}(),za={webkit:/(Movement[XY]|Radius[XY]|RotationAngle|Force)$/};wa.prototype={getPageXY:function(a,b){return Aa(a,b,this)},getClientXY:function(a,b){return Ta(a,b,this)},setEventXY:function(a,b){b=1<b.length?Va(b):b[0];Aa(b,ma,this);a.page.x=ma.x;a.page.y=ma.y;Ta(b,ma,this);a.client.x=ma.x;a.client.y=ma.y;a.timeStamp=(new Date).getTime()},pointerOver:function(a,b,c){function d(a,b){a&&r(c)&&ua(a,c)&&!ca(a,c,c)&&da(a,c,c)&&T(c,b)&&(e.push(a),k.push(c))}if(!this.prepared.name&&
this.mouse){var e=[],k=[],h=this.element;this.addPointer(a);!this.target||!ca(this.target,this.element,c)&&da(this.target,this.element,c)||(this.element=this.target=null,this.matches=[],this.matchElements=[]);var f=D.get(c),q=f&&!ca(f,c,c)&&da(f,c,c)&&Z(f.getAction(a,b,this,c),f);q&&!ia(f,c,q)&&(q=null);q?(this.target=f,this.element=c,this.matches=[],this.matchElements=[]):(D.forEachSelector(d),this.validateSelector(a,b,e,k)?(this.matches=e,this.matchElements=k,this.pointerHover(a,b,this.matches,
this.matchElements),n.add(c,U?L.move:"mousemove",l.pointerHover)):this.target&&(ba(h,c)?(this.pointerHover(a,b,this.matches,this.matchElements),n.add(this.element,U?L.move:"mousemove",l.pointerHover)):(this.element=this.target=null,this.matches=[],this.matchElements=[])))}},pointerHover:function(a,b,c,d,e,k){c=this.target;if(!this.prepared.name&&this.mouse){var h;this.setEventXY(this.curCoords,[a]);e?h=this.validateSelector(a,b,e,k):c&&(h=Z(c.getAction(this.pointers[0],b,this,this.element),this.target));
c&&c.options.styleCursor&&(c._doc.documentElement.style.cursor=h?cb(h):"")}else this.prepared.name&&this.checkAndPreventDefault(b,c,this.element)},pointerOut:function(a,b,c){this.prepared.name||(D.get(c)||n.remove(c,U?L.move:"mousemove",l.pointerHover),this.target&&this.target.options.styleCursor&&!this.interacting()&&(this.target._doc.documentElement.style.cursor=""))},selectorDown:function(a,b,c,d){function e(a,b,d){d=la?d.querySelectorAll(b):void 0;ua(a,f)&&!ca(a,f,c)&&da(a,f,c)&&T(f,b,d)&&(k.matches.push(a),
k.matchElements.push(f))}var k=this,h=n.useAttachEvent?C({},b):b,f=c,q=this.addPointer(a);this.holdTimers[q]=setTimeout(function(){k.pointerHold(n.useAttachEvent?h:a,h,c,d)},H._holdDuration);this.pointerIsDown=!0;if(this.inertiaStatus.active&&this.target.selector)for(;r(f);){if(f===this.element&&Z(this.target.getAction(a,b,this,this.element),this.target).name===this.prepared.name){aa(this.inertiaStatus.i);this.inertiaStatus.active=!1;this.collectEventTargets(a,b,c,"down");return}f=N(f)}if(!this.interacting()){this.setEventXY(this.curCoords,
[a]);for(this.downEvent=b;r(f)&&!g;){this.matches=[];this.matchElements=[];D.forEachSelector(e);var g=this.validateSelector(a,b,this.matches,this.matchElements);f=N(f)}if(g)return this.prepared.name=g.name,this.prepared.axis=g.axis,this.prepared.edges=g.edges,this.collectEventTargets(a,b,c,"down"),this.pointerDown(a,b,c,d,g);this.downTimes[q]=(new Date).getTime();this.downTargets[q]=c;qa(this.downPointer,a);ra(this.prevCoords,this.curCoords);this.pointerWasMoved=!1}this.collectEventTargets(a,b,c,
"down")},pointerDown:function(a,b,c,d,e){if(!e&&!this.inertiaStatus.active&&this.pointerWasMoved&&this.prepared.name)this.checkAndPreventDefault(b,this.target,this.element);else{this.pointerIsDown=!0;this.downEvent=b;var k=this.addPointer(a),h;if(1<this.pointerIds.length&&this.target._element===this.element){var f=Z(e||this.target.getAction(a,b,this,this.element),this.target);ia(this.target,this.element,f)&&(h=f);this.prepared.name=null}else this.prepared.name||(f=D.get(d))&&!ca(f,d,c)&&da(f,d,c)&&
(h=Z(e||f.getAction(a,b,this,d),f,c))&&ia(f,d,h)&&(this.target=f,this.element=d);var q=(f=this.target)&&f.options;!f||!e&&this.prepared.name?this.inertiaStatus.active&&d===this.element&&Z(f.getAction(a,b,this,this.element),f).name===this.prepared.name&&(aa(this.inertiaStatus.i),this.inertiaStatus.active=!1,this.checkAndPreventDefault(b,f,this.element)):(h=h||Z(e||f.getAction(a,b,this,d),f,this.element),this.setEventXY(this.startCoords,this.pointers),h&&(q.styleCursor&&(f._doc.documentElement.style.cursor=
cb(h)),this.resizeAxes="resize"===h.name?h.axis:null,"gesture"===h&&2>this.pointerIds.length&&(h=null),this.prepared.name=h.name,this.prepared.axis=h.axis,this.prepared.edges=h.edges,this.snapStatus.snappedX=this.snapStatus.snappedY=this.restrictStatus.restrictedX=this.restrictStatus.restrictedY=NaN,this.downTimes[k]=(new Date).getTime(),this.downTargets[k]=c,qa(this.downPointer,a),ra(this.prevCoords,this.startCoords),this.pointerWasMoved=!1,this.checkAndPreventDefault(b,f,this.element)))}},setModifications:function(a,
b){var c=this.target,d=!0,e=Ja(c,this.prepared.name)&&(!c.options[this.prepared.name].snap.endOnly||b);b=Ka(c,this.prepared.name)&&(!c.options[this.prepared.name].restrict.endOnly||b);e?this.setSnapping(a):this.snapStatus.locked=!1;b?this.setRestriction(a):this.restrictStatus.restricted=!1;e&&this.snapStatus.locked&&!this.snapStatus.changed?d=b&&this.restrictStatus.restricted&&this.restrictStatus.changed:b&&this.restrictStatus.restricted&&!this.restrictStatus.changed&&(d=!1);return d},setStartOffsets:function(a,
b,c){a=b.getRect(c);var d=na(b,c);c=b.options[this.prepared.name].snap;b=b.options[this.prepared.name].restrict;if(a){this.startOffset.left=this.startCoords.page.x-a.left;this.startOffset.top=this.startCoords.page.y-a.top;this.startOffset.right=a.right-this.startCoords.page.x;this.startOffset.bottom=a.bottom-this.startCoords.page.y;var e="width"in a?a.width:a.right-a.left;var k="height"in a?a.height:a.bottom-a.top}else this.startOffset.left=this.startOffset.top=this.startOffset.right=this.startOffset.bottom=
0;this.snapOffsets.splice(0);d=c&&"startCoords"===c.offset?{x:this.startCoords.page.x-d.x,y:this.startCoords.page.y-d.y}:c&&c.offset||{x:0,y:0};if(a&&c&&c.relativePoints&&c.relativePoints.length)for(var h=0;h<c.relativePoints.length;h++)this.snapOffsets.push({x:this.startOffset.left-e*c.relativePoints[h].x+d.x,y:this.startOffset.top-k*c.relativePoints[h].y+d.y});else this.snapOffsets.push(d);a&&b.elementRect?(this.restrictOffset.left=this.startOffset.left-e*b.elementRect.left,this.restrictOffset.top=
this.startOffset.top-k*b.elementRect.top,this.restrictOffset.right=this.startOffset.right-e*(1-b.elementRect.right),this.restrictOffset.bottom=this.startOffset.bottom-k*(1-b.elementRect.bottom)):this.restrictOffset.left=this.restrictOffset.top=this.restrictOffset.right=this.restrictOffset.bottom=0},start:function(a,b,c){this.interacting()||!this.pointerIsDown||this.pointerIds.length<("gesture"===a.name?2:1)||(-1===y(w,this)&&w.push(this),this.prepared.name||this.setEventXY(this.startCoords,this.pointers),
this.prepared.name=a.name,this.prepared.axis=a.axis,this.prepared.edges=a.edges,this.target=b,this.element=c,this.setStartOffsets(a.name,b,c),this.setModifications(this.startCoords.page),this.prevEvent=this[this.prepared.name+"Start"](this.downEvent))},pointerMove:function(a,b,c,d,e){if(this.inertiaStatus.active){d=this.inertiaStatus.upCoords.page;var k=this.inertiaStatus.upCoords.client;this.setEventXY(this.curCoords,[{pageX:d.x+this.inertiaStatus.sx,pageY:d.y+this.inertiaStatus.sy,clientX:k.x+this.inertiaStatus.sx,
clientY:k.y+this.inertiaStatus.sy}])}else this.recordPointer(a),this.setEventXY(this.curCoords,this.pointers);d=this.curCoords.page.x===this.prevCoords.page.x&&this.curCoords.page.y===this.prevCoords.page.y&&this.curCoords.client.x===this.prevCoords.client.x&&this.curCoords.client.y===this.prevCoords.client.y;var k=this.mouse?0:y(this.pointerIds,Q(a));if(this.pointerIsDown&&!this.pointerWasMoved){var h=this.curCoords.client.x-this.startCoords.client.x;var f=this.curCoords.client.y-this.startCoords.client.y;
this.pointerWasMoved=ga(h,f)>Na}d||this.pointerIsDown&&!this.pointerWasMoved||(this.pointerIsDown&&clearTimeout(this.holdTimers[k]),this.collectEventTargets(a,b,c,"move"));if(this.pointerIsDown)if(d&&this.pointerWasMoved&&!e)this.checkAndPreventDefault(b,this.target,this.element);else if(Qa(this.pointerDelta,this.prevCoords,this.curCoords),this.prepared.name){if(this.pointerWasMoved&&(!this.inertiaStatus.active||a instanceof I&&/inertiastart/.test(a.type))){if(!this.interacting()&&(Qa(this.pointerDelta,
this.prevCoords,this.curCoords),"drag"===this.prepared.name)){h=Math.abs(h);f=Math.abs(f);d=this.target.options.drag.axis;var q=h>f?"x":h<f?"y":"xy";if("xy"!==q&&"xy"!==d&&d!==q){this.prepared.name=null;for(var g=c;r(g);){if((f=D.get(g))&&f!==this.target&&!f.options.drag.manualStart&&"drag"===f.getAction(this.downPointer,this.downEvent,this,g).name&&Ya(q,f)){this.prepared.name="drag";this.target=f;this.element=g;break}g=N(g)}if(!this.prepared.name){var n=this;f=function(a,b,d){d=la?d.querySelectorAll(b):
void 0;if(a!==n.target&&ua(a,c)&&!a.options.drag.manualStart&&!ca(a,g,c)&&da(a,g,c)&&T(g,b,d)&&"drag"===a.getAction(n.downPointer,n.downEvent,n,g).name&&Ya(q,a)&&ia(a,g,"drag"))return a};for(g=c;r(g);){if(h=D.forEachSelector(f)){this.prepared.name="drag";this.target=h;this.element=g;break}g=N(g)}}}}if((f=!!this.prepared.name&&!this.interacting())&&(this.target.options[this.prepared.name].manualStart||!ia(this.target,this.element,this.prepared))){this.stop(b);return}if(this.prepared.name&&this.target){f&&
this.start(this.prepared,this.target,this.element);if(this.setModifications(this.curCoords.page,e)||f)this.prevEvent=this[this.prepared.name+"Move"](b);this.checkAndPreventDefault(b,this.target,this.element)}}ra(this.prevCoords,this.curCoords);(this.dragging||this.resizing)&&this.autoScrollMove(a)}},dragStart:function(a){var b=new I(this,a,"drag","start",this.element);this.dragging=!0;this.target.fire(b);this.activeDrops.dropzones=[];this.activeDrops.elements=[];this.activeDrops.rects=[];this.dynamicDrop||
this.setActiveDrops(this.element);a=this.getDropEvents(a,b);a.activate&&this.fireActiveDrops(a.activate);return b},dragMove:function(a){var b=this.target,c=new I(this,a,"drag","move",this.element),d=this.getDrop(c,a,this.element);this.dropTarget=d.dropzone;this.dropElement=d.element;a=this.getDropEvents(a,c);b.fire(c);a.leave&&this.prevDropTarget.fire(a.leave);a.enter&&this.dropTarget.fire(a.enter);a.move&&this.dropTarget.fire(a.move);this.prevDropTarget=this.dropTarget;this.prevDropElement=this.dropElement;
return c},resizeStart:function(a){a=new I(this,a,"resize","start",this.element);if(this.prepared.edges){var b=this.target.getRect(this.element);if(this.target.options.resize.square||this.target.options.resize.preserveAspectRatio){var c=C({},this.prepared.edges);c.top=c.top||c.left&&!c.bottom;c.left=c.left||c.top&&!c.right;c.bottom=c.bottom||c.right&&!c.top;c.right=c.right||c.bottom&&!c.left;this.prepared._linkedEdges=c}else this.prepared._linkedEdges=null;this.target.options.resize.preserveAspectRatio&&
(this.resizeStartAspectRatio=b.width/b.height);this.resizeRects={start:b,current:C({},b),restricted:C({},b),previous:C({},b),delta:{left:0,right:0,width:0,top:0,bottom:0,height:0}};a.rect=this.resizeRects.restricted;a.deltaRect=this.resizeRects.delta}this.target.fire(a);this.resizing=!0;return a},resizeMove:function(a){a=new I(this,a,"resize","move",this.element);var b=this.prepared.edges,c=this.target.options.resize.invert,d="reposition"===c||"negate"===c;if(b){var e=a.dx,k=a.dy,h=this.resizeRects.start,
f=this.resizeRects.current,q=this.resizeRects.restricted,g=this.resizeRects.delta,n=C(this.resizeRects.previous,q),l=b;if(this.target.options.resize.preserveAspectRatio){var m=this.resizeStartAspectRatio,b=this.prepared._linkedEdges;if(l.left&&l.bottom||l.right&&l.top)k=-e/m;else if(l.left||l.right)k=e/m;else if(l.top||l.bottom)e=k*m}else if(this.target.options.resize.square)if(b=this.prepared._linkedEdges,l.left&&l.bottom||l.right&&l.top)k=-e;else if(l.left||l.right)k=e;else if(l.top||l.bottom)e=
k;b.top&&(f.top+=k);b.bottom&&(f.bottom+=k);b.left&&(f.left+=e);b.right&&(f.right+=e);d?(C(q,f),"reposition"===c&&(q.top>q.bottom&&(b=q.top,q.top=q.bottom,q.bottom=b),q.left>q.right&&(b=q.left,q.left=q.right,q.right=b))):(q.top=Math.min(f.top,h.bottom),q.bottom=Math.max(f.bottom,h.top),q.left=Math.min(f.left,h.right),q.right=Math.max(f.right,h.left));q.width=q.right-q.left;q.height=q.bottom-q.top;for(var p in q)g[p]=q[p]-n[p];a.edges=this.prepared.edges;a.rect=q;a.deltaRect=g}this.target.fire(a);
return a},gestureStart:function(a){a=new I(this,a,"gesture","start",this.element);a.ds=0;this.gesture.startDistance=this.gesture.prevDistance=a.distance;this.gesture.startAngle=this.gesture.prevAngle=a.angle;this.gesture.scale=1;this.gesturing=!0;this.target.fire(a);return a},gestureMove:function(a){if(!this.pointerIds.length)return this.prevEvent;a=new I(this,a,"gesture","move",this.element);a.ds=a.scale-this.gesture.scale;this.target.fire(a);this.gesture.prevAngle=a.angle;this.gesture.prevDistance=
a.distance;Infinity===a.scale||null===a.scale||void 0===a.scale||isNaN(a.scale)||(this.gesture.scale=a.scale);return a},pointerHold:function(a,b,c){this.collectEventTargets(a,b,c,"hold")},pointerUp:function(a,b,c,d){var e=this.mouse?0:y(this.pointerIds,Q(a));clearTimeout(this.holdTimers[e]);this.collectEventTargets(a,b,c,"up");this.collectEventTargets(a,b,c,"tap");this.pointerEnd(a,b,c,d);this.removePointer(a)},pointerCancel:function(a,b,c,d){var e=this.mouse?0:y(this.pointerIds,Q(a));clearTimeout(this.holdTimers[e]);
this.collectEventTargets(a,b,c,"cancel");this.pointerEnd(a,b,c,d);this.removePointer(a)},ie8Dblclick:function(a,b,c){this.prevTap&&b.clientX===this.prevTap.clientX&&b.clientY===this.prevTap.clientY&&c===this.prevTap.target&&(this.downTargets[0]=c,this.downTimes[0]=(new Date).getTime(),this.collectEventTargets(a,b,c,"tap"))},pointerEnd:function(a,b,c,d){var e=this.target,k=e&&e.options,h=k&&this.prepared.name&&k[this.prepared.name].inertia;var f=this.inertiaStatus;if(this.interacting()){if(f.active&&
!f.ending)return;var q=(new Date).getTime(),g,l=!1,n=Ja(e,this.prepared.name)&&k[this.prepared.name].snap.endOnly,m=Ka(e,this.prepared.name)&&k[this.prepared.name].restrict.endOnly,p=0,r=0,k=this.dragging?"x"===k.drag.axis?Math.abs(this.pointerDelta.client.vx):"y"===k.drag.axis?Math.abs(this.pointerDelta.client.vy):this.pointerDelta.client.speed:this.pointerDelta.client.speed,h=(g=h&&h.enabled&&"gesture"!==this.prepared.name&&b!==f.startEvent)&&50>q-this.curCoords.timeStamp&&k>h.minSpeed&&k>h.endSpeed;
g&&!h&&(n||m)&&(g={},g.snap=g.restrict=g,n&&(this.setSnapping(this.curCoords.page,g),g.locked&&(p+=g.dx,r+=g.dy)),m&&(this.setRestriction(this.curCoords.page,g),g.restricted&&(p+=g.dx,r+=g.dy)),p||r)&&(l=!0);if(h||l){ra(f.upCoords,this.curCoords);this.pointers[0]=f.startEvent=new I(this,b,this.prepared.name,"inertiastart",this.element);f.t0=q;e.fire(f.startEvent);h?(f.vx0=this.pointerDelta.client.vx,f.vy0=this.pointerDelta.client.vy,f.v0=k,this.calcInertia(f),b=C({},this.curCoords.page),e=na(e,this.element),
b.x=b.x+f.xe-e.x,b.y=b.y+f.ye-e.y,e={useStatusXY:!0,x:b.x,y:b.y,dx:0,dy:0,snap:null},e.snap=e,p=r=0,n&&(b=this.setSnapping(this.curCoords.page,e),b.locked&&(p+=b.dx,r+=b.dy)),m&&(e=this.setRestriction(this.curCoords.page,e),e.restricted&&(p+=e.dx,r+=e.dy)),f.modifiedXe+=p,f.modifiedYe+=r,f.i=W(this.boundInertiaFrame)):(f.smoothEnd=!0,f.xe=p,f.ye=r,f.sx=f.sy=0,f.i=W(this.boundSmoothEndFrame));f.active=!0;return}(n||m)&&this.pointerMove(a,b,c,d,!0)}this.dragging?(f=new I(this,b,"drag","end",this.element),
m=this.getDrop(f,b,this.element),this.dropTarget=m.dropzone,this.dropElement=m.element,m=this.getDropEvents(b,f),m.leave&&this.prevDropTarget.fire(m.leave),m.enter&&this.dropTarget.fire(m.enter),m.drop&&this.dropTarget.fire(m.drop),m.deactivate&&this.fireActiveDrops(m.deactivate),e.fire(f)):this.resizing?(f=new I(this,b,"resize","end",this.element),e.fire(f)):this.gesturing&&(f=new I(this,b,"gesture","end",this.element),e.fire(f));this.stop(b)},collectDrops:function(a){var b=[],c=[],d;a=a||this.element;
for(d=0;d<D.length;d++)if(D[d].options.drop.enabled){var e=D[d],k=e.options.drop.accept;if(!(r(k)&&k!==a||P(k)&&!T(a,k)))for(var k=e.selector?e._context.querySelectorAll(e.selector):[e._element],h=0,f=k.length;h<f;h++){var g=k[h];g!==a&&(b.push(e),c.push(g))}}return{dropzones:b,elements:c}},fireActiveDrops:function(a){var b;for(b=0;b<this.activeDrops.dropzones.length;b++){var c=this.activeDrops.dropzones[b];var d=this.activeDrops.elements[b];d!==e&&(a.target=d,c.fire(a));var e=d}},setActiveDrops:function(a){a=
this.collectDrops(a,!0);this.activeDrops.dropzones=a.dropzones;this.activeDrops.elements=a.elements;this.activeDrops.rects=[];for(a=0;a<this.activeDrops.dropzones.length;a++)this.activeDrops.rects[a]=this.activeDrops.dropzones[a].getRect(this.activeDrops.elements[a])},getDrop:function(a,b,c){var d=[];Ma&&this.setActiveDrops(c);for(var e=0;e<this.activeDrops.dropzones.length;e++){var k=this.activeDrops.elements[e];d.push(this.activeDrops.dropzones[e].dropCheck(a,b,this.target,c,k,this.activeDrops.rects[e])?
k:null)}c=(b=d[0])?0:-1;for(var h,e=[],f,k=1;k<d.length;k++)if((a=d[k])&&a!==b)if(!b)b=a,c=k;else if(a.parentNode!==a.ownerDocument)if(b.parentNode===a.ownerDocument)b=a,c=k;else{if(!e.length)for(h=b;h.parentNode&&h.parentNode!==h.ownerDocument;)e.unshift(h),h=h.parentNode;if(b instanceof nb&&a instanceof Ua&&!(a instanceof mb)){if(a===b.parentNode)continue;h=a.ownerSVGElement}else h=a;for(f=[];h.parentNode!==h.ownerDocument;)f.unshift(h),h=h.parentNode;for(h=0;f[h]&&f[h]===e[h];)h++;h=[f[h-1],f[h],
e[h]];for(f=h[0].lastChild;f;){if(f===h[1]){b=a;c=k;e=[];break}else if(f===h[2])break;f=f.previousSibling}}d=c;return{dropzone:this.activeDrops.dropzones[d]||null,element:this.activeDrops.elements[d]||null}},getDropEvents:function(a,b){a={enter:null,leave:null,activate:null,deactivate:null,move:null,drop:null};this.dropElement!==this.prevDropElement&&(this.prevDropTarget&&(a.leave={target:this.prevDropElement,dropzone:this.prevDropTarget,relatedTarget:b.target,draggable:b.interactable,dragEvent:b,
interaction:this,timeStamp:b.timeStamp,type:"dragleave"},b.dragLeave=this.prevDropElement,b.prevDropzone=this.prevDropTarget),this.dropTarget&&(a.enter={target:this.dropElement,dropzone:this.dropTarget,relatedTarget:b.target,draggable:b.interactable,dragEvent:b,interaction:this,timeStamp:b.timeStamp,type:"dragenter"},b.dragEnter=this.dropElement,b.dropzone=this.dropTarget));"dragend"===b.type&&this.dropTarget&&(a.drop={target:this.dropElement,dropzone:this.dropTarget,relatedTarget:b.target,draggable:b.interactable,
dragEvent:b,interaction:this,timeStamp:b.timeStamp,type:"drop"},b.dropzone=this.dropTarget);"dragstart"===b.type&&(a.activate={target:null,dropzone:null,relatedTarget:b.target,draggable:b.interactable,dragEvent:b,interaction:this,timeStamp:b.timeStamp,type:"dropactivate"});"dragend"===b.type&&(a.deactivate={target:null,dropzone:null,relatedTarget:b.target,draggable:b.interactable,dragEvent:b,interaction:this,timeStamp:b.timeStamp,type:"dropdeactivate"});"dragmove"===b.type&&this.dropTarget&&(a.move=
{target:this.dropElement,dropzone:this.dropTarget,relatedTarget:b.target,draggable:b.interactable,dragEvent:b,interaction:this,dragmove:b,timeStamp:b.timeStamp,type:"dropmove"},b.dropzone=this.dropTarget);return a},currentAction:function(){return this.dragging&&"drag"||this.resizing&&"resize"||this.gesturing&&"gesture"||null},interacting:function(){return this.dragging||this.resizing||this.gesturing},clearTargets:function(){this.dropTarget=this.dropElement=this.prevDropTarget=this.prevDropElement=
this.target=this.element=null},stop:function(a){if(this.interacting()){g.stop();this.matches=[];this.matchElements=[];var b=this.target;b.options.styleCursor&&(b._doc.documentElement.style.cursor="");a&&x(a.preventDefault)&&this.checkAndPreventDefault(a,b,this.element);this.dragging&&(this.activeDrops.dropzones=this.activeDrops.elements=this.activeDrops.rects=null)}this.clearTargets();this.pointerIsDown=this.snapStatus.locked=this.dragging=this.resizing=this.gesturing=!1;this.prepared.name=this.prevEvent=
null;for(a=this.inertiaStatus.resumeDx=this.inertiaStatus.resumeDy=0;a<this.pointers.length;a++)-1===y(this.pointerIds,Q(this.pointers[a]))&&this.pointers.splice(a,1)},inertiaFrame:function(){var a=this.inertiaStatus;var b=this.target.options[this.prepared.name].inertia.resistance;var c=(new Date).getTime()/1E3-a.t0;if(c<a.te){c=1-(Math.exp(-b*c)-a.lambda_v0)/a.one_ve_v0;if(a.modifiedXe===a.xe&&a.modifiedYe===a.ye)a.sx=a.xe*c,a.sy=a.ye*c;else{var d=a.ye,e=a.modifiedYe;b=Wa(c,0,a.xe,a.modifiedXe);
c=Wa(c,0,d,e);a.sx=b;a.sy=c}this.pointerMove(a.startEvent,a.startEvent);a.i=W(this.boundInertiaFrame)}else a.ending=!0,a.sx=a.modifiedXe,a.sy=a.modifiedYe,this.pointerMove(a.startEvent,a.startEvent),this.pointerEnd(a.startEvent,a.startEvent),a.active=a.ending=!1},smoothEndFrame:function(){var a=this.inertiaStatus,b=(new Date).getTime()-a.t0,c=this.target.options[this.prepared.name].inertia.smoothEndDuration;if(b<c){var d=b/c;a.sx=-a.xe*d*(d-2)+0;b/=c;a.sy=-a.ye*b*(b-2)+0;this.pointerMove(a.startEvent,
a.startEvent);a.i=W(this.boundSmoothEndFrame)}else a.ending=!0,a.sx=a.xe,a.sy=a.ye,this.pointerMove(a.startEvent,a.startEvent),this.pointerEnd(a.startEvent,a.startEvent),a.smoothEnd=a.active=a.ending=!1},addPointer:function(a){var b=Q(a),c=this.mouse?0:y(this.pointerIds,b);-1===c&&(c=this.pointerIds.length);this.pointerIds[c]=b;this.pointers[c]=a;return c},removePointer:function(a){a=Q(a);a=this.mouse?0:y(this.pointerIds,a);-1!==a&&(this.pointers.splice(a,1),this.pointerIds.splice(a,1),this.downTargets.splice(a,
1),this.downTimes.splice(a,1),this.holdTimers.splice(a,1))},recordPointer:function(a){var b=this.mouse?0:y(this.pointerIds,Q(a));-1!==b&&(this.pointers[b]=a)},collectEventTargets:function(a,b,c,d){function e(a,b,e){e=la?e.querySelectorAll(b):void 0;a._iEvents[d]&&r(g)&&ua(a,g)&&!ca(a,g,c)&&da(a,g,c)&&T(g,b,e)&&(h.push(a),f.push(g))}var k=this.mouse?0:y(this.pointerIds,Q(a));if("tap"!==d||!this.pointerWasMoved&&this.downTargets[k]&&this.downTargets[k]===c){for(var h=[],f=[],g=c;g;)p.isSet(g)&&p(g)._iEvents[d]&&
(h.push(p(g)),f.push(g)),D.forEachSelector(e),g=N(g);(h.length||"tap"===d)&&this.firePointers(a,b,c,h,f,d)}},firePointers:function(a,b,c,d,e,k){var h=this.mouse?0:y(this.pointerIds,Q(a)),f={};"doubletap"===k?f=a:(qa(f,b),b!==a&&qa(f,a),f.preventDefault=bb,f.stopPropagation=I.prototype.stopPropagation,f.stopImmediatePropagation=I.prototype.stopImmediatePropagation,f.interaction=this,f.timeStamp=(new Date).getTime(),f.originalEvent=b,f.originalPointer=a,f.type=k,f.pointerId=Q(a),f.pointerType=this.mouse?
"mouse":U?P(a.pointerType)?a.pointerType:[,,"touch","pen","mouse"][a.pointerType]:"touch");if("tap"===k){f.dt=f.timeStamp-this.downTimes[h];var g=f.timeStamp-this.tapTime;var l=!!(this.prevTap&&"doubletap"!==this.prevTap.type&&this.prevTap.target===f.target&&500>g);f.double=l;this.tapTime=f.timeStamp}for(a=0;a<d.length&&!(f.currentTarget=e[a],f.interactable=d[a],d[a].fire(f),f.immediatePropagationStopped||f.propagationStopped&&e[a+1]!==f.currentTarget);a++);l?(d={},C(d,f),d.dt=g,d.type="doubletap",
this.collectEventTargets(d,b,c,"doubletap"),this.prevTap=d):"tap"===k&&(this.prevTap=f)},validateSelector:function(a,b,c,d){for(var e=0,k=c.length;e<k;e++){var h=c[e],f=d[e],g=Z(h.getAction(a,b,this,f),h);if(g&&ia(h,f,g))return this.target=h,this.element=f,g}},setSnapping:function(a,b){var c=this.target.options[this.prepared.name].snap,d=[],e;b=b||this.snapStatus;if(b.useStatusXY)a={x:b.x,y:b.y};else{var k=na(this.target,this.element);a=C({},a);a.x-=k.x;a.y-=k.y}b.realX=a.x;b.realY=a.y;a.x-=this.inertiaStatus.resumeDx;
a.y-=this.inertiaStatus.resumeDy;for(var h=c.targets?c.targets.length:0,f=0;f<this.snapOffsets.length;f++){var g=a.x-this.snapOffsets[f].x,l=a.y-this.snapOffsets[f].y;for(e=0;e<h;e++)(k=x(c.targets[e])?c.targets[e](g,l,this):c.targets[e])&&d.push({x:F(k.x)?k.x+this.snapOffsets[f].x:g,y:F(k.y)?k.y+this.snapOffsets[f].y:l,range:F(k.range)?k.range:c.range})}var c=null,f=!1,m=0,n=0;e=l=g=0;for(h=d.length;e<h;e++){k=d[e];var p=k.range,r=k.x-a.x,u=k.y-a.y,v=ga(r,u),w=v<=p;Infinity===p&&f&&Infinity!==n&&
(w=!1);if(!c||(w?f&&Infinity!==p?v/p<m/n:Infinity===p&&Infinity!==n||v<m:!f&&v<m))Infinity===p&&(w=!0),c=k,m=v,n=p,f=w,g=r,l=u,b.range=p}c?(d=b.snappedX!==c.x||b.snappedY!==c.y,b.snappedX=c.x,b.snappedY=c.y):(d=!0,b.snappedX=NaN,b.snappedY=NaN);b.dx=g;b.dy=l;b.changed=d||f&&!b.locked;b.locked=f;return b},setRestriction:function(a,b){var c=this.target,d=c&&c.options[this.prepared.name].restrict,e=d&&d.restriction;if(!e)return b;b=b||this.restrictStatus;d=b.useStatusXY?d={x:b.x,y:b.y}:d=C({},a);b.snap&&
b.snap.locked&&(d.x+=b.snap.dx||0,d.y+=b.snap.dy||0);d.x-=this.inertiaStatus.resumeDx;d.y-=this.inertiaStatus.resumeDy;b.dx=0;b.dy=0;b.restricted=!1;if(P(e)&&(e="parent"===e?N(this.element):"self"===e?c.getRect(this.element):Ha(this.element,e),!e))return b;x(e)&&(e=e(d.x,d.y,this.element));r(e)&&(e=ta(e));(a=e)?"x"in e&&"y"in e?(c=Math.max(Math.min(a.x+a.width-this.restrictOffset.right,d.x),a.x+this.restrictOffset.left),a=Math.max(Math.min(a.y+a.height-this.restrictOffset.bottom,d.y),a.y+this.restrictOffset.top)):
(c=Math.max(Math.min(a.right-this.restrictOffset.right,d.x),a.left+this.restrictOffset.left),a=Math.max(Math.min(a.bottom-this.restrictOffset.bottom,d.y),a.top+this.restrictOffset.top)):(c=d.x,a=d.y);b.dx=c-d.x;b.dy=a-d.y;b.changed=b.restrictedX!==c||b.restrictedY!==a;b.restricted=!(!b.dx&&!b.dy);b.restrictedX=c;b.restrictedY=a;return b},checkAndPreventDefault:function(a,b,c){if(b=b||this.target){b=b.options;var d=b.preventDefault;"auto"===d&&c&&!/^(input|select|textarea)$/i.test(a.target.nodeName)?
/down|start/i.test(a.type)&&"drag"===this.prepared.name&&"xy"!==b.drag.axis||b[this.prepared.name]&&b[this.prepared.name].manualStart&&!this.interacting()||a.preventDefault():"always"===d&&a.preventDefault()}},calcInertia:function(a){var b=this.target.options[this.prepared.name].inertia,c=b.resistance,d=-Math.log(b.endSpeed/a.v0)/c;a.x0=this.prevEvent.pageX;a.y0=this.prevEvent.pageY;a.t0=a.startEvent.timeStamp/1E3;a.sx=a.sy=0;a.modifiedXe=a.xe=(a.vx0-d)/c;a.modifiedYe=a.ye=(a.vy0-d)/c;a.te=d;a.lambda_v0=
c/a.v0;a.one_ve_v0=1-b.endSpeed/a.v0},autoScrollMove:function(a){var b;if(b=this.interacting()){b=this.prepared.name;var c=this.target.options;/^resize/.test(b)&&(b="resize");b=c[b].autoScroll&&c[b].autoScroll.enabled}if(b)if(this.inertiaStatus.active)g.x=g.y=0;else{var d=this.target.options[this.prepared.name].autoScroll,e=d.container||Y(this.element);if(M(e)){var k=a.clientX<g.margin;b=a.clientY<g.margin;c=a.clientX>e.innerWidth-g.margin;a=a.clientY>e.innerHeight-g.margin}else e=Ca(e),k=a.clientX<
e.left+g.margin,b=a.clientY<e.top+g.margin,c=a.clientX>e.right-g.margin,a=a.clientY>e.bottom-g.margin;g.x=c?1:k?-1:0;g.y=a?1:b?-1:0;g.isScrolling||(g.margin=d.margin,g.speed=d.speed,g.start(this))}},_updateEventTargets:function(a,b){this._eventTarget=a;this._curEventTarget=b}};I.prototype={preventDefault:J,stopImmediatePropagation:function(){this.immediatePropagationStopped=this.propagationStopped=!0},stopPropagation:function(){this.propagationStopped=!0}};for(var l={},ib="dragStart dragMove resizeStart resizeMove gestureStart gestureMove pointerOver pointerOut pointerHover selectorDown pointerDown pointerMove pointerUp pointerCancel pointerEnd addPointer removePointer recordPointer autoScrollMove".split(" "),
Oa=0,Pa=ib.length;Oa<Pa;Oa++){var jb=ib[Oa];l[jb]=$a(jb)}D.indexOfElement=function(a,b){b=b||S;for(var c=0;c<this.length;c++){var d=this[c];if(d.selector===a&&d._context===b||!d.selector&&d._element===a)return c}return-1};D.get=function(a,b){return this[this.indexOfElement(a,b&&b.context)]};D.forEachSelector=function(a){for(var b=0;b<this.length;b++){var c=this[b];if(c.selector&&(c=a(c,c.selector,c._context,b,this),void 0!==c))return c}};E.prototype={setOnEvents:function(a,b){"drop"===a?(x(b.ondrop)&&
(this.ondrop=b.ondrop),x(b.ondropactivate)&&(this.ondropactivate=b.ondropactivate),x(b.ondropdeactivate)&&(this.ondropdeactivate=b.ondropdeactivate),x(b.ondragenter)&&(this.ondragenter=b.ondragenter),x(b.ondragleave)&&(this.ondragleave=b.ondragleave),x(b.ondropmove)&&(this.ondropmove=b.ondropmove)):(a="on"+a,x(b.onstart)&&(this[a+"start"]=b.onstart),x(b.onmove)&&(this[a+"move"]=b.onmove),x(b.onend)&&(this[a+"end"]=b.onend),x(b.oninertiastart)&&(this[a+"inertiastart"]=b.oninertiastart));return this},
draggable:function(a){return u(a)?(this.options.drag.enabled=!1===a.enabled?!1:!0,this.setPerAction("drag",a),this.setOnEvents("drag",a),/^x$|^y$|^xy$/.test(a.axis)?this.options.drag.axis=a.axis:null===a.axis&&delete this.options.drag.axis,this):K(a)?(this.options.drag.enabled=a,this):this.options.drag},setPerAction:function(a,b){for(var c in b)c in H[a]&&(u(b[c])?(this.options[a][c]=C(this.options[a][c]||{},b[c]),u(H.perAction[c])&&"enabled"in H.perAction[c]&&(this.options[a][c].enabled=!1===b[c].enabled?
!1:!0)):K(b[c])&&u(H.perAction[c])?this.options[a][c].enabled=b[c]:void 0!==b[c]&&(this.options[a][c]=b[c]))},dropzone:function(a){return u(a)?(this.options.drop.enabled=!1===a.enabled?!1:!0,this.setOnEvents("drop",a),/^(pointer|center)$/.test(a.overlap)?this.options.drop.overlap=a.overlap:F(a.overlap)&&(this.options.drop.overlap=Math.max(Math.min(1,a.overlap),0)),"accept"in a&&(this.options.drop.accept=a.accept),"checker"in a&&(this.options.drop.checker=a.checker),this):K(a)?(this.options.drop.enabled=
a,this):this.options.drop},dropCheck:function(a,b,c,d,e,k){var h=!1;if(!(k=k||this.getRect(e)))return this.options.drop.checker?this.options.drop.checker(a,b,h,this,e,c,d):!1;var f=this.options.drop.overlap;if("pointer"===f){var g=Aa(a),h=na(c,d);g.x+=h.x;g.y+=h.y;h=g.x>k.left&&g.x<k.right;g=g.y>k.top&&g.y<k.bottom;h=h&&g}g=c.getRect(d);if("center"===f)var h=g.left+g.width/2,l=g.top+g.height/2,h=h>=k.left&&h<=k.right&&l>=k.top&&l<=k.bottom;F(f)&&(h=Math.max(0,Math.min(k.right,g.right)-Math.max(k.left,
g.left))*Math.max(0,Math.min(k.bottom,g.bottom)-Math.max(k.top,g.top))/(g.width*g.height)>=f);this.options.drop.checker&&(h=this.options.drop.checker(a,b,h,this,e,c,d));return h},dropChecker:function(a){return x(a)?(this.options.drop.checker=a,this):null===a?(delete this.options.getRect,this):this.options.drop.checker},accept:function(a){return r(a)||fa(a)?(this.options.drop.accept=a,this):null===a?(delete this.options.drop.accept,this):this.options.drop.accept},resizable:function(a){return u(a)?
(this.options.resize.enabled=!1===a.enabled?!1:!0,this.setPerAction("resize",a),this.setOnEvents("resize",a),/^x$|^y$|^xy$/.test(a.axis)?this.options.resize.axis=a.axis:null===a.axis&&(this.options.resize.axis=H.resize.axis),K(a.preserveAspectRatio)?this.options.resize.preserveAspectRatio=a.preserveAspectRatio:K(a.square)&&(this.options.resize.square=a.square),this):K(a)?(this.options.resize.enabled=a,this):this.options.resize},squareResize:function(a){return K(a)?(this.options.resize.square=a,this):
null===a?(delete this.options.resize.square,this):this.options.resize.square},gesturable:function(a){return u(a)?(this.options.gesture.enabled=!1===a.enabled?!1:!0,this.setPerAction("gesture",a),this.setOnEvents("gesture",a),this):K(a)?(this.options.gesture.enabled=a,this):this.options.gesture},autoScroll:function(a){u(a)?a=C({actions:["drag","resize"]},a):K(a)&&(a={actions:["drag","resize"],enabled:a});return this.setOptions("autoScroll",a)},snap:function(a){a=this.setOptions("snap",a);return a===
this?this:a.drag},setOptions:function(a,b){var c=b&&B(b.actions)?b.actions:["drag"],d;if(u(b)||K(b)){for(d=0;d<c.length;d++){var e=/resize/.test(c[d])?"resize":c[d];u(this.options[e])&&(e=this.options[e][a],u(b)?(C(e,b),e.enabled=!1===b.enabled?!1:!0,"snap"===a&&("grid"===e.mode?e.targets=[p.createSnapGrid(C({offset:e.gridOffset||{x:0,y:0}},e.grid||{}))]:"anchor"===e.mode?e.targets=e.anchors:"path"===e.mode&&(e.targets=e.paths),"elementOrigin"in b&&(e.relativePoints=[b.elementOrigin]))):K(b)&&(e.enabled=
b))}return this}b={};c=["drag","resize","gesture"];for(d=0;d<c.length;d++)a in H[c[d]]&&(b[c[d]]=this.options[c[d]][a]);return b},inertia:function(a){a=this.setOptions("inertia",a);return a===this?this:a.drag},getAction:function(a,b,c,d){var e=this.defaultActionChecker(a,c,d);return this.options.actionChecker?this.options.actionChecker(a,b,e,this,d,c):e},defaultActionChecker:db,actionChecker:function(a){return x(a)?(this.options.actionChecker=a,this):null===a?(delete this.options.actionChecker,this):
this.options.actionChecker},getRect:function(a){a=a||this._element;this.selector&&!r(a)&&(a=this._context.querySelector(this.selector));return ta(a)},rectChecker:function(a){return x(a)?(this.getRect=a,this):null===a?(delete this.options.getRect,this):this.getRect},styleCursor:function(a){return K(a)?(this.options.styleCursor=a,this):null===a?(delete this.options.styleCursor,this):this.options.styleCursor},preventDefault:function(a){return/^(always|never|auto)$/.test(a)?(this.options.preventDefault=
a,this):K(a)?(this.options.preventDefault=a?"always":"never",this):this.options.preventDefault},origin:function(a){return fa(a)||u(a)?(this.options.origin=a,this):this.options.origin},deltaSource:function(a){return"page"===a||"client"===a?(this.options.deltaSource=a,this):this.options.deltaSource},restrict:function(a){if(!u(a))return this.setOptions("restrict",a);for(var b=["drag","resize","gesture"],c,d=0;d<b.length;d++){var e=b[d];e in a&&(c=C({actions:[e],restriction:a[e]},a),c=this.setOptions("restrict",
c))}return c},context:function(){return this._context},_context:S,ignoreFrom:function(a){return fa(a)||r(a)?(this.options.ignoreFrom=a,this):this.options.ignoreFrom},allowFrom:function(a){return fa(a)||r(a)?(this.options.allowFrom=a,this):this.options.allowFrom},element:function(){return this._element},fire:function(a){if(!a||!a.type||-1===y(ea,a.type))return this;var b,c="on"+a.type;if(a.type in this._iEvents){var d=this._iEvents[a.type];var e=0;for(b=d.length;e<b&&!a.immediatePropagationStopped;e++)d[e](a)}if(x(this[c]))this[c](a);
if(a.type in X&&(d=X[a.type]))for(e=0,b=d.length;e<b&&!a.immediatePropagationStopped;e++)d[e](a);return this},on:function(a,b,c){var d;P(a)&&-1!==a.search(" ")&&(a=a.trim().split(/ +/));if(B(a)){for(d=0;d<a.length;d++)this.on(a[d],b,c);return this}if(u(a)){for(d in a)this.on(d,a[d],b);return this}"wheel"===a&&(a=hb);c=c?!0:!1;if(-1!==y(ea,a))a in this._iEvents?this._iEvents[a].push(b):this._iEvents[a]=[b];else if(this.selector){if(!R[a])for(R[a]={selectors:[],contexts:[],listeners:[]},d=0;d<ka.length;d++)n.add(ka[d],
a,pa),n.add(ka[d],a,ya,!0);a=R[a];for(d=a.selectors.length-1;0<=d&&(a.selectors[d]!==this.selector||a.contexts[d]!==this._context);d--);-1===d&&(d=a.selectors.length,a.selectors.push(this.selector),a.contexts.push(this._context),a.listeners.push([]));a.listeners[d].push([b,c])}else n.add(this._element,a,b,c);return this},off:function(a,b,c){var d;P(a)&&-1!==a.search(" ")&&(a=a.trim().split(/ +/));if(B(a)){for(d=0;d<a.length;d++)this.off(a[d],b,c);return this}if(u(a)){for(var e in a)this.off(e,a[e],
b);return this}e=-1;c=c?!0:!1;"wheel"===a&&(a=hb);if(-1!==y(ea,a))(c=this._iEvents[a])&&-1!==(e=y(c,b))&&this._iEvents[a].splice(e,1);else if(this.selector){var g=R[a],h=!1;if(!g)return this;for(e=g.selectors.length-1;0<=e;e--)if(g.selectors[e]===this.selector&&g.contexts[e]===this._context){var f=g.listeners[e];for(d=f.length-1;0<=d;d--){var l=f[d][1];if(f[d][0]===b&&l===c){f.splice(d,1);f.length||(g.selectors.splice(e,1),g.contexts.splice(e,1),g.listeners.splice(e,1),n.remove(this._context,a,pa),
n.remove(this._context,a,ya,!0),g.selectors.length||(R[a]=null));h=!0;break}}if(h)break}}else n.remove(this._element,a,b,c);return this},set:function(a){u(a)||(a={});this.options=C({},H.base);var b,c=["drag","drop","resize","gesture"],d=["draggable","dropzone","resizable","gesturable"],e=C(C({},H.perAction),a[g]||{});for(b=0;b<c.length;b++){var g=c[b];this.options[g]=C({},H[g]);this.setPerAction(g,e);this[d[b]](a[g])}g="accept actionChecker allowFrom deltaSource dropChecker ignoreFrom origin preventDefault rectChecker styleCursor".split(" ");
b=0;for(Pa=g.length;b<Pa;b++)if(c=g[b],this.options[c]=H.base[c],c in a)this[c](a[c]);return this},unset:function(){n.remove(this._element,"all");if(P(this.selector))for(var a in R)for(var b=R[a];0<b.selectors.length;){b.selectors[0]===this.selector&&b.contexts[0]===this._context&&(b.selectors.splice(0,1),b.contexts.splice(0,1),b.listeners.splice(0,1),b.selectors.length||(R[a]=null));n.remove(this._context,a,pa);n.remove(this._context,a,ya,!0);break}else n.remove(this,"all"),this.options.styleCursor&&
(this._element.style.cursor="");this.dropzone(!1);D.splice(y(D,this),1);return p}};E.prototype.snap=O(E.prototype.snap,"Interactable#snap is deprecated. See the new documentation for snapping at http://interactjs.io/docs/snapping");E.prototype.restrict=O(E.prototype.restrict,"Interactable#restrict is deprecated. See the new documentation for resticting at http://interactjs.io/docs/restriction");E.prototype.inertia=O(E.prototype.inertia,"Interactable#inertia is deprecated. See the new documentation for inertia at http://interactjs.io/docs/inertia");
E.prototype.autoScroll=O(E.prototype.autoScroll,"Interactable#autoScroll is deprecated. See the new documentation for autoScroll at http://interactjs.io/docs/#autoscroll");E.prototype.squareResize=O(E.prototype.squareResize,"Interactable#squareResize is deprecated. See http://interactjs.io/docs/#resize-square");E.prototype.accept=O(E.prototype.accept,"Interactable#accept is deprecated. use Interactable#dropzone({ accept: target }) instead");E.prototype.dropChecker=O(E.prototype.dropChecker,"Interactable#dropChecker is deprecated. use Interactable#dropzone({ dropChecker: checkerFunction }) instead");
E.prototype.context=O(E.prototype.context,"Interactable#context as a method is deprecated. It will soon be a DOM Node instead");p.isSet=function(a,b){return-1!==D.indexOfElement(a,b&&b.context)};p.on=function(a,b,c){P(a)&&-1!==a.search(" ")&&(a=a.trim().split(/ +/));if(B(a)){for(var d=0;d<a.length;d++)p.on(a[d],b,c);return p}if(u(a)){for(d in a)p.on(d,a[d],b);return p}-1!==y(ea,a)?X[a]?X[a].push(b):X[a]=[b]:n.add(S,a,b,c);return p};p.off=function(a,b,c){P(a)&&-1!==a.search(" ")&&(a=a.trim().split(/ +/));
if(B(a)){for(var d=0;d<a.length;d++)p.off(a[d],b,c);return p}if(u(a)){for(d in a)p.off(d,a[d],b);return p}if(-1===y(ea,a))n.remove(S,a,b,c);else{var e;a in X&&-1!==(e=y(X[a],b))&&X[a].splice(e,1)}return p};p.enableDragging=O(function(a){return null!==a&&void 0!==a?(V.drag=a,p):V.drag},"interact.enableDragging is deprecated and will soon be removed.");p.enableResizing=O(function(a){return null!==a&&void 0!==a?(V.resize=a,p):V.resize},"interact.enableResizing is deprecated and will soon be removed.");
p.enableGesturing=O(function(a){return null!==a&&void 0!==a?(V.gesture=a,p):V.gesture},"interact.enableGesturing is deprecated and will soon be removed.");p.eventTypes=ea;p.debug=function(){var a=w[0]||new wa;return{interactions:w,target:a.target,dragging:a.dragging,resizing:a.resizing,gesturing:a.gesturing,prepared:a.prepared,matches:a.matches,matchElements:a.matchElements,prevCoords:a.prevCoords,startCoords:a.startCoords,pointerIds:a.pointerIds,pointers:a.pointers,addPointer:l.addPointer,removePointer:l.removePointer,
recordPointer:l.recordPointer,snap:a.snapStatus,restrict:a.restrictStatus,inertia:a.inertiaStatus,downTime:a.downTimes[0],downEvent:a.downEvent,downPointer:a.downPointer,prevEvent:a.prevEvent,Interactable:E,interactables:D,pointerIsDown:a.pointerIsDown,defaultOptions:H,defaultActionChecker:db,actionCursors:xa,dragMove:l.dragMove,resizeMove:l.resizeMove,gestureMove:l.gestureMove,pointerUp:l.pointerUp,pointerDown:l.pointerDown,pointerMove:l.pointerMove,pointerHover:l.pointerHover,eventTypes:ea,events:n,
globalEvents:X,delegatedEvents:R,prefixedPropREs:za}};p.getPointerAverage=Va;p.getTouchBBox=Ea;p.getTouchDistance=Fa;p.getTouchAngle=Ga;p.getElementRect=ta;p.getElementClientRect=Ca;p.matchesSelector=T;p.closest=Ha;p.margin=O(function(a){return F(a)?(oa=a,p):oa},"interact.margin is deprecated. Use interact(target).resizable({ margin: number }); instead.");p.supportsTouch=function(){return ha};p.supportsPointerEvent=function(){return U};p.stop=function(a){for(var b=w.length-1;0<=b;b--)w[b].stop(a);
return p};p.dynamicDrop=function(a){return K(a)?(Ma=a,p):Ma};p.pointerMoveTolerance=function(a){return F(a)?(Na=a,this):Na};p.maxInteractions=function(a){return F(a)?(va=a,this):va};p.createSnapGrid=function(a){return function(b,c){var d=0,e=0;u(a.offset)&&(d=a.offset.x,e=a.offset.y);return{x:Math.round((b-d)/a.x)*a.x+d,y:Math.round((c-e)/a.y)*a.y+e,range:a.range}}};eb(S);La in Element.prototype&&x(Element.prototype[La])||(la=function(a,b,c){c=c||a.parentNode.querySelectorAll(b);b=0;for(var d=c.length;b<
d;b++)if(c[b]===a)return!0;return!1});(function(){for(var a=0,b=["ms","moz","webkit","o"],c=0;c<b.length&&!m.requestAnimationFrame;++c)W=m[b[c]+"RequestAnimationFrame"],aa=m[b[c]+"CancelAnimationFrame"]||m[b[c]+"CancelRequestAnimationFrame"];W||(W=function(b){var c=(new Date).getTime(),d=Math.max(0,16-(c-a)),g=setTimeout(function(){b(c+d)},d);a=c+d;return g});aa||(aa=function(a){clearTimeout(a)})})();"undefined"!==typeof exports?("undefined"!==typeof module&&module.exports&&(exports=module.exports=
p),exports.interact=p):"function"===typeof define&&define.amd?define("interact",function(){return p}):m.interact=p}})("undefined"===typeof window?void 0:window);
//# sourceMappingURL=interact.min.js.map

/* axios v0.17.1 | (c) 2017 by Matt Zabriskie */
!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define([],t):"object"==typeof exports?exports.axios=t():e.axios=t()}(this,function(){return function(e){function t(r){if(n[r])return n[r].exports;var o=n[r]={exports:{},id:r,loaded:!1};return e[r].call(o.exports,o,o.exports,t),o.loaded=!0,o.exports}var n={};return t.m=e,t.c=n,t.p="",t(0)}([function(e,t,n){e.exports=n(1)},function(e,t,n){"use strict";function r(e){var t=new s(e),n=i(s.prototype.request,t);return o.extend(n,s.prototype,t),o.extend(n,t),n}var o=n(2),i=n(3),s=n(5),u=n(6),a=r(u);a.Axios=s,a.create=function(e){return r(o.merge(u,e))},a.Cancel=n(23),a.CancelToken=n(24),a.isCancel=n(20),a.all=function(e){return Promise.all(e)},a.spread=n(25),e.exports=a,e.exports.default=a},function(e,t,n){"use strict";function r(e){return"[object Array]"===R.call(e)}function o(e){return"[object ArrayBuffer]"===R.call(e)}function i(e){return"undefined"!=typeof FormData&&e instanceof FormData}function s(e){var t;return t="undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(e):e&&e.buffer&&e.buffer instanceof ArrayBuffer}function u(e){return"string"==typeof e}function a(e){return"number"==typeof e}function c(e){return"undefined"==typeof e}function f(e){return null!==e&&"object"==typeof e}function p(e){return"[object Date]"===R.call(e)}function d(e){return"[object File]"===R.call(e)}function l(e){return"[object Blob]"===R.call(e)}function h(e){return"[object Function]"===R.call(e)}function m(e){return f(e)&&h(e.pipe)}function y(e){return"undefined"!=typeof URLSearchParams&&e instanceof URLSearchParams}function w(e){return e.replace(/^\s*/,"").replace(/\s*$/,"")}function g(){return("undefined"==typeof navigator||"ReactNative"!==navigator.product)&&("undefined"!=typeof window&&"undefined"!=typeof document)}function v(e,t){if(null!==e&&"undefined"!=typeof e)if("object"!=typeof e&&(e=[e]),r(e))for(var n=0,o=e.length;n<o;n++)t.call(null,e[n],n,e);else for(var i in e)Object.prototype.hasOwnProperty.call(e,i)&&t.call(null,e[i],i,e)}function x(){function e(e,n){"object"==typeof t[n]&&"object"==typeof e?t[n]=x(t[n],e):t[n]=e}for(var t={},n=0,r=arguments.length;n<r;n++)v(arguments[n],e);return t}function b(e,t,n){return v(t,function(t,r){n&&"function"==typeof t?e[r]=E(t,n):e[r]=t}),e}var E=n(3),C=n(4),R=Object.prototype.toString;e.exports={isArray:r,isArrayBuffer:o,isBuffer:C,isFormData:i,isArrayBufferView:s,isString:u,isNumber:a,isObject:f,isUndefined:c,isDate:p,isFile:d,isBlob:l,isFunction:h,isStream:m,isURLSearchParams:y,isStandardBrowserEnv:g,forEach:v,merge:x,extend:b,trim:w}},function(e,t){"use strict";e.exports=function(e,t){return function(){for(var n=new Array(arguments.length),r=0;r<n.length;r++)n[r]=arguments[r];return e.apply(t,n)}}},function(e,t){function n(e){return!!e.constructor&&"function"==typeof e.constructor.isBuffer&&e.constructor.isBuffer(e)}function r(e){return"function"==typeof e.readFloatLE&&"function"==typeof e.slice&&n(e.slice(0,0))}/*!
	 * Determine if an object is a Buffer
	 *
	 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
	 * @license  MIT
	 */
e.exports=function(e){return null!=e&&(n(e)||r(e)||!!e._isBuffer)}},function(e,t,n){"use strict";function r(e){this.defaults=e,this.interceptors={request:new s,response:new s}}var o=n(6),i=n(2),s=n(17),u=n(18);r.prototype.request=function(e){"string"==typeof e&&(e=i.merge({url:arguments[0]},arguments[1])),e=i.merge(o,this.defaults,{method:"get"},e),e.method=e.method.toLowerCase();var t=[u,void 0],n=Promise.resolve(e);for(this.interceptors.request.forEach(function(e){t.unshift(e.fulfilled,e.rejected)}),this.interceptors.response.forEach(function(e){t.push(e.fulfilled,e.rejected)});t.length;)n=n.then(t.shift(),t.shift());return n},i.forEach(["delete","get","head","options"],function(e){r.prototype[e]=function(t,n){return this.request(i.merge(n||{},{method:e,url:t}))}}),i.forEach(["post","put","patch"],function(e){r.prototype[e]=function(t,n,r){return this.request(i.merge(r||{},{method:e,url:t,data:n}))}}),e.exports=r},function(e,t,n){"use strict";function r(e,t){!i.isUndefined(e)&&i.isUndefined(e["Content-Type"])&&(e["Content-Type"]=t)}function o(){var e;return"undefined"!=typeof XMLHttpRequest?e=n(8):"undefined"!=typeof process&&(e=n(8)),e}var i=n(2),s=n(7),u={"Content-Type":"application/x-www-form-urlencoded"},a={adapter:o(),transformRequest:[function(e,t){return s(t,"Content-Type"),i.isFormData(e)||i.isArrayBuffer(e)||i.isBuffer(e)||i.isStream(e)||i.isFile(e)||i.isBlob(e)?e:i.isArrayBufferView(e)?e.buffer:i.isURLSearchParams(e)?(r(t,"application/x-www-form-urlencoded;charset=utf-8"),e.toString()):i.isObject(e)?(r(t,"application/json;charset=utf-8"),JSON.stringify(e)):e}],transformResponse:[function(e){if("string"==typeof e)try{e=JSON.parse(e)}catch(e){}return e}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,validateStatus:function(e){return e>=200&&e<300}};a.headers={common:{Accept:"application/json, text/plain, */*"}},i.forEach(["delete","get","head"],function(e){a.headers[e]={}}),i.forEach(["post","put","patch"],function(e){a.headers[e]=i.merge(u)}),e.exports=a},function(e,t,n){"use strict";var r=n(2);e.exports=function(e,t){r.forEach(e,function(n,r){r!==t&&r.toUpperCase()===t.toUpperCase()&&(e[t]=n,delete e[r])})}},function(e,t,n){"use strict";var r=n(2),o=n(9),i=n(12),s=n(13),u=n(14),a=n(10),c="undefined"!=typeof window&&window.btoa&&window.btoa.bind(window)||n(15);e.exports=function(e){return new Promise(function(t,f){var p=e.data,d=e.headers;r.isFormData(p)&&delete d["Content-Type"];var l=new XMLHttpRequest,h="onreadystatechange",m=!1;if("undefined"==typeof window||!window.XDomainRequest||"withCredentials"in l||u(e.url)||(l=new window.XDomainRequest,h="onload",m=!0,l.onprogress=function(){},l.ontimeout=function(){}),e.auth){var y=e.auth.username||"",w=e.auth.password||"";d.Authorization="Basic "+c(y+":"+w)}if(l.open(e.method.toUpperCase(),i(e.url,e.params,e.paramsSerializer),!0),l.timeout=e.timeout,l[h]=function(){if(l&&(4===l.readyState||m)&&(0!==l.status||l.responseURL&&0===l.responseURL.indexOf("file:"))){var n="getAllResponseHeaders"in l?s(l.getAllResponseHeaders()):null,r=e.responseType&&"text"!==e.responseType?l.response:l.responseText,i={data:r,status:1223===l.status?204:l.status,statusText:1223===l.status?"No Content":l.statusText,headers:n,config:e,request:l};o(t,f,i),l=null}},l.onerror=function(){f(a("Network Error",e,null,l)),l=null},l.ontimeout=function(){f(a("timeout of "+e.timeout+"ms exceeded",e,"ECONNABORTED",l)),l=null},r.isStandardBrowserEnv()){var g=n(16),v=(e.withCredentials||u(e.url))&&e.xsrfCookieName?g.read(e.xsrfCookieName):void 0;v&&(d[e.xsrfHeaderName]=v)}if("setRequestHeader"in l&&r.forEach(d,function(e,t){"undefined"==typeof p&&"content-type"===t.toLowerCase()?delete d[t]:l.setRequestHeader(t,e)}),e.withCredentials&&(l.withCredentials=!0),e.responseType)try{l.responseType=e.responseType}catch(t){if("json"!==e.responseType)throw t}"function"==typeof e.onDownloadProgress&&l.addEventListener("progress",e.onDownloadProgress),"function"==typeof e.onUploadProgress&&l.upload&&l.upload.addEventListener("progress",e.onUploadProgress),e.cancelToken&&e.cancelToken.promise.then(function(e){l&&(l.abort(),f(e),l=null)}),void 0===p&&(p=null),l.send(p)})}},function(e,t,n){"use strict";var r=n(10);e.exports=function(e,t,n){var o=n.config.validateStatus;n.status&&o&&!o(n.status)?t(r("Request failed with status code "+n.status,n.config,null,n.request,n)):e(n)}},function(e,t,n){"use strict";var r=n(11);e.exports=function(e,t,n,o,i){var s=new Error(e);return r(s,t,n,o,i)}},function(e,t){"use strict";e.exports=function(e,t,n,r,o){return e.config=t,n&&(e.code=n),e.request=r,e.response=o,e}},function(e,t,n){"use strict";function r(e){return encodeURIComponent(e).replace(/%40/gi,"@").replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}var o=n(2);e.exports=function(e,t,n){if(!t)return e;var i;if(n)i=n(t);else if(o.isURLSearchParams(t))i=t.toString();else{var s=[];o.forEach(t,function(e,t){null!==e&&"undefined"!=typeof e&&(o.isArray(e)&&(t+="[]"),o.isArray(e)||(e=[e]),o.forEach(e,function(e){o.isDate(e)?e=e.toISOString():o.isObject(e)&&(e=JSON.stringify(e)),s.push(r(t)+"="+r(e))}))}),i=s.join("&")}return i&&(e+=(e.indexOf("?")===-1?"?":"&")+i),e}},function(e,t,n){"use strict";var r=n(2),o=["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"];e.exports=function(e){var t,n,i,s={};return e?(r.forEach(e.split("\n"),function(e){if(i=e.indexOf(":"),t=r.trim(e.substr(0,i)).toLowerCase(),n=r.trim(e.substr(i+1)),t){if(s[t]&&o.indexOf(t)>=0)return;"set-cookie"===t?s[t]=(s[t]?s[t]:[]).concat([n]):s[t]=s[t]?s[t]+", "+n:n}}),s):s}},function(e,t,n){"use strict";var r=n(2);e.exports=r.isStandardBrowserEnv()?function(){function e(e){var t=e;return n&&(o.setAttribute("href",t),t=o.href),o.setAttribute("href",t),{href:o.href,protocol:o.protocol?o.protocol.replace(/:$/,""):"",host:o.host,search:o.search?o.search.replace(/^\?/,""):"",hash:o.hash?o.hash.replace(/^#/,""):"",hostname:o.hostname,port:o.port,pathname:"/"===o.pathname.charAt(0)?o.pathname:"/"+o.pathname}}var t,n=/(msie|trident)/i.test(navigator.userAgent),o=document.createElement("a");return t=e(window.location.href),function(n){var o=r.isString(n)?e(n):n;return o.protocol===t.protocol&&o.host===t.host}}():function(){return function(){return!0}}()},function(e,t){"use strict";function n(){this.message="String contains an invalid character"}function r(e){for(var t,r,i=String(e),s="",u=0,a=o;i.charAt(0|u)||(a="=",u%1);s+=a.charAt(63&t>>8-u%1*8)){if(r=i.charCodeAt(u+=.75),r>255)throw new n;t=t<<8|r}return s}var o="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";n.prototype=new Error,n.prototype.code=5,n.prototype.name="InvalidCharacterError",e.exports=r},function(e,t,n){"use strict";var r=n(2);e.exports=r.isStandardBrowserEnv()?function(){return{write:function(e,t,n,o,i,s){var u=[];u.push(e+"="+encodeURIComponent(t)),r.isNumber(n)&&u.push("expires="+new Date(n).toGMTString()),r.isString(o)&&u.push("path="+o),r.isString(i)&&u.push("domain="+i),s===!0&&u.push("secure"),document.cookie=u.join("; ")},read:function(e){var t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove:function(e){this.write(e,"",Date.now()-864e5)}}}():function(){return{write:function(){},read:function(){return null},remove:function(){}}}()},function(e,t,n){"use strict";function r(){this.handlers=[]}var o=n(2);r.prototype.use=function(e,t){return this.handlers.push({fulfilled:e,rejected:t}),this.handlers.length-1},r.prototype.eject=function(e){this.handlers[e]&&(this.handlers[e]=null)},r.prototype.forEach=function(e){o.forEach(this.handlers,function(t){null!==t&&e(t)})},e.exports=r},function(e,t,n){"use strict";function r(e){e.cancelToken&&e.cancelToken.throwIfRequested()}var o=n(2),i=n(19),s=n(20),u=n(6),a=n(21),c=n(22);e.exports=function(e){r(e),e.baseURL&&!a(e.url)&&(e.url=c(e.baseURL,e.url)),e.headers=e.headers||{},e.data=i(e.data,e.headers,e.transformRequest),e.headers=o.merge(e.headers.common||{},e.headers[e.method]||{},e.headers||{}),o.forEach(["delete","get","head","post","put","patch","common"],function(t){delete e.headers[t]});var t=e.adapter||u.adapter;return t(e).then(function(t){return r(e),t.data=i(t.data,t.headers,e.transformResponse),t},function(t){return s(t)||(r(e),t&&t.response&&(t.response.data=i(t.response.data,t.response.headers,e.transformResponse))),Promise.reject(t)})}},function(e,t,n){"use strict";var r=n(2);e.exports=function(e,t,n){return r.forEach(n,function(n){e=n(e,t)}),e}},function(e,t){"use strict";e.exports=function(e){return!(!e||!e.__CANCEL__)}},function(e,t){"use strict";e.exports=function(e){return/^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(e)}},function(e,t){"use strict";e.exports=function(e,t){return t?e.replace(/\/+$/,"")+"/"+t.replace(/^\/+/,""):e}},function(e,t){"use strict";function n(e){this.message=e}n.prototype.toString=function(){return"Cancel"+(this.message?": "+this.message:"")},n.prototype.__CANCEL__=!0,e.exports=n},function(e,t,n){"use strict";function r(e){if("function"!=typeof e)throw new TypeError("executor must be a function.");var t;this.promise=new Promise(function(e){t=e});var n=this;e(function(e){n.reason||(n.reason=new o(e),t(n.reason))})}var o=n(23);r.prototype.throwIfRequested=function(){if(this.reason)throw this.reason},r.source=function(){var e,t=new r(function(t){e=t});return{token:t,cancel:e}},e.exports=r},function(e,t){"use strict";e.exports=function(e){return function(t){return e.apply(null,t)}}}])});
//# sourceMappingURL=axios.min.map
!function e(t,n,o){function r(a,s){if(!n[a]){if(!t[a]){var l="function"==typeof require&&require;if(!s&&l)return l(a,!0);if(i)return i(a,!0);var u=new Error("Cannot find module '"+a+"'");throw u.code="MODULE_NOT_FOUND",u}var d=n[a]={exports:{}};t[a][0].call(d.exports,function(e){var n=t[a][1][e];return r(n||e)},d,d.exports,e,t,n,o)}return n[a].exports}for(var i="function"==typeof require&&require,a=0;a<o.length;a++)r(o[a]);return r}({1:[function(e,t,n){t.exports=e("./lib/axios")},{"./lib/axios":3}],2:[function(e,t,n){(function(n){"use strict";var o=e("./../utils"),r=e("./../core/settle"),i=e("./../helpers/buildURL"),a=e("./../helpers/parseHeaders"),s=e("./../helpers/isURLSameOrigin"),l=e("../core/createError"),u="undefined"!=typeof window&&window.btoa&&window.btoa.bind(window)||e("./../helpers/btoa");t.exports=function(t){return new Promise(function(d,c){var h=t.data,p=t.headers;o.isFormData(h)&&delete p["Content-Type"];var f=new XMLHttpRequest,y="onreadystatechange",m=!1;if("test"===n.env.NODE_ENV||"undefined"==typeof window||!window.XDomainRequest||"withCredentials"in f||s(t.url)||(f=new window.XDomainRequest,y="onload",m=!0,f.onprogress=function(){},f.ontimeout=function(){}),t.auth){var v=t.auth.username||"",g=t.auth.password||"";p.Authorization="Basic "+u(v+":"+g)}if(f.open(t.method.toUpperCase(),i(t.url,t.params,t.paramsSerializer),!0),f.timeout=t.timeout,f[y]=function(){if(f&&(4===f.readyState||m)&&(0!==f.status||f.responseURL&&0===f.responseURL.indexOf("file:"))){var e="getAllResponseHeaders"in f?a(f.getAllResponseHeaders()):null,n=t.responseType&&"text"!==t.responseType?f.response:f.responseText,o={data:n,status:1223===f.status?204:f.status,statusText:1223===f.status?"No Content":f.statusText,headers:e,config:t,request:f};r(d,c,o),f=null}},f.onerror=function(){c(l("Network Error",t,null,f)),f=null},f.ontimeout=function(){c(l("timeout of "+t.timeout+"ms exceeded",t,"ECONNABORTED",f)),f=null},o.isStandardBrowserEnv()){var b=e("./../helpers/cookies"),j=(t.withCredentials||s(t.url))&&t.xsrfCookieName?b.read(t.xsrfCookieName):void 0;j&&(p[t.xsrfHeaderName]=j)}if("setRequestHeader"in f&&o.forEach(p,function(e,t){void 0===h&&"content-type"===t.toLowerCase()?delete p[t]:f.setRequestHeader(t,e)}),t.withCredentials&&(f.withCredentials=!0),t.responseType)try{f.responseType=t.responseType}catch(e){if("json"!==t.responseType)throw e}"function"==typeof t.onDownloadProgress&&f.addEventListener("progress",t.onDownloadProgress),"function"==typeof t.onUploadProgress&&f.upload&&f.upload.addEventListener("progress",t.onUploadProgress),t.cancelToken&&t.cancelToken.promise.then(function(e){f&&(f.abort(),c(e),f=null)}),void 0===h&&(h=null),f.send(h)})}}).call(this,e("_process"))},{"../core/createError":9,"./../core/settle":12,"./../helpers/btoa":16,"./../helpers/buildURL":17,"./../helpers/cookies":19,"./../helpers/isURLSameOrigin":21,"./../helpers/parseHeaders":23,"./../utils":25,_process:27}],3:[function(e,t,n){"use strict";function o(e){var t=new a(e),n=i(a.prototype.request,t);return r.extend(n,a.prototype,t),r.extend(n,t),n}var r=e("./utils"),i=e("./helpers/bind"),a=e("./core/Axios"),s=e("./defaults"),l=o(s);l.Axios=a,l.create=function(e){return o(r.merge(s,e))},l.Cancel=e("./cancel/Cancel"),l.CancelToken=e("./cancel/CancelToken"),l.isCancel=e("./cancel/isCancel"),l.all=function(e){return Promise.all(e)},l.spread=e("./helpers/spread"),t.exports=l,t.exports.default=l},{"./cancel/Cancel":4,"./cancel/CancelToken":5,"./cancel/isCancel":6,"./core/Axios":7,"./defaults":14,"./helpers/bind":15,"./helpers/spread":24,"./utils":25}],4:[function(e,t,n){"use strict";function o(e){this.message=e}o.prototype.toString=function(){return"Cancel"+(this.message?": "+this.message:"")},o.prototype.__CANCEL__=!0,t.exports=o},{}],5:[function(e,t,n){"use strict";function o(e){if("function"!=typeof e)throw new TypeError("executor must be a function.");var t;this.promise=new Promise(function(e){t=e});var n=this;e(function(e){n.reason||(n.reason=new r(e),t(n.reason))})}var r=e("./Cancel");o.prototype.throwIfRequested=function(){if(this.reason)throw this.reason},o.source=function(){var e;return{token:new o(function(t){e=t}),cancel:e}},t.exports=o},{"./Cancel":4}],6:[function(e,t,n){"use strict";t.exports=function(e){return!(!e||!e.__CANCEL__)}},{}],7:[function(e,t,n){"use strict";function o(e){this.defaults=e,this.interceptors={request:new a,response:new a}}var r=e("./../defaults"),i=e("./../utils"),a=e("./InterceptorManager"),s=e("./dispatchRequest");o.prototype.request=function(e){"string"==typeof e&&(e=i.merge({url:arguments[0]},arguments[1])),e=i.merge(r,this.defaults,{method:"get"},e),e.method=e.method.toLowerCase();var t=[s,void 0],n=Promise.resolve(e);for(this.interceptors.request.forEach(function(e){t.unshift(e.fulfilled,e.rejected)}),this.interceptors.response.forEach(function(e){t.push(e.fulfilled,e.rejected)});t.length;)n=n.then(t.shift(),t.shift());return n},i.forEach(["delete","get","head","options"],function(e){o.prototype[e]=function(t,n){return this.request(i.merge(n||{},{method:e,url:t}))}}),i.forEach(["post","put","patch"],function(e){o.prototype[e]=function(t,n,o){return this.request(i.merge(o||{},{method:e,url:t,data:n}))}}),t.exports=o},{"./../defaults":14,"./../utils":25,"./InterceptorManager":8,"./dispatchRequest":10}],8:[function(e,t,n){"use strict";function o(){this.handlers=[]}var r=e("./../utils");o.prototype.use=function(e,t){return this.handlers.push({fulfilled:e,rejected:t}),this.handlers.length-1},o.prototype.eject=function(e){this.handlers[e]&&(this.handlers[e]=null)},o.prototype.forEach=function(e){r.forEach(this.handlers,function(t){null!==t&&e(t)})},t.exports=o},{"./../utils":25}],9:[function(e,t,n){"use strict";var o=e("./enhanceError");t.exports=function(e,t,n,r,i){var a=new Error(e);return o(a,t,n,r,i)}},{"./enhanceError":11}],10:[function(e,t,n){"use strict";function o(e){e.cancelToken&&e.cancelToken.throwIfRequested()}var r=e("./../utils"),i=e("./transformData"),a=e("../cancel/isCancel"),s=e("../defaults"),l=e("./../helpers/isAbsoluteURL"),u=e("./../helpers/combineURLs");t.exports=function(e){return o(e),e.baseURL&&!l(e.url)&&(e.url=u(e.baseURL,e.url)),e.headers=e.headers||{},e.data=i(e.data,e.headers,e.transformRequest),e.headers=r.merge(e.headers.common||{},e.headers[e.method]||{},e.headers||{}),r.forEach(["delete","get","head","post","put","patch","common"],function(t){delete e.headers[t]}),(e.adapter||s.adapter)(e).then(function(t){return o(e),t.data=i(t.data,t.headers,e.transformResponse),t},function(t){return a(t)||(o(e),t&&t.response&&(t.response.data=i(t.response.data,t.response.headers,e.transformResponse))),Promise.reject(t)})}},{"../cancel/isCancel":6,"../defaults":14,"./../helpers/combineURLs":18,"./../helpers/isAbsoluteURL":20,"./../utils":25,"./transformData":13}],11:[function(e,t,n){"use strict";t.exports=function(e,t,n,o,r){return e.config=t,n&&(e.code=n),e.request=o,e.response=r,e}},{}],12:[function(e,t,n){"use strict";var o=e("./createError");t.exports=function(e,t,n){var r=n.config.validateStatus;n.status&&r&&!r(n.status)?t(o("Request failed with status code "+n.status,n.config,null,n.request,n)):e(n)}},{"./createError":9}],13:[function(e,t,n){"use strict";var o=e("./../utils");t.exports=function(e,t,n){return o.forEach(n,function(n){e=n(e,t)}),e}},{"./../utils":25}],14:[function(e,t,n){(function(n){"use strict";function o(e,t){!r.isUndefined(e)&&r.isUndefined(e["Content-Type"])&&(e["Content-Type"]=t)}var r=e("./utils"),i=e("./helpers/normalizeHeaderName"),a={"Content-Type":"application/x-www-form-urlencoded"},s={adapter:function(){var t;return"undefined"!=typeof XMLHttpRequest?t=e("./adapters/xhr"):void 0!==n&&(t=e("./adapters/http")),t}(),transformRequest:[function(e,t){return i(t,"Content-Type"),r.isFormData(e)||r.isArrayBuffer(e)||r.isBuffer(e)||r.isStream(e)||r.isFile(e)||r.isBlob(e)?e:r.isArrayBufferView(e)?e.buffer:r.isURLSearchParams(e)?(o(t,"application/x-www-form-urlencoded;charset=utf-8"),e.toString()):r.isObject(e)?(o(t,"application/json;charset=utf-8"),JSON.stringify(e)):e}],transformResponse:[function(e){if("string"==typeof e)try{e=JSON.parse(e)}catch(e){}return e}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,validateStatus:function(e){return e>=200&&e<300}};s.headers={common:{Accept:"application/json, text/plain, */*"}},r.forEach(["delete","get","head"],function(e){s.headers[e]={}}),r.forEach(["post","put","patch"],function(e){s.headers[e]=r.merge(a)}),t.exports=s}).call(this,e("_process"))},{"./adapters/http":2,"./adapters/xhr":2,"./helpers/normalizeHeaderName":22,"./utils":25,_process:27}],15:[function(e,t,n){"use strict";t.exports=function(e,t){return function(){for(var n=new Array(arguments.length),o=0;o<n.length;o++)n[o]=arguments[o];return e.apply(t,n)}}},{}],16:[function(e,t,n){"use strict";function o(){this.message="String contains an invalid character"}function r(e){for(var t,n,r=String(e),a="",s=0,l=i;r.charAt(0|s)||(l="=",s%1);a+=l.charAt(63&t>>8-s%1*8)){if((n=r.charCodeAt(s+=.75))>255)throw new o;t=t<<8|n}return a}var i="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";o.prototype=new Error,o.prototype.code=5,o.prototype.name="InvalidCharacterError",t.exports=r},{}],17:[function(e,t,n){"use strict";function o(e){return encodeURIComponent(e).replace(/%40/gi,"@").replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}var r=e("./../utils");t.exports=function(e,t,n){if(!t)return e;var i;if(n)i=n(t);else if(r.isURLSearchParams(t))i=t.toString();else{var a=[];r.forEach(t,function(e,t){null!==e&&void 0!==e&&(r.isArray(e)&&(t+="[]"),r.isArray(e)||(e=[e]),r.forEach(e,function(e){r.isDate(e)?e=e.toISOString():r.isObject(e)&&(e=JSON.stringify(e)),a.push(o(t)+"="+o(e))}))}),i=a.join("&")}return i&&(e+=(-1===e.indexOf("?")?"?":"&")+i),e}},{"./../utils":25}],18:[function(e,t,n){"use strict";t.exports=function(e,t){return t?e.replace(/\/+$/,"")+"/"+t.replace(/^\/+/,""):e}},{}],19:[function(e,t,n){"use strict";var o=e("./../utils");t.exports=o.isStandardBrowserEnv()?function(){return{write:function(e,t,n,r,i,a){var s=[];s.push(e+"="+encodeURIComponent(t)),o.isNumber(n)&&s.push("expires="+new Date(n).toGMTString()),o.isString(r)&&s.push("path="+r),o.isString(i)&&s.push("domain="+i),!0===a&&s.push("secure"),document.cookie=s.join("; ")},read:function(e){var t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove:function(e){this.write(e,"",Date.now()-864e5)}}}():function(){return{write:function(){},read:function(){return null},remove:function(){}}}()},{"./../utils":25}],20:[function(e,t,n){"use strict";t.exports=function(e){return/^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(e)}},{}],21:[function(e,t,n){"use strict";var o=e("./../utils");t.exports=o.isStandardBrowserEnv()?function(){function e(e){var t=e;return n&&(r.setAttribute("href",t),t=r.href),r.setAttribute("href",t),{href:r.href,protocol:r.protocol?r.protocol.replace(/:$/,""):"",host:r.host,search:r.search?r.search.replace(/^\?/,""):"",hash:r.hash?r.hash.replace(/^#/,""):"",hostname:r.hostname,port:r.port,pathname:"/"===r.pathname.charAt(0)?r.pathname:"/"+r.pathname}}var t,n=/(msie|trident)/i.test(navigator.userAgent),r=document.createElement("a");return t=e(window.location.href),function(n){var r=o.isString(n)?e(n):n;return r.protocol===t.protocol&&r.host===t.host}}():function(){return function(){return!0}}()},{"./../utils":25}],22:[function(e,t,n){"use strict";var o=e("../utils");t.exports=function(e,t){o.forEach(e,function(n,o){o!==t&&o.toUpperCase()===t.toUpperCase()&&(e[t]=n,delete e[o])})}},{"../utils":25}],23:[function(e,t,n){"use strict";var o=e("./../utils"),r=["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"];t.exports=function(e){var t,n,i,a={};return e?(o.forEach(e.split("\n"),function(e){if(i=e.indexOf(":"),t=o.trim(e.substr(0,i)).toLowerCase(),n=o.trim(e.substr(i+1)),t){if(a[t]&&r.indexOf(t)>=0)return;a[t]="set-cookie"===t?(a[t]?a[t]:[]).concat([n]):a[t]?a[t]+", "+n:n}}),a):a}},{"./../utils":25}],24:[function(e,t,n){"use strict";t.exports=function(e){return function(t){return e.apply(null,t)}}},{}],25:[function(e,t,n){"use strict";function o(e){return"[object Array]"===C.call(e)}function r(e){return"[object ArrayBuffer]"===C.call(e)}function i(e){return"undefined"!=typeof FormData&&e instanceof FormData}function a(e){return"undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(e):e&&e.buffer&&e.buffer instanceof ArrayBuffer}function s(e){return"string"==typeof e}function l(e){return"number"==typeof e}function u(e){return void 0===e}function d(e){return null!==e&&"object"==typeof e}function c(e){return"[object Date]"===C.call(e)}function h(e){return"[object File]"===C.call(e)}function p(e){return"[object Blob]"===C.call(e)}function f(e){return"[object Function]"===C.call(e)}function y(e){return d(e)&&f(e.pipe)}function m(e){return"undefined"!=typeof URLSearchParams&&e instanceof URLSearchParams}function v(e){return e.replace(/^\s*/,"").replace(/\s*$/,"")}function g(){return("undefined"==typeof navigator||"ReactNative"!==navigator.product)&&("undefined"!=typeof window&&"undefined"!=typeof document)}function b(e,t){if(null!==e&&void 0!==e)if("object"!=typeof e&&(e=[e]),o(e))for(var n=0,r=e.length;n<r;n++)t.call(null,e[n],n,e);else for(var i in e)Object.prototype.hasOwnProperty.call(e,i)&&t.call(null,e[i],i,e)}function j(){function e(e,n){"object"==typeof t[n]&&"object"==typeof e?t[n]=j(t[n],e):t[n]=e}for(var t={},n=0,o=arguments.length;n<o;n++)b(arguments[n],e);return t}function E(e,t,n){return b(t,function(t,o){e[o]=n&&"function"==typeof t?w(t,n):t}),e}var w=e("./helpers/bind"),A=e("is-buffer"),C=Object.prototype.toString;t.exports={isArray:o,isArrayBuffer:r,isBuffer:A,isFormData:i,isArrayBufferView:a,isString:s,isNumber:l,isObject:d,isUndefined:u,isDate:c,isFile:h,isBlob:p,isFunction:f,isStream:y,isURLSearchParams:m,isStandardBrowserEnv:g,forEach:b,merge:j,extend:E,trim:v}},{"./helpers/bind":15,"is-buffer":26}],26:[function(e,t,n){function o(e){return!!e.constructor&&"function"==typeof e.constructor.isBuffer&&e.constructor.isBuffer(e)}function r(e){return"function"==typeof e.readFloatLE&&"function"==typeof e.slice&&o(e.slice(0,0))}t.exports=function(e){return null!=e&&(o(e)||r(e)||!!e._isBuffer)}},{}],27:[function(e,t,n){function o(){throw new Error("setTimeout has not been defined")}function r(){throw new Error("clearTimeout has not been defined")}function i(e){if(c===setTimeout)return setTimeout(e,0);if((c===o||!c)&&setTimeout)return c=setTimeout,setTimeout(e,0);try{return c(e,0)}catch(t){try{return c.call(null,e,0)}catch(t){return c.call(this,e,0)}}}function a(e){if(h===clearTimeout)return clearTimeout(e);if((h===r||!h)&&clearTimeout)return h=clearTimeout,clearTimeout(e);try{return h(e)}catch(t){try{return h.call(null,e)}catch(t){return h.call(this,e)}}}function s(){m&&f&&(m=!1,f.length?y=f.concat(y):v=-1,y.length&&l())}function l(){if(!m){var e=i(s);m=!0;for(var t=y.length;t;){for(f=y,y=[];++v<t;)f&&f[v].run();v=-1,t=y.length}f=null,m=!1,a(e)}}function u(e,t){this.fun=e,this.array=t}function d(){}var c,h,p=t.exports={};!function(){try{c="function"==typeof setTimeout?setTimeout:o}catch(e){c=o}try{h="function"==typeof clearTimeout?clearTimeout:r}catch(e){h=r}}();var f,y=[],m=!1,v=-1;p.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)t[n-1]=arguments[n];y.push(new u(e,t)),1!==y.length||m||i(l)},u.prototype.run=function(){this.fun.apply(null,this.array)},p.title="browser",p.browser=!0,p.env={},p.argv=[],p.version="",p.versions={},p.on=d,p.addListener=d,p.once=d,p.off=d,p.removeListener=d,p.removeAllListeners=d,p.emit=d,p.prependListener=d,p.prependOnceListener=d,p.listeners=function(e){return[]},p.binding=function(e){throw new Error("process.binding is not supported")},p.cwd=function(){return"/"},p.chdir=function(e){throw new Error("process.chdir is not supported")},p.umask=function(){return 0}},{}],28:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("./helper"),i=function(){function e(e){this.changeCallback=e}return e.prototype.set=function(e,t){var n=this[e];if(this.changeCallback&&n!==t){return!1!==this.changeCallback.apply(this,[e,t,n])&&(this[e]=t,!0)}},e.prototype.get=function(e){return this[e]},e.prototype.init=function(e){var t=this;for(var n in this)this.hasOwnProperty(n)||"function"==typeof this[n]||delete this[n];return Object.keys(e||{}).forEach(function(n){t[n]=e[n]}),this},e}();n.Configuration=i;var a=function(e){function t(){var t=e.call(this)||this;t.isInitialized=!1;var n=Array.prototype.slice.call(arguments);return t.created&&t.created.apply(t,n),t}return o(t,e),t.prototype.fireEvent=function(e,t,n,o){return void 0===t&&(t=null),void 0===n&&(n=!1),void 0===o&&(o=!1),r.default.fireEvent(this,e,t,n,o)},t.prototype.executeAction=function(e,t,n){return void 0===t&&(t=null),r.default.executeAction(e,t,n,this)},t.prototype.callUserCallback=function(e,t,n){void 0===n&&(n=!0);var o=this,r=this[e];n?setTimeout(function(){r&&r.apply(o,t)}):r&&r.apply(o,t)},t.prototype.getType=function(){},t.prototype.initializeElement=function(){},t.prototype.attributeChangedCallback=function(e,t,n){var o=Array.prototype.slice.call(arguments);this.fireEvent("attributeChanged",{name:e,oldVal:t,newVal:n}),this.callUserCallback("attributeChanged",o)},t.prototype.connectedCallback=function(){if(!this.isInitialized){var e=this.getType();e&&this.setAttribute("j-type",e),this.initializeElement(),this.fireEvent("initialized"),this.callUserCallback("initialized"),this.isInitialized=!0}this.fireEvent("connected"),this.callUserCallback("connected")},t.prototype.disconnectedCallback=function(){this.fireEvent("disconnected"),this.callUserCallback("disconnected")},t}(HTMLElement);n.HtmlElement=a;var s=function(e){function t(){var t=e.call(this)||this;return t.useShadow=!1,t.elementContent=t,t}return o(t,e),t.prototype.createShadowRoot=function(){return this.attachShadow.apply(this,[{mode:"open"}])},t.prototype.attributeChangedCallback=function(t,n,o){if("template"==t&&o){document.querySelector(o)}e.prototype.attributeChangedCallback.call(this,t,n,o)},t.prototype.addToSlot=function(e,t){if(void 0===t&&(t=!1),this.useShadow)return this.elementContent.appendChild(e);var n=e.getAttribute("slot"),o=this.elementContent.querySelector("slot[name="+n+"]");if(o){var r=o.parentElement;return r?r.replaceChild(e,o):o.appendChild(e),e}return t?this.elementContent.appendChild(e):void 0},t.prototype.getDefaultTemplate=function(){return this.getAttribute("default-template")?document.querySelector("template#"+this.getAttribute("default-template")):void 0},t.prototype.locateTemplate=function(){var e;return this.getAttribute("template")&&(e=document.querySelector("template#"+this.getAttribute("template"))),this.getAttribute("remote-template"),e||(e=this.querySelector("template")),e||(e=document.querySelector("template#"+this.tagName.toLowerCase())),e||(e=this.getDefaultTemplate()),e},t.prototype.createChildren=function(e){if(this.template=this.template||this.locateTemplate(),this.template){var t=document.importNode(this.template.content,!0);e.appendChild(t)}},t.prototype.connectedCallback=function(){this.isInitialized||(this.useShadow="true"==this.getAttribute("j-attach-shadow"),this.elementContent=this.useShadow?this.createShadowRoot():this,this.createChildren(this.elementContent)),e.prototype.connectedCallback.call(this)},t}(a);n.TemplatedElement=s;var l=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.locateTemplate=function(){var t=this.template||e.prototype.locateTemplate.call(this);return!t&&this.component&&(t=this.component.template),t},t.prototype.initializeElement=function(){},t.prototype.connectedCallback=function(){this.isInitialized||(this.component=this.component||d.getByTag(this.tagName.toLowerCase()),this.component&&this.component.initElement(this)),e.prototype.connectedCallback.call(this)},t}(s);n.ComponentGeneratedElement=l;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(l);n.ComponentElement=u;var d=function(e){function t(){var n=e.call(this)||this;return n.elementRegistered=!1,n.defineScriptExecuted=!1,n.options={},n.elementTag&&(t.definedElements[n.elementTag]=n),r.default.fireEvent(window,"jdash:component.created",{component:n}),n}return o(t,e),t.prototype.locateTemplate=function(){return this.querySelector("template")},Object.defineProperty(t.prototype,"template",{get:function(){return this._template||(this._template=this.locateTemplate())},enumerable:!0,configurable:!0}),t.prototype.initElement=function(e,n){n=n||{};for(var o=0;o<this.attributes.length;o++){var r=this.attributes[o];if(!(t.reservedAttributes.indexOf(r.name)>=0)){var i=n[r.name]||r.value;e.getAttribute(r.name)||e.setAttribute(r.name,i)}}return Object.keys(n).forEach(function(t){if(e.getAttribute(t))e.setAttribute(t,n[t]);else{var o=t;e.setAttribute(o,n[t])}}),e},t.getByTag=function(e){return t.definedElements[e]},t.locate=function(e){var n=null;if("object"==typeof e&&e.is){var o=e.is;n=t.getByTag(o)}else if("string"==typeof e)n=t.getByTag(o);else{var r=document._currentScript||document.currentScript;n=r?r.parentElement:void 0}return n},t.prototype.setElementClassProperties=function(){this.elementClass.prototype.component=this,this.options.createdCallback&&(this.elementClass.prototype.created=this.options.createdCallback)},t.prototype.getBaseElementClass=function(){return u},t.prototype.generateElementClass=function(){var e=this.options&&this.options.elementClass||this.getBaseElementClass();return r.default.inherit(e)},t.prototype.registerElement=function(){var e=this.elementTag;if(!e)throw new Error("Element tag should be set using id, name, is attribute or calling jdash.define with options.is");this.elementClass=this.generateElementClass(),this.setElementClassProperties(),t.definedElements[e]=this,window.customElements.get(e)||window.customElements.define(e,this.elementClass),this.elementRegistered=!0},t.prototype.connectedCallback=function(){r.default.fireEvent(window,"jdash:component.connected",{component:this}),"true"==this.getAttribute("delay-register")||this.elementRegistered||this.registerElement(),e.prototype.connectedCallback.call(this)},t.prototype.runDefineScript=function(e){if(!this.defineScriptExecuted){if(this.options=e,this.elementRegistered){if(this.setElementClassProperties(),this.options.elementClass)throw new Error("Element already registered. Please add delay-register attribute to set a different element class")}else this.registerElement();this.defineScriptExecuted=!0}},t.elementTag=function(e){return e.id||e.getAttribute("name")||e.getAttribute("is")},Object.defineProperty(t.prototype,"elementTag",{get:function(){return this.options&&this.options.is||t.elementTag(this)},enumerable:!0,configurable:!0}),t.define=function(e,n){var o=arguments,r=t.locate(e),i={};1==o.length?"string"==typeof e?i.is=e:"function"==typeof e?i.createdCallback=e:"object"==typeof e&&(i=e):2==o.length&&(i.is=e,"function"==typeof n?i.createdCallback=n:"object"==typeof n&&(i.elementClass=n.elementClass,i.createdCallback=n.createdCallback));var a=i.is||r&&t.elementTag(r);if(!a)throw new Error("Need an element tag either by id or functions arguments");window.customElements.whenDefined("j-component").then(function(e){(r=r||t.getByTag(a))&&r.runDefineScript&&r.runDefineScript(i)}),window.addEventListener("jdash:component.created",function(e){(r=r||t.getByTag(a))&&(r==e.detail.component||i.is==r.elementTag)&&r.runDefineScript&&r.runDefineScript(i)}),window.addEventListener("jdash:component.connected",function(e){(r=r||t.getByTag(a))!=e.detail.component&&e.detail.component.elementTag!=i.is||(r=e.detail.component,r.runDefineScript&&r.runDefineScript(i))})},t.definedElements={},t.reservedAttributes=["id","name","is"],t}(a);n.Component=d},{"./helper":35}],29:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../core"),i=e("../helper"),a=e("../helper");n.IDashletElementStatus={created:"created",loaded:"loaded"},n.DashletViewMode={readonly:"readonly",configure:"configure",preview:"preview"};var s=function(){function e(){}return e}();n.DashletContext=s;var l=function(e){function t(){var t=e.call(this)||this;return t.status=n.IDashletElementStatus.created,t._viewMode=n.DashletViewMode.readonly,t._configObject=new r.Configuration(function(e,n,o){t.executeAction("configitemupdated",{key:e,newVal:n,oldVal:o})}),t}return o(t,e),Object.defineProperty(t.prototype,"canBeConfigured",{get:function(){var e=this.getAttribute("j-editor")||this.tagName.toLowerCase()+"-editor";return"none"!=e&&window.customElements.get(e)},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"model",{get:function(){return this._model},set:function(e){e.id?(this.id=this.id||e.id,this.setAttribute("j-provider-id",e.id)):this.removeAttribute("j-provider-id"),this.config=e.configuration,this.title=e.title,this._model=e},enumerable:!0,configurable:!0}),t.prototype.updateFromModel=function(){this.model&&(this.id=this.id||this.model.id,this.setAttribute("j-provider-id",this.model.id),this.title=this.model.title,this.config=this.model.configuration)},t.prototype.updateModel=function(){if(this.model){var e=this.getAttribute("j-provider-id")||this.id;e&&(this.model.id=e),this.model.configuration=this.config,this.model.title=this.title}},Object.defineProperty(t.prototype,"panel",{get:function(){return this._panel||i.default.getContainingType(this,"j-dashlet-panel")},set:function(e){this._panel=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"Provider",{get:function(){return this._provider?this._provider:(this.layout&&this.layout.dashboard&&this.layout.dashboard.provider&&(this._provider=this.layout.dashboard.provider),this._provider)},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"viewMode",{get:function(){return this._viewMode},set:function(e){this.viewMode!=e&&(this._viewMode=e,this.setAttribute("j-view-mode",e))},enumerable:!0,configurable:!0}),t.prototype.getType=function(){return"j-dashlet"},t.prototype.setViewMode=function(e){switch(this.panel&&this.panel.setAttribute("j-view-mode",e),e){case n.DashletViewMode.readonly:this.setDashletViewModeConfigure(!1),this.setDashletViewModePreview(!1),this.setDashletViewModeReadonly(!0);break;case n.DashletViewMode.configure:this.setDashletViewModePreview(!1),this.setDashletViewModeReadonly(!1),this.setDashletViewModeConfigure(!0);break;case n.DashletViewMode.preview:this.setDashletViewModeConfigure(!1),this.setDashletViewModeReadonly(!1),this.setDashletViewModePreview(!0)}this.arrangeTitleNodes()},t.prototype.setDashletViewModeReadonly=function(e){},t.prototype.setDashletViewModePreview=function(e){},t.prototype.setDashletViewModeConfigure=function(e){var t=this,n=this.panel||this,o=n.querySelector('[j-type="j-dashlet-configuration-tools"]:not(template)'),r=i.default.locateTemplate(this,"j-dashlet-configuration-tools",!0);e?o?i.default.hideElements(o,!1):r&&i.default.instantiateTemplate(r,o,{position:a.TemplateInstantiatePosition.insert,preProcess:function(e,n){i.default.bindActions(e,{zone:n},t),i.default.setBindings(e),o&&i.default.hideElements(o,!1)}}):(r&&i.default.removeTemplateInstances(n,r),o&&i.default.hideElements(o,!0));var s=n.querySelectorAll('[j-action="configuredashlet"]');i.default.hideElements(s,!this.canBeConfigured)},Object.defineProperty(t.prototype,"config",{get:function(){return this._configObject},set:function(e){var t=this._configObject;if(e instanceof r.Configuration){if(e===t)return;this._configObject=e}else this._configObject.init(e)},enumerable:!0,configurable:!0}),t.prototype.configurationChangeHandler=function(e){},t.prototype.configurationSaveHandler=function(e){},t.prototype.getDashletSize=function(){return this.getBoundingClientRect()},t.prototype.saveConfiguration=function(){var e=this;return this.Provider?this.Provider.saveDashlet(this.getAttribute("j-provider-id")||this.id,{configuration:this.config}).then(function(){var t={};e.executeAction("configsaved",t);e.callUserCallback("loadConfig",[],!1)}):Promise.reject("no provider")},Object.defineProperty(t,"observedAttributes",{get:function(){return["disabled","title","j-view-mode","j-zone","j-x","j-y","j-z"]},enumerable:!0,configurable:!0}),t.prototype.createPanelForDashletEditor=function(e){var t=e.getAttribute("j-panel")||"j-dashlet-editor-panel";if(t&&"none"!=t){var n=document.createElement(t);return n.setAttribute("j-type","j-dashlet-editor-panel"),n.editor=e,n}var o=document.createElement("div");return o.setAttribute("j-type","j-dashlet-editor-panel"),o.editor=e,o.appendChild(e),o},t.prototype.openConfiguration=function(){var e=this.getAttribute("j-editor")||this.tagName.toLowerCase()+"-editor",t=document.createElement(e),n=this.createPanelForDashletEditor(t);t.panel=n,t.dashlet=this,n.classList.add(e),this.editor=t,this.appendChild(n)},t.prototype.configureDashletActionHandler=function(e){return this.openConfiguration()},t.prototype.cloneDashletActionHandler=function(e){return this.layout&&this.layout.cloneDashlet(this)},t.prototype.removeDashletActionHandler=function(e){return this.layout&&this.layout.removeDashlet(this)},t.prototype.arrangeTitleNodes=function(){var e=this.panel||this,t=i.default.locateTemplate(this,"j-dashlet-header",!0);if(t)i.default.removeTemplateInstances(e,t),"readonly"!=this.viewMode?i.default.instantiateTemplate(t):this.title&&""!=this.title.trim()&&i.default.instantiateTemplate(t);else for(var n=e.querySelectorAll('[j-type="j-dashlet-title"]'),o=0;o<n.length;o++){var r=n[o];this.title?(r.textContent=this.title,r.style.display=""):(r.style.display="none",r.textContent="")}this.title?e.classList.remove("j-no-title"):e.classList.add("j-no-title"),i.default.setBindings(e,this,'[j-bind][j-type="j-dashlet-title"]')},t.prototype.editDashletTitleActionHandler=function(e){var t=this,n=prompt("Title",this.title);if(null!==n){var o=this.getAttribute("j-provider-id")||this.id;this.Provider?e.detail.$waitFor=this.Provider.saveDashlet(o,{title:n}).then(function(){t.title=n,t.arrangeTitleNodes()}):this.title=n}},t.prototype.listenforActions=function(){i.default.addActionListener("configuredashlet",this.configureDashletActionHandler.bind(this),this),i.default.addActionListener("clonedashlet",this.cloneDashletActionHandler.bind(this),this),i.default.addActionListener("removedashlet",this.removeDashletActionHandler.bind(this),this),i.default.addActionListener("setdashlettitle",this.editDashletTitleActionHandler.bind(this),this),i.default.addActionListener("configurationchange",this.configurationChangeHandler.bind(this),this),i.default.addActionListener("configurationsave",this.configurationSaveHandler.bind(this),this)},t.prototype.initializeElement=function(){e.prototype.initializeElement.call(this),this.setViewMode(this.viewMode),this.listenforActions(),this.arrangeTitleNodes(),this.panel&&this.panel.classList.add(this.tagName.toLowerCase()+"-panel"),
i.default.setBindings(this.panel||this,this),this.model&&(this.title=this.model.title),this.callUserCallback("loadConfig",[],!1)},t.prototype.attributeChangedCallback=function(t,n,o){"title"==t&&this.isInitialized&&this.arrangeTitleNodes(),"j-view-mode"==t&&(this._viewMode=o,this.isInitialized&&this.setViewMode(o)),e.prototype.attributeChangedCallback.call(this,t,n,o)},t}(r.ComponentGeneratedElement);n.Dashlet=l;var u=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(r.ComponentGeneratedElement);n.DashletEditor=u;var d=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.getBaseElementClass=function(){return u},t}(r.Component);n.DashletEditorModule=d;var c=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.getBaseElementClass=function(){return l},t.getModules=function(){var e=this.definedElements,n=[];return Object.keys(e).forEach(function(o){var r=e[o];r instanceof t&&n.push(r)}),n},t.getByTag=function(e){return r.Component.definedElements[e]},t.prototype.createEditorForDashlet=function(e){},t.createModule=function(e,t){var n=document.createElement("j-dashlet");return n.id="string"==typeof e?e:e.tagName.toLowerCase(),n},t}(r.Component);n.DashletModule=c},{"../core":28,"../helper":35}],30:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../core"),i=e("../helper"),a=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.closeEditor=function(e){this.remove(),this.editor.dashlet.editor=void 0},t.prototype.getType=function(){return"j-dashlet-editor-panel"},t.prototype.closeEditorActionHandler=function(e){this.closeEditor(!0)},t.prototype.saveConfigActionHandler=function(e){var t=this,n=e.detail||{};n.$waitFor=this.editor.dashlet.saveConfiguration(),Promise.resolve(n.$waitFor).then(function(e){0!=e&&t.closeEditor(!1)})},t.prototype.showEditor=function(){i.default.getFirstElementChild(this).style.display="block"},t.prototype.initializeElement=function(){i.default.addActionListener("closeeditor",this.closeEditorActionHandler.bind(this),this.editor),i.default.addActionListener("setconfig",this.saveConfigActionHandler.bind(this),this.editor),this.showEditor()},t.prototype.createChildren=function(t){e.prototype.createChildren.call(this,t),this.editor&&(this.editor.setAttribute("slot","body"),this.addToSlot(this.editor,!0),i.default.setBindings(this,this.editor.dashlet)),i.default.bindActions(this,{dashlet:this.editor.dashlet},this.editor)},t}(r.ComponentGeneratedElement);n.DashletEditorPanel=a;var s=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.getBaseElementClass=function(){return a},t}(r.Component);n.DashletEditorPanelModule=s},{"../core":28,"../helper":35}],31:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../core"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),Object.defineProperty(t.prototype,"dashlet",{get:function(){return this._dashlet||this.querySelector('[j-type="j-dashlet-"]')},set:function(e){this._dashlet=e},enumerable:!0,configurable:!0}),t.prototype.createChildren=function(t){e.prototype.createChildren.call(this,t),this.dashlet&&(this.dashlet.setAttribute("slot","body"),this.addToSlot(this.dashlet,!0))},t.prototype.getType=function(){return"j-dashlet-panel"},t}(r.ComponentGeneratedElement);n.DashletPanel=i;var a=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.getBaseElementClass=function(){return i},t}(r.Component);n.DashletPanelModule=a},{"../core":28}],32:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../../helper"),i=e("../dashleteditorpanel"),a=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.closeEditor=function(e){this.editor.dashlet.editor=void 0},t.prototype.initializeElement=function(){e.prototype.initializeElement.call(this)},t.prototype.showEditor=function(){var e=window.$(r.default.getFirstElementChild(this)).modal("show");e.on("hidden.bs.modal",function(){this.remove(),this.editor.dashlet.style.position=""}.bind(this)),e.on("hidden",function(){this.remove(),this.editor.dashlet.panel.style.position=""}.bind(this));var t=window.$(".modal-backdrop");t.appendTo(this.editor.dashlet),t.css({position:"absolute","border-radius":"10px"}),window.$("body").removeClass("modal-open"),this.editor.dashlet.panel.style.position="relative"},t}(i.DashletEditorPanel);n.BsDashletEditorPanel=a},{"../../helper":35,"../dashleteditorpanel":30}],33:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../dashletpanel"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(r.DashletPanel);n.BsDashletPanel=i},{"../dashletpanel":31}],34:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../jdash"),i=e("./dashlet"),a=e("../core"),s=e("../layout"),l=e("../helper");n.DashboardState={none:"none",loading:"loading",loaded:"loaded"};var u=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._state=n.DashboardState.none,t}return o(t,e),Object.defineProperty(t,"observedAttributes",{get:function(){return["j-provider","j-provider-id","j-layout","j-view-mode","title"]},enumerable:!0,configurable:!0}),t.prototype.getType=function(){return"j-dashboard"},Object.defineProperty(t.prototype,"state",{get:function(){return this._state},set:function(e){var t=this._state;this._state=e,this.fireEvent("state-change",{newVal:e,oldVal:t})},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"provider",{get:function(){if(!this._provider){var e=this.locateProvider();e&&(this._provider=e)}return this._provider},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"model",{get:function(){return this._model},set:function(e){e?(e.id?(this.id=this.id||e.id,this.setAttribute("j-provider-id",e.id)):this.removeAttribute("j-provider-id"),this.title=e.title):(this.title="",this.removeAttribute("j-provider-id")),this._model=e,l.default.setBindings(this)},enumerable:!0,configurable:!0}),t.prototype.initializeLayout=function(){this._layout.dashboard=this;var e=this.getAttribute("j-view-mode");e&&(this.layout.viewMode=e);var t=this.getAttribute("j-layout-style");t&&(this.layout.layoutStyle=t),this.fireEvent("layout-ready")},Object.defineProperty(t.prototype,"layout",{get:function(){return this._layout},set:function(e){this._layout!=e&&(this._layout=e,this.initializeLayout())},enumerable:!0,configurable:!0}),t.prototype.unload=function(){this.layout.reset(),this.model=void 0,l.default.setBindings(this),this.state=n.DashboardState.none},t.prototype.load=function(e){var t=this;return this.state==n.DashboardState.loaded&&this.unload(),this.state==n.DashboardState.loading?Promise.reject(new Error("Loading not completed")):(this.state=n.DashboardState.loading,this.provider.getDashboard("string"==typeof e?e:e.id).then(function(e){return t.model=e.dashboard,Promise.resolve(t.layout.load(t.model.layout,e.dashlets)).then(function(){return t.state=n.DashboardState.loaded,e.dashboard})}).catch(function(e){return t.state=n.DashboardState.none,Promise.reject(e)}))},t.prototype.moveDashlet=function(e,t){var n=this;return Promise.resolve(this.layout.moveDashlet(e,t)).then(function(e){var t={};e.forEach(function(e){t[e.getAttribute("j-provider-id")]=n.getDashletPosition(e)})})},t.prototype.locateTemplate=function(){return e.prototype.locateTemplate.call(this)},t.prototype.getDashletAt=function(e){return this.layout.getDashletAt(e)},t.prototype.getDashletPosition=function(e){return this.layout.getElementPosition(e)},t.prototype.locateProvider=function(){return r.JDash.Provider},t.prototype.hideDashlets=function(e){this.layout.hideDashlets(e)},t.prototype.collapseDashlets=function(e){this.layout.collapseDashlets(e)},t.prototype.toggleDashlets=function(e){this.layout.toggleDashlets()},t.prototype.toggleCollapseDashlets=function(e){this.layout.toggleCollapseDashlets()},t.prototype.createDefaultLayout=function(){return document.createElement(t.defaultLayoutModule)},t.prototype.initializeElement=function(){var e=!1;if(!this._layout){var t=s.DashboardLayout,n=l.default.locateElementType(this,t);n.length>0&&(this.layout=n[0],e=!0)}this.layout=this.layout||this.createDefaultLayout(),e||this.appendChild(this.layout),l.default.setBindings(this)},t.prototype.attributeChangedCallback=function(e,t,n){"title"==e&&this.isInitialized&&l.default.setBindings(this,this),"j-view-mode"==e.toLowerCase()&&this.layout&&(this.layout.viewMode2=n),"j-style"==e.toLowerCase()&&this.layout&&(this.layout.layoutStyle=n),"j-layout"==e.toLowerCase()&&(this.isInitialized||(this.layout=document.createElement(e)))},t.prototype.addDashlet=function(e,t){var n,o;if("string"==typeof e){var r=i.DashletModule.getByTag(e);o={moduleId:r&&r.elementTag||e,title:r&&r.title||"",dashboardId:this.getAttribute("j-provider-id")||this.id,createdAt:void 0},n=this.layout.generateDashletElement(o,i.IDashletElementStatus.created)}else if(e instanceof i.Dashlet)n=e,o={moduleId:e.tagName.toLowerCase(),title:e.title,dashboardId:this.getAttribute("j-provider-id")||this.id,createdAt:void 0};else if(e instanceof i.DashletModule){var r=e;o={moduleId:r&&r.elementTag,title:r&&r.title||"",dashboardId:this.getAttribute("j-provider-id")||this.id,createdAt:void 0},n=this.layout.generateDashletElement(o,i.IDashletElementStatus.created)}else o=e,n=this.layout.generateDashletElement(o,i.IDashletElementStatus.created);return this.layout.placeDashlet(n,t),n},t.defaultLayoutModule="j-grid-layout",t}(a.TemplatedElement);n.Dashboard=u},{"../core":28,"../helper":35,"../jdash":36,"../layout":40,"./dashlet":29}],35:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.TemplateInstantiatePosition={insert:"insert",append:"append",sibling:"sibling",auto:"auto"};var o=function(){function e(){}return e.getElementChildren=function(e){for(var t=[],n=0;n<e.childNodes.length;n++){var o=e.childNodes[n];o instanceof Element&&t.push(o)}return t},e.elementIndex=function(t,n){for(var o=e.getElementChildren(t),r=0;r<o.length;r++)if(o[r]==n)return r;return-1},e.cloneElement=function(e,t,n,o){n=n||{},o=o||{};var r=function(e){for(var t=Object.keys(n),r=0;r<t.length;r++){var i=t[r],a=n[i];"string"==typeof a&&(a=[a]);var s=e.getAttribute(i);if(void 0!==s&&a.indexOf(s)>=0)return!1}if(t=Object.keys(o),t.length>0){for(var r=0;r<t.length;r++){var i=t[r],a=o[i];"string"==typeof a&&(a=[a]);var s=e.getAttribute(i);if(void 0!==s&&a.indexOf(s)>=0)return!0}return!1}return!0},i=function(e,t){return void 0===t&&(t=!1),e.cloneNode()},a=function(e,n){if(void 0===n&&(n=0),r(e)){var o=i(e,!0);if(void 0!==t&&"boolean"!=typeof t&&t<n)return o;n++;for(var s=0;s<e.childNodes.length;s++){var l=e.childNodes[s];if(3==l.nodeType)o.appendChild(l.cloneNode());else if(r(l)){var u=a(l,n);u&&o.appendChild(u)}}return o}return null};return!1!==t&&void 0!==t&&0!==t?a(e):r(e)?i(e):void 0},e.moveElement=function(t,n,o){n=n||"next";var r=e.getImmidiateSiblings(t,o,!0);if(!(r.length<2)){var i=Array.prototype.indexOf.call(r,t);if(!(i<0)){var a;0==i&&"prev"==n?(a=r.length-1,n="next"):i==r.length-1&&"next"==n?(a=0,n="prev"):a="next"==n?i+1:i-1;var s=r[a];"next"==n?t.parentElement.insertBefore(s,t):t.parentElement.insertBefore(t,s)}}},e.executeAction=function(t,n,o,r){var i={$event:o};n&&Object.keys(n).forEach(function(e){return i[e]=n[e]}),r=r||window;var a=r["j-action-"+t+"-handlers"]||[];return r["j-action-"+t+"-execute-handler"]||(r.addEventListener("execute-"+t,function(n){if(!n.defaultPrevented){var o=e.fireEvent(r||window,""+t,n.detail,!0,!0);if(0==o.dispatchResult||o.event.defaultPrevented)return void(n.cancelable&&n.preventDefault());var i=n.detail.$waitFor;Promise.resolve(i).then(function(){a.forEach(function(e){return e.apply(r,[n])}),e.fireEvent(r||window,"after-"+t,n.detail,!1,!0)})}}),r["j-action-"+t+"-execute-handler"]=!0),e.fireEvent(r,"execute-"+t,i,!0,!0)},e.setBindings=function(e,t,n){t=t||e;for(var o=e.querySelectorAll(n||"[j-bind]"),r=0;r<o.length;r++){var i=o[r],a=i.getAttribute("j-bind");if((i["__j-binding-context"]||(i["__j-binding-context"]=t))===t){var s=a?t[a]:t;if(s)i.textContent=s.toString();else{var l=i.getAttribute("j-bind-default");l&&(i.innerHTML=l)}}}},e.bindActions=function(t,n,o){for(var r=t.querySelectorAll("[j-action]"),i=0;i<r.length;i++){var a=r[i],s=a.getAttribute("j-action"),l=a.getAttribute("j-action-params"),u=function(e){var t={};if(e){e.split(",").forEach(function(e){var n=e.split(":");t[n[0]]=n[1]})}return t}(l);n&&Object.keys(n).forEach(function(e){var t=n[e];u[e]=t}),function(t,n){a.addEventListener("click",function(r){return e.executeAction.apply(null,[""+t,n,r,o])})}(s,u)}},e.addActionListener=function(e,t,n){var o=n["j-action-"+e+"-handlers"]||[];o.push(t),n["j-action-"+e+"-handlers"]=o},e.ensureId=function(e,t){for(var n=e.querySelectorAll("["+t+'=""]'),o=0;o<n.length;o++)n[o].setAttribute(t,this.makeid())},e.locateElementType=function(t,n,o){var r=[],i=function(t){if(o||!(r.length>0))for(var a=e.getElementChildren(t),s=0;s<a.length;s++){var l=a[s];i(l),l instanceof n&&r.push(l)}};return i(t),r},e.getSiblings=function(e,t){var n=e.parentElement,o=n.querySelectorAll(t);return Array.prototype.filter.call(o,function(t){return t!==e})},e.getImmidiateSiblings=function(e,t,n){var o=e.parentElement,r=o.querySelectorAll(t);return Array.prototype.filter.call(r,function(t){return!(!n&&t===e)&&t.parentElement===o})},e.extractTemplate=function(t){var n,o=document.importNode(t.content,!0),r=e.getElementChildren(o);r.length>1||t.getAttribute("j-target-tag")?(n=document.createElement(t.getAttribute("j-target-tag")||"div"),n.appendChild(o)):n=r.length<1?document.createElement(t.getAttribute("j-target-tag")||"div"):r[0],n.className=n.className+(t.className||"");for(var i=0;i<t.attributes.length;i++)n.setAttribute(t.attributes[i].name,t.attributes[i].value);return n.setAttribute("j-template-generated",""),n},e.getFirstElementChild=function(e){if(!e.hasChildNodes())return null;if(e.firstElementChild)return e.firstElementChild;for(var t=0;t<e.childNodes.length;t++){var n=e.childNodes[t];if(n.nodeType===Node.ELEMENT_NODE)return n}},e.instantiateTemplate=function(t,o,r){var i=this;r=r||{};var a;a=t.getAttribute("j-target-selector")?(r.container||document).querySelectorAll(t.getAttribute("j-target-selector")):"string"==typeof o?(r.container||document).querySelectorAll(o):o instanceof NodeList?o:o?[o]:void 0;var s=[],l=a?t.getAttribute("j-target-position")||r.position||n.TemplateInstantiatePosition.append:n.TemplateInstantiatePosition.auto,u=function(t,o){var a=!0;if(r.preProcess&&!1!==(a=r.preProcess.apply(i,[t,o]))&&(a=!0),a){if(l==n.TemplateInstantiatePosition.append)o.appendChild(t);else if(l==n.TemplateInstantiatePosition.insert){var u=e.getFirstElementChild(o);u?o.insertBefore(t,u):o.appendChild(t)}else if(l==n.TemplateInstantiatePosition.auto){var d=o.parentElement;d.insertBefore(t,o)}else e.hideElements(o,!0),o.parentElement.insertBefore(t,o);r.postProcess&&r.postProcess.apply(i,[t,o]),s.push(t)}};if(l==n.TemplateInstantiatePosition.auto){var d=e.extractTemplate(t);u(d,t)}else for(var c=0;c<a.length;c++){var h=a[c],d=e.extractTemplate(t);u(d,h)}return s},e.locateTemplate=function(e,t,n){void 0===n&&(n=!1);var o=function(e){return e.querySelector('template[j-type="'+t+'"]')},r=o(e);if(r)return r;if(!n)return null;for(var i=e.parentElement;i;){var a=o(i);if(a)return a;i=i.parentElement}},e.removeTemplateInstances=function(e,t){for(var n=Array.isArray(t)?t:"string"==typeof t?[t]:[t.getAttribute("j-type")],o=0;o<n.length;o++){var r=e.querySelectorAll('[j-type="'+n[o]+'"]:not(template)');this.removeElements(r)}},e.hideTemplateInstances=function(e,t,n){for(var o=Array.isArray(t)?t:[t],r=0;r<o.length;r++){var i=e.querySelectorAll('[j-type="'+o[r]+'"]:not(template)');this.hideElements(i,n)}},e.hideElements=function(e,t){for(var n=e instanceof NodeList?e:[e],o=0;o<n.length;o++){var r=n[o];r.style.display=t?"none":""}},e.removeElements=function(e){for(var t=e instanceof NodeList?e:[e],n=0;n<t.length;n++)t[n].remove()},e.getElementsNotIn=function(e,t,n){for(var o=e.querySelectorAll(t),r=e.querySelectorAll(n),i=[],a=0;a<r.length;a++)for(var s=r[a],l=s.querySelectorAll(t),u=0;u<l.length;u++)i.push(l[u]);for(var d=[],a=0;a<o.length;a++){for(var c=!1,u=0;u<i.length;u++)o[a]===i[u]&&(c=!0);c||d.push(o[a])}return d},e.getContainingType=function(e,t){for(var n=e.parentElement;n;){if(n.getAttribute("j-type")==t)return n;n=n.parentElement}return null},e.getContainingAttr=function(e,t,n){for(var o=e.parentElement;o;){if(o.hasAttribute(t)){if(!n)return o;if(n&&o.getAttribute(t)==n)return o}o=o.parentElement}},e.makeid=function(){for(var e="",t="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789",n=0;n<8;n++)e+=t.charAt(Math.floor(Math.random()*t.length));return e},e.fireEvent=function(e,t,n,o,r){void 0===n&&(n=null),void 0===o&&(o=!1),void 0===r&&(r=!1);var i=new CustomEvent("Event");return i.initCustomEvent(t,r,o,n),{event:i,dispatchResult:e.dispatchEvent(i)}},e.extends=function(e,t){function n(){this.constructor=e}for(var o in t)t.hasOwnProperty(o)&&(e[o]=t[o]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},e.inherit=function(t){return function(t){function n(){return t.apply(this,arguments)||this}return e.extends(n,t),n}(t)},e}();n.default=o},{}],36:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o=e("./layout/ext/bsgridlayout"),r=e("./dashboard/ext/bsdashletpanel"),i=e("./dashboard/ext/bsdashleteditorpanel"),a=e("./dashboard"),s=e("axios"),l=e("./theme"),u=e("./dashboard/dashlet"),d=e("./provider/cloud"),c=e("./provider/premise"),h=e("./dashboard/dashletpanel"),p=e("./dashboard/dashleteditorpanel"),f=e("./core"),y=e("./core"),m=e("./layout/grid"),v=e("./layout/generic"),g=e("./layout"),b=e("./helper"),j=e("./register"),E=e("./lib/initialConfigurator");n.JDash={HtmlElement:y.HtmlElement,Helper:b.default,Component:f.Component,DashletModule:u.DashletModule,DashletPanel:h.DashletPanel,DashletEditorPanel:p.DashletEditorPanel,GenericLayout:v.GenericLayout,GridLayout:m.GridLayout,DashboardLayout:g.DashboardLayout,Configuration:y.Configuration,ThemeManager:l.ThemeManager,Dashboard:a.Dashboard,Http:s,bs:{DashletEditorPanel:i.BsDashletEditorPanel,DashletPanel:r.BsDashletPanel,GridLayout:o.BsGridLayout},ProviderTypes:{Cloud:d.CloudProvider,OnPremise:c.PremiseProvider},Provider:new d.CloudProvider,dashlet:function(e,t){var o=Array.prototype.slice.call(arguments);n.JDash.define.apply(this,o)},define:function(e,t){var n=Array.prototype.slice.apply(arguments);return f.Component.define.apply(f.Component,n)},ready:function(e){window.customElements.flush&&window.customElements.flush(),"loading"!=document.readyState?e():document.addEventListener("DOMContentLoaded",function(){window.HTMLImports?window.HTMLImports.whenReady(function(){return setTimeout(function(){e()})}):e()})}},function(e){e.jdash=n.JDash,E.InitialConfigurator.JDashConfiguratorAttributes(),j.default.elements(),n.JDash.ready(function(){return l.ThemeManager.init()})}(window)},{"./core":28,"./dashboard":34,"./dashboard/dashlet":29,"./dashboard/dashleteditorpanel":30,"./dashboard/dashletpanel":31,"./dashboard/ext/bsdashleteditorpanel":32,"./dashboard/ext/bsdashletpanel":33,"./helper":35,"./layout":40,"./layout/ext/bsgridlayout":37,"./layout/generic":38,"./layout/grid":39,"./lib/initialConfigurator":41,"./provider/cloud":43,"./provider/premise":44,"./register":45,"./theme":46,axios:1}],37:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("../grid"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.setColumnWidths4Zones=function(e){for(var t=0,n=(e.length,0);n<e.length;n++){var o=e[n],r=parseInt(o.getAttribute("j-weight")||"1")||1;t+=r}for(var i=12/t,a=0,n=0;n<e.length;n++){var o=e[n],r=parseInt(o.getAttribute("j-weight")||"1")||1,s=Math.round(r*i);n==e.length-1?s=Math.abs(12-a):a+=s,o.setAttribute("class",""),o.classList.add("col-md-"+s)}},t}(r.GridLayout);n.BsGridLayout=i},{"../grid":39}],38:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("./"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t}(r.DashboardLayout);n.GenericLayout=i},{"./":40}],39:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("./"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.getStyles=function(){return{dark:"Dark",light:"Light"}},t.prototype.setColumnWidths4Zones=function(e){for(var t=0,n=(e.length,0);n<e.length;n++){var o=e[n],r=parseInt(o.getAttribute("j-weight")||"1")||1;t+=r}for(var i=12/t,a=0,n=0;n<e.length;n++){var o=e[n],r=parseInt(o.getAttribute("j-weight")||"1")||1,s=Math.round(r*i);n==e.length-1?s=Math.abs(12-a):a+=s,o.setAttribute("class",""),o.classList.add("j-col","m"+s)}},t.prototype.setColumnWidths=function(){var e=this.querySelectorAll('[j-type="j-layout-section"]');if(0==e.length)this.setColumnWidths4Zones(this.querySelectorAll("[j-dashlet-zone]"));else for(var t=0;t<e.length;t++){var n=e[t].querySelectorAll("[j-dashlet-zone]");this.setColumnWidths4Zones(n)}},t.prototype.createChildren=function(t){e.prototype.createChildren.call(this,t)},t.prototype.connectedCallback=function(){e.prototype.connectedCallback.call(this)},t}(r.DashboardLayout);n.GridLayout=i},{"./":40}],40:[function(e,t,n){"use strict";function o(e){var t=e.target;e.pageX,e.pageY;t.style.position="fixed",t.style.left=e.pageX-(window.scrollX||window.pageXOffset)+"px",t.style.top=e.pageY-(window.scrollY||window.pageYOffset)+"px"}function r(e){var t=document,n=window,o=t.body,r=void 0!==n.pageXOffset?n.pageXOffset:(t.documentElement||o.parentNode||o).scrollLeft,i=void 0!==n.pageYOffset?n.pageYOffset:(t.documentElement||o.parentNode||o).scrollTop,a=e.getBoundingClientRect();if(e!==o)for(var s=e.parentNode;s!==o;)r+=s.scrollLeft,i+=s.scrollTop,s=s.parentNode;return{bottom:a.bottom+i,height:a.height,left:a.left+r,right:a.right+r,top:a.top+i,width:a.width}}var i=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var a=e("../dashboard"),s=e("../dashboard/dashlet"),l=e("./../core"),u=e("../helper"),d=e("../helper");n.LayoutViewMode={readonly:"readonly",layoutedit:"layoutedit",dashletedit:"dashletedit",editable:"editable"};var c=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t._viewMode=n.LayoutViewMode.readonly,t._viewMode2=n.LayoutViewMode.readonly,t.discardedAttributesOnClone={"j-type":["j-dashlet-panel","j-dashlet","j-zone-editor","j-section-editor","j-dashlet-zone-group-editor"]},t}return i(t,e),t.prototype.getType=function(){return"j-layout"},t.prototype.getStyles=function(){return{}},Object.defineProperty(t.prototype,"layoutStyle",{get:function(){return this._layoutStyle},set:function(e){this._layoutStyle&&this.classList.remove(this._layoutStyle),this.getStyles()&&(this.classList.add(e),this._layoutStyle=e)},enumerable:!0,configurable:!0}),t.prototype.getModel=function(){for(var e=this.querySelector('[j-type="j-layout-content"]:not(template)'),t=u.default.cloneElement(e,!0,void 0,{"j-persist":""}),n=this.getDashlets(),o={},r=0;r<n.length;r++){var i=n[r],a=i.getAttribute("j-provider-id")||i.id;a&&(o[a]={position:this.getElementPosition(i)})}return{moduleId:this.tagName.toLowerCase(),dashlets:o,config:{content:t.outerHTML}}},t.prototype.removeZoneActionHandler=function(e){var t=e.detail.zone,n=(t.parentElement,u.default.getContainingType(t,"j-dashlet-zone-group")),o=u.default.getImmidiateSiblings(t,"[j-dashlet-zone]",!1);t.remove(),n&&!o.length&&n.remove(),this.setColumnWidths4Zones(o),this.save()},t.prototype.moveSectionActionHandler=function(e){var t=e.detail.direction||"next",n=e.detail.section;u.default.moveElement(n,t,'[j-type="j-layout-section"]'),this.save()},t.prototype.cloneZoneActionHandler=function(e){var t=e.detail.zone,n=u.default.cloneElement(t,!0,this.discardedAttributesOnClone);n.setAttribute("j-dashlet-zone",u.default.makeid()),t.parentElement.insertBefore(n,t),this.setLayoutMode4Zone(n);var o=u.default.getImmidiateSiblings(t,"[j-dashlet-zone]",!1);this.setColumnWidths4Zones(Array.prototype.concat.apply(o,[t])),this.save()},t.prototype.editSectionTitle=function(e,t){var n=e.querySelectorAll('[j-type="j-layout-section-title"]');if(n.length>0){var o=n[0].textContent,r=window.prompt(t||"Title",o);if(null!=r){for(var i=0;i<n.length;i++)n[i].textContent=r;return r}return null}},t.prototype.editSectionTitleActionHandler=function(e){this.editSectionTitle(e.detail.section,"Set section title"),this.save()},t.prototype.removeSectionActionHandler=function(e){var t=e.detail.section,n=u.default.getContainingType(t,"j-layout-content");t.remove(),n.querySelector('[j-type="j-layout-section"]')||this.reset(),this.save()},t.prototype.editzoneGroupTitle=function(e,t){var n=e.querySelectorAll('[j-type="j-dashlet-zone-group-title"]');if(n.length>0){var o=n[0].textContent.trim(),r=window.prompt(t||"Title",o);if(null!=r){for(var i=0;i<n.length;i++)n[i].textContent=r;return r}return null}},t.prototype.moveZoneGroupActionHandler=function(e){var t=e.detail.direction,n=e.detail.group;u.default.moveElement(n,t,'[j-type="j-dashlet-zone-group"]'),this.save()},t.prototype.cloneZoneGroupActionHandler=function(e){for(var t=e.detail.group,n=u.default.cloneElement(t,!0,this.discardedAttributesOnClone),o=n.querySelectorAll("[j-dashlet-zone]"),r=0;r<o.length;r++)o[r].setAttribute("j-dashlet-zone",u.default.makeid()),this.setLayoutMode4Zone(o[r]);this.setLayoutMode4ZoneGroup(n),null!==this.editzoneGroupTitle(n,"Set a title for new group")&&(this.save(),t.parentElement.insertBefore(n,t))},t.prototype.editZoneGroupTitleActionHandler=function(e){this.editzoneGroupTitle(e.detail.group,"Set group title"),this.save()},t.prototype.removeZoneGroupActionHandler=function(e){e.detail.group.remove(),this.save()},t.prototype.makeZoneGroupActionHandler=function(e){var t=this,n=e.detail.zone,o=u.default.locateTemplate(this,"j-dashlet-zone-group");o&&(u.default.instantiateTemplate(o,n,{position:d.TemplateInstantiatePosition.append,postProcess:function(e){for(var n=e.querySelectorAll("[j-dashlet-zone]"),o=0;o<n.length;o++)n[o].setAttribute("j-dashlet-zone",u.default.makeid()),t.setLayoutMode4Zone(n[o]);t.setLayoutMode4ZoneGroup(e),t.setColumnWidths4Zones(n)}}),this.save())},t.prototype.cloneSectionActionHandler=function(e){for(var t=e.detail.section,n=u.default.cloneElement(t,!0,this.discardedAttributesOnClone),o=n.querySelectorAll("[j-dashlet-zone]"),r=0;r<o.length;r++)o[r].setAttribute("j-dashlet-zone",u.default.makeid()),this.setLayoutMode4Zone(o[r]);this.setLayoutMode4Section(n),null!==this.editSectionTitle(n,"Set a title for new section")&&(t.parentElement.insertBefore(n,t),this.save())},t.prototype.resetSectionActionHandler=function(e){for(var t=e.detail.section,n=t.querySelectorAll("[j-dashlet-zone]"),o=0;o<n.length;o++)n[o].removeAttribute("j-weight");this.setColumnWidths4Zones(n),this.save()},t.prototype.moveZoneActionHandler=function(e){var t=e.detail.direction,n=e.detail.zone;u.default.moveElement(n,t,"[j-dashlet-zone]"),this.save()},t.prototype.setColumnWidths4Zones=function(e){},t.prototype.setColumnWidths=function(){},t.prototype.getElementWeigth=function(e){if(e.hasAttribute("j-weight")){return Number(e.getAttribute("j-weight"))||1}return 1},t.prototype.changeElementWeigth=function(e,t,n){var o=this.getElementWeigth(e);if(!(o>=n)){var r=o+t;0==r&&t>0?r=2:r<1&&t<0&&(r=1),e.setAttribute("j-weight",r.toString())}},t.prototype.changeElementWeigths=function(e,t,n){for(var o=0;o<e.length;o++)this.changeElementWeigth(e[o],t,n)},t.prototype.resizeZoneActionHandler=function(e){var t=Number(e.detail.inc),n=e.detail.zone,o=u.default.getImmidiateSiblings(n,"[j-dashlet-zone]",!1),r=12-(o.length-1);if(t>0){this.getElementWeigth(n)>=r?this.changeElementWeigths(o,-1,r):this.changeElementWeigth(n,1,r)}else this.changeElementWeigths(o,1,r);this.setColumnWidths4Zones(Array.prototype.concat.apply(o,[n])),this.save()},t.prototype.getDashlets=function(){return this.querySelectorAll('[j-type="j-dashlet"]')},t.prototype.makeDashletsDragable=function(e){for(var t=this.getDashlets(),n=0;n<t.length;n++)this.makeDashletDragable(t[n],e)},t.prototype.hideDashlets=function(e){var t=this.querySelectorAll('[j-type="j-dashlet-panel"]');u.default.hideElements(t,e),this.dashletsHidden=!!e},t.prototype.toggleDashlets=function(){this.hideDashlets(!this.dashletsHidden)},t.prototype.collapseDashlet=function(e,t){var n=this.querySelectorAll('[j-type="j-dashlet-configuration-tools"]');"dashletedit"==this.viewMode&&u.default.hideElements(n,t),u.default.hideElements(e,t)},t.prototype.collapseDashlets=function(e){
for(var t=this.getDashlets(),n=0;n<t.length;n++)this.collapseDashlet(t[n],e);this.dashletsCollapsed=e},t.prototype.toggleCollapseDashlets=function(){this.collapseDashlets(!this.dashletsCollapsed)},Object.defineProperty(t.prototype,"viewMode",{get:function(){return this._viewMode},set:function(e){this.viewMode2=e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"viewMode2",{get:function(){return this._viewMode2},set:function(e){this._viewMode!=e?(this.fireEvent("viewmode-change",{oldVal:this.viewMode,newVal:e},!1,!0),this._viewMode=e,this.isInitialized&&this.setViewMode(e)):console.log("Canceled values are same")},enumerable:!0,configurable:!0}),t.prototype.setViewMode=function(e){switch(this.clearDropZones("j-dashlet"),this.setAttribute("j-view-mode",e),e){case n.LayoutViewMode.readonly:this.setLayoutEditMode(!1),this.setDashletEditMode(!1);break;case n.LayoutViewMode.layoutedit:this.setDashletEditMode(!1),this.setLayoutEditMode(!0);break;case n.LayoutViewMode.dashletedit:this.setLayoutEditMode(!1),this.setDashletEditMode(!0)}},t.prototype.initializeElement=function(){var t=this.getStyles(),n=null;this.layoutStyle||Object.keys(t).forEach(function(e){n=n||e}),n&&(this.layoutStyle=n),e.prototype.initializeElement.call(this),interact.dynamicDrop(!0),this.listenforActions(),u.default.ensureId(this,"j-dashlet-zone"),this.setViewMode(this.viewMode)},t.prototype.setDashletViewMode=function(e,t){for(var n=t instanceof NodeList?t:[t],o=0;o<n.length;o++){n[o].setAttribute("j-view-mode",e)}},t.prototype.setDashletEditMode=function(e){e?(this.createDashletDropzones(),this.makeZonesDroppable(!0),this.makeDashletsDragable(!0),this.setDashletViewMode(s.DashletViewMode.configure,this.getDashlets())):(this.makeDashletsDragable(!1),this.makeZonesDroppable(!1),this.clearDropZones("j-dashlet"),this.setDashletViewMode(s.DashletViewMode.readonly,this.getDashlets()))},t.prototype.setLayoutMode4Zone=function(e){var t=this,n=u.default.locateTemplate(this,"j-zone-editor",!0);n&&u.default.instantiateTemplate(n,e,{position:d.TemplateInstantiatePosition.insert,preProcess:function(e,n){u.default.bindActions(e,{zone:n},t)}})},t.prototype.setLayoutMode4Section=function(e){var t=this,n=u.default.locateTemplate(this,"j-section-editor",!0),o=e.querySelectorAll('[j-type="j-layout-section-header"]');n&&u.default.instantiateTemplate(n,o,{position:d.TemplateInstantiatePosition.sibling,preProcess:function(e,n){u.default.bindActions(e,{section:u.default.getContainingType(n,"j-layout-section")},t);var o=n.querySelector('[j-type="j-layout-section-title"]');if(o){var r=e.querySelector('[j-type="j-layout-section-title"]');r&&(r.innerHTML=o.innerHTML)}}})},t.prototype.setLayoutMode4ZoneGroup=function(e){var t=this,n=u.default.locateTemplate(this,"j-dashlet-zone-group-editor",!0),o=e.querySelectorAll('[j-type="j-dashlet-zone-group-header"]');n&&u.default.instantiateTemplate(n,o,{position:d.TemplateInstantiatePosition.sibling,preProcess:function(e,n){u.default.bindActions(e,{group:u.default.getContainingType(n,"j-dashlet-zone-group")},t);var o=n.querySelector('[j-type="j-dashlet-zone-group-title"]');if(o){var r=e.querySelector('[j-type="j-dashlet-zone-group-title"]');r&&(r.innerHTML=o.innerHTML)}}})},t.prototype.load=function(e,t){var n=this;e.config&&e.config.content?this.generateLayoutContent(e.config&&e.config.content):this.reset(),t.forEach(function(t){var o=n.generateDashletElement(t,s.IDashletElementStatus.loaded);n.placeDashlet(o,e.dashlets&&e.dashlets[t.id]&&e.dashlets[t.id].position)})},t.prototype.save=function(){var e=this.getModel(),t=this.dashboard.getAttribute("j-provider-id")||this.dashboard.id;return this.dashboard.provider.saveDashboard(t,{layout:e})},t.prototype.setLayoutEditMode=function(e){if(e){this.dashletsCollapsed||(this.collapseDashlets(!0),this._dashletsCollapsedByLayout=!0);this.querySelectorAll("[j-dashlet-zone]");this.setLayoutMode4Zone(this.querySelectorAll("[j-dashlet-zone]")),this.setLayoutMode4Section(this),this.setLayoutMode4ZoneGroup(this)}else u.default.removeTemplateInstances(this,["j-zone-editor","j-section-editor","j-dashlet-zone-group-editor"]),u.default.hideElements(this.querySelectorAll('[j-type="j-layout-section-header"]'),!1),u.default.hideElements(this.querySelectorAll('[j-type="j-dashlet-zone-group-header"]'),!1),this._dashletsCollapsedByLayout&&(this.collapseDashlets(!1),delete this._dashletsCollapsedByLayout)},t.prototype.generateDashletElement=function(e,t){var n=s.DashletModule.getByTag(e.moduleId);n=n||s.DashletModule.createModule(e.moduleId);var o=document.createElement(n.elementTag);return o.model=e,o.status=t,o},t.prototype.attributeChangedCallback=function(t,n,o){e.prototype.attributeChangedCallback.call(this,t,n,o)},t.prototype.createDropzoneElement=function(e){var t=u.default.locateTemplate(this,"j-dropzone",!0),n=u.default.extractTemplate(t);return e&&n.setAttribute("j-instance",e),n},t.prototype.dropActiveForElement=function(e){var t=r(e);void 0===e.__originalPosition&&(e.__originalPosition=e.style.position,e.style.position="absolute",e.style.left=Math.round(t.left)+"px",e.style.top=Math.round(t.top)+"px",e.style.width=Math.round(t.width)+"px",e.style.height=Math.round(t.height)+"px")},t.prototype.dropEndForElement=function(e){e.style.webkitTransform=e.style.transform="",e.removeAttribute("data-x"),e.removeAttribute("data-y"),e.style.position=e.__originalPosition||"",e.style.left="",e.style.top="",e.style.width="",e.style.height="",delete e.__originalPosition},t.prototype.makeZonesDroppable=function(e){var t=this,n=interact('[j-type="j-dropzone"][j-instance="j-dashlet"]:not(template)',{context:this});e&&n.dropzone({accept:'[j-type="j-dashlet-panel"],[j-type="j-dashlet-module"]',checker:function(e,t,n,o,r,i,a){return n},ondropactivate:function(e){var n=e.relatedTarget,o=e.target,r=n.querySelector('[j-type="j-dashlet"]');n.querySelector('[j-type="j-dashlet-module"]');o.classList.add("j-dropzone-active"),t.dropActiveForElement(n),r&&t.createDashletDropzones([r])},ondragenter:function(e){var n=e.relatedTarget,o=e.target,r=n.querySelector('[j-type="j-dashlet"]');n.querySelector('[j-type="j-dashlet-module"]');if(r){var i=u.default.fireEvent(r,"drag-zone-entering",{zone:o,dashlet:r,target:n,originalEvent:e},!0);if(i.event.defaultPrevented||(i=u.default.fireEvent(t.dashboard,"dashlet:drag-zone-entering",{zone:o,dashlet:r,target:n,originalEvent:e},!0,!0)),i.event.defaultPrevented)return!1}o.classList.add("j-dropzone-enter"),n.classList.add("j-can-drop");var a=n.getBoundingClientRect();if(o.style.height=Math.round(a.height)+"px",r){var i=u.default.fireEvent(r,"drag-zone-entered",{zone:o,dashlet:r,target:n,originalEvent:e});i=u.default.fireEvent(t.dashboard,"dashlet:drag-zone-entered",{zone:o,dashlet:r,target:n,originalEvent:e},!1,!0)}},ondragleave:function(e){var n=e.relatedTarget,o=e.target,r=n.querySelector('[j-type="j-dashlet"]');n.querySelector('[j-type="j-dashlet-module"]');o.classList.remove("j-dropzone-enter"),o.style.height="",n.classList.remove("j-can-drop"),r&&(u.default.fireEvent(r,"drag-zone-left",{zone:o,dashlet:r,target:n,originalEvent:e}),u.default.fireEvent(t.dashboard,"dashlet:drag-zone-left",{zone:o,dashlet:r,target:n,originalEvent:e},!1,!0))},ondrop:function(e){var n=e.relatedTarget,o=e.target,r=n.querySelector('[j-type="j-dashlet"]');n.querySelector('[j-type="j-dashlet-module"]');if(r){var i=u.default.fireEvent(r,"drop-to-zone-starting",{zone:o,dashlet:r,target:n,originalEvent:e},!0);if(i.event.defaultPrevented||(i=u.default.fireEvent(t.dashboard,"dashlet:drop-to-zone-starting",{zone:o,dashlet:r,target:n,originalEvent:e},!0,!0)),i.event.defaultPrevented)return t.moveDashletToOriginalPosition(r),!1}n.classList.remove("j-can-drop"),t.dropEndForElement(n);var a=t.getElementPosition(o);r?(t.placeDashlet(r,a),u.default.fireEvent(r,"drop-to-zone-end",{zone:o,dashlet:r,target:n,originalEvent:e,fromModule:!1}),u.default.fireEvent(t.dashboard,"dashlet:drop-to-zone-end",{zone:o,dashlet:r,target:n,originalEvent:e,fromModule:!1},!1,!0)):"j-dashlet-module"==n.getAttribute("j-type")&&(r=t.dashboard.addDashlet(n.getAttribute("j-module-id"),a),u.default.fireEvent(r,"drop-to-zone-end",{zone:o,dashlet:r,target:n,originalEvent:e,fromModule:!0}),u.default.fireEvent(t.dashboard,"dashlet:drop-to-zone-end",{zone:o,dashlet:r,target:n,originalEvent:e,fromModule:!0},!1,!0))},ondropdeactivate:function(e){var t=e.relatedTarget,n=e.target;t.querySelector('[j-type="j-dashlet"]');n.classList.remove("drop-active"),n.classList.remove("drop-target")}})},t.prototype.moveDashletToOriginalPosition=function(e){this.dropEndForElement(e.panel);var t=this.getElementPosition(e);this.placeDashlet(e,t)},t.prototype.makeDashletDragable=function(e,t){var n=e.panel?'[j-type="j-dashlet-panel"]':'[j-type="j-dashlet"]',r=interact(n,{context:e.panel||e}),i=this;t?r.draggable({inertia:!0,restrict:{endOnly:!0,elementRect:{top:1,left:1,bottom:1,right:1}},autoScroll:!0,onstart:function(t){var n=u.default.fireEvent(e,"drag-started",{dashlet:e,originalEvent:t},!0);if(n.event.defaultPrevented||(n=u.default.fireEvent(i.dashboard,"dashlet:drag-started",{dashlet:e,originalEvent:t},!0,!0)),n.event.defaultPrevented)return t.interaction.stop(),!1},onmove:function(e){o.apply(this,[e])},onend:function(e){if(!e.dropzone){var t=e.target.querySelector('[j-type="j-dashlet"]');i.moveDashletToOriginalPosition(t)}}}).allowFrom("[j-drag-handle]"):r.draggable(!1)},t.prototype.makeDroppable=function(e,t,n,r){var i=interact(e,{context:n}),a=this;t?i.draggable({inertia:!0,restrict:{endOnly:!0,elementRect:{top:1,left:1,bottom:1,right:1}},autoScroll:{container:this},onstart:function(e){if("j-dashlet-module"==e.target.getAttribute("j-type")){if(u.default.fireEvent(a.dashboard,"dashlet-module:drag-started",{module:e.target,originalEvent:e},!0,!0).event.defaultPrevented)return e.interaction.stop(),!1}},onmove:function(e){o.apply(this,[e])},onend:function(e){if(a.dropEndForElement(e.target),!e.dropzone){var t=e.target;t.style.webkitTransform=t.style.transform="",t.removeAttribute("data-x"),t.removeAttribute("data-y")}}}).allowFrom("[j-drag-handle]"):i.draggable(!1)},t.prototype.createDashletDropzones=function(e){void 0===e&&(e=[]);var t=this.querySelectorAll("[j-dashlet-zone]");this.clearDropZones("j-dashlet");for(var n=0;n<t.length;n++){for(var o=t[n],r=o.querySelectorAll('[j-type="j-dashlet"]'),i=0;i<r.length;i++)if(!(e.indexOf(r[i])>=0)){var a=r[i];if(a.panel.parentElement==o){var s=this.createDropzoneElement("j-dashlet");o.insertBefore(s,a.panel)}}var s=this.createDropzoneElement("j-dashlet"),l=o.getAttribute("j-dashlet-zone");o.appendChild(s),this.autoArrangeElements(l,"j-dropzone")}},t.prototype.clearDropZones=function(e){for(var t=e?this.querySelectorAll('[j-type="j-dropzone"][j-instance="'+e+'"]:not(template)'):this.querySelectorAll('[j-type="j-dropzone"]:not(template)'),n=0;n<t.length;n++){t[n].remove()}},t.prototype.generateDashletZoneIds=function(){for(var e=this.querySelectorAll("[j-dashlet-zone='']"),t=0;t<e.length;t++){var n=e[t],o=u.default.makeid();n.setAttribute("j-dashlet-zone",o)}},t.prototype.generateLayoutContent=function(e){var t=u.default.locateTemplate(this,"j-layout-content",!1);if(e){u.default.removeTemplateInstances(this,"j-layout-content");var n=document.createElement("template");n.innerHTML=e,n.setAttribute("j-type","j-layout-content");var o=u.default.extractTemplate(n);this.insertBefore(o,t),this.generateDashletZoneIds(),this.setViewMode(this.viewMode)}else u.default.instantiateTemplate(t),this.generateDashletZoneIds()},t.prototype.createChildren=function(t){e.prototype.createChildren.call(this,t),this.generateLayoutContent(),this.setColumnWidths()},t.prototype.listenforActions=function(){u.default.addActionListener("removezone",this.removeZoneActionHandler.bind(this),this),u.default.addActionListener("movesection",this.moveSectionActionHandler.bind(this),this),u.default.addActionListener("movezone",this.moveZoneActionHandler.bind(this),this),u.default.addActionListener("resizezone",this.resizeZoneActionHandler.bind(this),this),u.default.addActionListener("clonezone",this.cloneZoneActionHandler.bind(this),this),u.default.addActionListener("clonesection",this.cloneSectionActionHandler.bind(this),this),u.default.addActionListener("editsectiontitle",this.editSectionTitleActionHandler.bind(this),this),u.default.addActionListener("removesection",this.removeSectionActionHandler.bind(this),this),u.default.addActionListener("makezonegroup",this.makeZoneGroupActionHandler.bind(this),this),u.default.addActionListener("movezonegroup",this.moveZoneGroupActionHandler.bind(this),this),u.default.addActionListener("clonezonegroup",this.cloneZoneGroupActionHandler.bind(this),this),u.default.addActionListener("editzonegrouptitle",this.editZoneGroupTitleActionHandler.bind(this),this),u.default.addActionListener("removezonegroup",this.removeZoneGroupActionHandler.bind(this),this),u.default.addActionListener("resetsection",this.resetSectionActionHandler.bind(this),this)},t.prototype.connectedCallback=function(){e.prototype.connectedCallback.call(this)},t.prototype.setDashletProperties=function(e){[n.LayoutViewMode.editable,n.LayoutViewMode.dashletedit].indexOf(this.viewMode)>=0?(this.makeDashletDragable(e,!0),this.setDashletViewMode(s.DashletViewMode.configure,e)):(this.makeDashletDragable(e,!1),this.setDashletViewMode(s.DashletViewMode.readonly,e)),e.config=e.config||{}},t.prototype.createPanelForDashlet=function(e){var t=e.getAttribute("j-panel")||"j-dashlet-panel";if(t&&"none"!=t){var n=document.createElement(t);return n.setAttribute("j-type","j-dashlet-panel"),n.dashlet=e,n}var o=document.createElement("div");return o.setAttribute("j-type","j-dashlet-panel"),o.dashlet=e,o.appendChild(e),o},t.prototype.normalizePosition=function(e){e=e||{};var t,n=0;return e.zone?t=this.querySelector("[j-dashlet-zone]"):(t=this.querySelector("[j-dashlet-zone]"))&&(e.zone=t.getAttribute("j-dashlet-zone")),t&&(n=t.querySelectorAll('[j-type="j-dashlet"]').length),e.x=e.x||0,e.y=e.y||0,e.z=e.z||0,e.y=Math.min(e.y,n),e},t.prototype.autoArrangeElements=function(e,t){var n=this.querySelector('[j-dashlet-zone="'+e+'"]');n||(n=this.querySelector("[j-dashlet-zone]"));for(var o=n.querySelectorAll('[j-type="'+t+'"]:not(template)'),r=0;r<o.length;r++){var i={zone:e,y:r};this.setElementPosition(o[r],i)}},t.prototype.getPositionalChanges=function(e,t){return this.getDashlets()},t.prototype.movePlacedDashlet=function(e,t,o){var r=this;o=this.normalizePosition(o);var i=this.querySelector('[j-dashlet-zone="'+o.zone+'"]');i=i||this.querySelector("[j-dashlet-zone]"),e.panel||(e.panel=this.createPanelForDashlet(e)),e.layout||(e.layout=this);e.getAttribute("j-provider-id")||e.id;t.target.parentElement.insertBefore(e.panel,t.target);for(var l=u.default.getElementsNotIn(i,'[j-type="j-dashlet"]','[j-type="j-dashlet-zone-group"]'),d=0;d<l.length;d++){var c=l[d];this.setElementPosition(c,{x:0,y:d,z:0})}this.setDashletProperties(e);var h={zone:i,dashlet:e};u.default.fireEvent(document,"jdash:dashlet.after-place",h),u.default.fireEvent(e,"after-place",h),this.viewMode!=n.LayoutViewMode.editable&&this.viewMode!=n.LayoutViewMode.dashletedit||this.createDashletDropzones(),this.collapseDashlet(e,this.dashletsCollapsed);var p;return this.dashboard.state==a.DashboardState.loading?Promise.resolve(e):(p=e.status==s.IDashletElementStatus.created?this.dashboard.provider.createDashlet(e.model).then(function(t){return e.model.id=t.id,e.status,s.IDashletElementStatus.loaded,e.updateFromModel(),e}):Promise.resolve(e),p.then(function(e){return r.save()}))},t.prototype.placeDashlet=function(e,t){var o=this;t=this.normalizePosition(t);var r=this.querySelector('[j-dashlet-zone="'+t.zone+'"]');r=r||this.querySelector("[j-dashlet-zone]"),e.panel||(e.panel=this.createPanelForDashlet(e)),e.layout||(e.layout=this);var i=(e.getAttribute("j-provider-id")||e.id,this.getElementPosition(e));e.panel.parentElement==r&&(e.panel.remove(),t=this.normalizePosition(t));var l=u.default.getElementsNotIn(r,'[j-type="j-dashlet"]','[j-type="j-dashlet-zone-group"]'),d=void 0;this.setElementPosition(e,t),this.setDashletProperties(e);for(var c=0;c<l.length;c++){var h=l[c],i=this.getElementPosition(h);t.y<=(i.y||0)&&(d=d||h)}d?r.insertBefore(e.panel||e,d.panel):r.appendChild(e.panel||e),this.autoArrangeElements(t.zone,"j-dashlet");var p={zone:r,dashlet:e};u.default.fireEvent(document,"jdash:dashlet.after-place",p),u.default.fireEvent(e,"after-place",p),this.viewMode!=n.LayoutViewMode.editable&&this.viewMode!=n.LayoutViewMode.dashletedit||this.createDashletDropzones(),this.collapseDashlet(e,this.dashletsCollapsed);var f;return this.dashboard.state==a.DashboardState.loading?Promise.resolve(e):(f=e.status==s.IDashletElementStatus.created?this.dashboard.provider.createDashlet(e.model).then(function(t){return e.model.id=t.id,e.status,s.IDashletElementStatus.loaded,e.updateFromModel(),e}):Promise.resolve(e),f.then(function(e){return o.save()}))},t.prototype.removeDashlet=function(e){var t=this,n=u.default.fireEvent(e,"dashlet-removing",{dashlet:e},!0,!1);if(n.event.defaultPrevented||(n=u.default.fireEvent(this.dashboard,"dashlet:dashlet-removing",{dashlet:e},!0,!0)),!n.event.defaultPrevented)return e.panel.remove(),u.default.fireEvent(e,"dashlet-removed",{dashlet:e}),u.default.fireEvent(this.dashboard,"dashlet:dashlet-removed",{dashlet:e},!1,!0),this.save().then(function(){return t.createDashletDropzones()})},t.prototype.cloneDashlet=function(e){var t=this,n=e.config?JSON.parse(JSON.stringify(e.config)):null,o=e.model?JSON.parse(JSON.stringify(e.model)):{};return o.title="Copy "+(o&&o.title),n&&(o.configuration=n),this.dashboard.provider.createDashlet(o).then(function(n){Object.keys(n).forEach(function(e){return o[e]=n[e]});var r=t.generateDashletElement(o,s.IDashletElementStatus.created);return t.placeDashlet(r,t.getElementPosition(e))})},t.prototype.normalizeDashletZones=function(){for(var e=this.querySelectorAll("[j-type='j-dashlet-zone-group']"),t=0;t<e.length;t++){var n=e[t],o=u.default.getElementsNotIn(n,"[j-dashlet-zone]","j-dashlet-zone-group");this.setColumnWidths4Zones(o)}},t.prototype.reset=function(e){for(var t=this.querySelectorAll('[j-type="j-dashlet"]'),n=0;n<t.length;n++)(t[n].panel||t[n]).remove();var o=this.querySelector("[j-type='j-layout-content']:not(template)");o&&o.remove(),this.generateLayoutContent(),e=e||this.viewMode,this.viewMode==e?this.setViewMode(e):this.viewMode=e,this.normalizeDashletZones()},t.prototype.getElementPosition=function(e){return{zone:e.getAttribute("j-zone"),x:e.getAttribute("j-x")?parseInt(e.getAttribute("j-x")):void 0,y:e.getAttribute("j-y")?parseInt(e.getAttribute("j-y")):void 0,z:e.getAttribute("j-z")?parseInt(e.getAttribute("j-z")):void 0}},t.prototype.setElementPosition=function(e,t){t.zone?e.setAttribute("j-zone",t.zone):e.removeAttribute("zone"),t.x?e.setAttribute("j-x",t.x.toString()):e.removeAttribute("j-x"),t.y?e.setAttribute("j-y",t.y.toString()):e.removeAttribute("j-y"),t.z?e.setAttribute("j-z",t.z.toString()):e.removeAttribute("j-z"),e.model&&(e.model.position=t)},t.prototype.moveDashlet=function(e,t){var n=this.getElementPosition(e),o=o=u.default.fireEvent(e,"drag-start",{from:n,to:t},!0)&&u.default.fireEvent(document,"jdash:dashlet.drag-start",{target:e,from:n,to:t},!0);return o?(this.placeDashlet(e,t),[e]):[]},t.prototype.getDashletsByPosition=function(e){var t='[j-type="j-dashlet"]';return t=e.zone?t.concat('[j-zone="'+e.zone+'"]'):t,t=e.x?t.concat('[j-x="'+e.x+'"]'):t,t=e.y?t.concat('[j-y="'+e.y+'"]'):t,t=e.z?t.concat('[j-z="'+e.z+'"]'):t,this.querySelectorAll(t)},t.prototype.getDashletAt=function(e){var t='[j-type="j-dashlet"]';return t=e.zone?t.concat('[j-zone="'+e.zone+'"]'):t,t=e.x?t.concat('[j-x="'+e.x+'"]'):t,t=e.y?t.concat('[j-y="'+e.y+'"]'):t,t=e.z?t.concat('[j-z="'+e.z+'"]'):t,this.querySelector(t)},t}(l.ComponentElement);n.DashboardLayout=c},{"../dashboard":34,"../dashboard/dashlet":29,"../helper":35,"./../core":28}],41:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o=function(){function e(){}return e.JDashConfiguratorAttributes=function(){},e}();n.InitialConfigurator=o},{}],42:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o=e("../dashboard"),r=e("axios"),i=function(){function e(e){this.options=e,this.options=e||{}}return e.prototype.getDefaultRequestConfig=function(e){var t={},n={url:e,headers:t};return this.options&&this.options.configRequest&&this.options.configRequest(n),Promise.resolve(n)},e.prototype.get=function(e){var t=this;return this.getDefaultRequestConfig(e).then(function(e){return e.method="get",t.makeRequest(e).then(function(e){return e.data})})},e.prototype.post=function(e,t){var n=this;return this.getDefaultRequestConfig(e).then(function(e){return e.method="post",e.data=t,n.makeRequest(e).then(function(e){return e.data})})},e.prototype.makeRequest=function(e){return r.request(e)},e.prototype.getDashboard=function(e){return this.get("/dashboard/"+e)},e.prototype.createDashboard=function(e){return e.layout||(e.layout={moduleId:o.Dashboard.defaultLayoutModule}),this.post("/dashboard/create",e)},e.prototype.getMyDashboards=function(e){return this.get("/dashboard/my")},e.prototype.searchDashboards=function(e,t){return this.post("/dashboard/search",{search:e,query:t})},e.prototype.deleteDashboard=function(e){return this.post("/dashboard/delete/"+e)},e.prototype.saveDashboard=function(e,t){return this.post("/dashboard/save/"+e,t)},e.prototype.createDashlet=function(e){return this.post("/dashlet/create",e)},e.prototype.getDashletsOfDashboard=function(e){return this.get("/dashlet/bydashboard/"+e)},e.prototype.deleteDashlet=function(e){return this.post("/dashlet/delete/"+e)},e.prototype.saveDashlet=function(e,t){return this.post("/dashlet/save/"+e,t)},e}();n.ApiProvider=i},{"../dashboard":34,axios:1}],43:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("./api"),i=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return o(t,e),t.prototype.init=function(e){this.tokenProvider=e},t.prototype.refreshUserToken=function(){var e=this;return new Promise(function(t,n){try{("string"==typeof e.tokenProvider.userToken?function(t){t(null,e.tokenProvider.userToken)}:e.tokenProvider.userToken)(function(o,r){if(o)return n(o);e.currentUserToken=r,t(r)})}catch(e){console.error("jdash.Provider must be initted with an object that has a getUserToken((function (userToken) { }) callback for authorization purposes."),console.warn&&console.warn("See https://docs.jdash.io/ for details"),n(e)}})},t.prototype.getAuthorizationHeaderContent=function(){return"Bearer "+this.currentUserToken},t.prototype.ensureTokenReceived=function(e,t){var n=this;if(401!==e.response.status||e.config.authRetry)throw e;return this.refreshUserToken().then(function(){return t.headers.Authorization=n.getAuthorizationHeaderContent(),t.authRetry=!0,n.makeRequest(t)})},t.prototype.makeRequest=function(t){var n=this;return e.prototype.makeRequest.call(this,t).catch(function(e){return n.ensureTokenReceived(e,t)})},t.prototype.getDefaultRequestConfig=function(n){var o=this;return e.prototype.getDefaultRequestConfig.call(this,n).then(function(e){return e.baseURL=t.url,o.currentUserToken?(e.headers.Authorization=o.getAuthorizationHeaderContent(),e):o.refreshUserToken().then(function(){return e.headers.Authorization=o.getAuthorizationHeaderContent(),e})})},t}(r.ApiProvider);n.CloudProvider=i,Object.defineProperty(i,"url",{get:function(){return"https://app.jdash.io/jdash/api/v1"}})},{"./api":42}],44:[function(e,t,n){"use strict";var o=this&&this.__extends||function(){var e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])};return function(t,n){function o(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(o.prototype=n.prototype,new o)}}();Object.defineProperty(n,"__esModule",{value:!0});var r=e("./api"),i=function(e){function t(t){var n=e.call(this,t)||this;return n.options=t,n.options=n.options||{url:"/jdash/api/v1"},n}return o(t,e),t.prototype.getDefaultRequestConfig=function(t){var n=this;return e.prototype.getDefaultRequestConfig.call(this,t).then(function(e){return e.baseURL=n.options.url,e})},t}(r.ApiProvider);n.PremiseProvider=i},{"./api":42}],45:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o=e("./core"),r=e("./dashboard/dashlet");n.default={elements:function(){window.customElements.define("j-component",o.Component),window.customElements.define("j-dashlet",r.DashletModule),window.customElements.define("j-dashlet-editor",r.DashletEditorModule)}}},{"./core":28,"./dashboard/dashlet":29}],46:[function(e,t,n){"use strict";Object.defineProperty(n,"__esModule",{value:!0});var o=function(){function e(){}return e.init=function(e,t){if(this.loadFromLocalstorage())this.setCurrentTheme(this.currentTheme.name,this.currentThemeLibrary);else{t=t||"jdash";var n=this.themes[t],o=n.filter(function(t){return t.name==e})[0]||n[0];this.setCurrentTheme(o.name,t)}},e.loadFromLocalstorage=function(){var e=localStorage.getItem("j-theme");if(e){var t=JSON.parse(e);return this.currentThemeLibrary=t.library,this.currentTheme=t.theme,!0}return!1},e.saveToLocalStorage=function(){localStorage.setItem("j-theme",JSON.stringify({library:this.currentThemeLibrary,theme:this.currentTheme}))},e.getThemes=function(e){return e=e||"jdash",this.themes[e]},e.registerDefinition=function(e,t){this.themes[e]=t},e.getCurrentTheme=function(){return this.currentThemeLibrary&&this.currentTheme?{library:this.currentThemeLibrary,theme:this.currentTheme}:void 0},e.clearCurrentTheme=function(){var e=this.getCurrentTheme();e&&document.body&&document.body.classList.remove(e.theme.cssClass)},e.setCurrentTheme=function(e,t){t=t||"jdash";var n=this.themes[t];this.getCurrentTheme()&&this.clearCurrentTheme();var o=n.filter(function(t){return t.name==e})[0];o&&(document.body.classList.add(o.cssClass),this.currentThemeLibrary=t,this.currentTheme=o,this.saveToLocalStorage())},e.themes={},e}();n.ThemeManager=o,o.registerDefinition("jdash",[{cssClass:"j-theme-jdash",name:"JDash"},{cssClass:"j-theme-jdash-dark",name:"JDash Dark"},{cssClass:"j-theme-red",name:"Red"},{cssClass:"j-theme-green",name:"Green"},{cssClass:"j-theme-blue",name:"Blue"},{cssClass:"j-theme-yellow",name:"Yellow"},{cssClass:"j-theme-black",name:"Black"},{cssClass:"j-theme-gray",name:"Gray"}]),o.registerDefinition("bootstrap",[{cssClass:"j-bootstrap-theme-default",name:"JDash"},{cssClass:"j-bootstrap-theme-dark",name:"JDash Dark"},{cssClass:"j-bootstrap-theme-red",name:"Red"},{cssClass:"j-bootstrap-theme-green",name:"Green"},{cssClass:"j-bootstrap-theme-blue",name:"Blue"},{cssClass:"j-bootstrap-theme-yellow",name:"Yellow"},{cssClass:"j-bootstrap-theme-black",name:"Black"},{cssClass:"j-bootstrap-theme-gray",name:"Gray"},{cssClass:"j-bootstrap-no-theme",name:"No Theme"}])},{}]},{},[36]);